@@ -29,4 +29,4 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
 
-extern GtkWidget *main_win_widget;
+template <typename T, typename D = gpointer> using GnomeCmdCallback = void (*)(T, D);
