@@ -51,54 +51,24 @@ GtkWidget *lookup_widget (GtkWidget *widget, const gchar *widget_name)
  *
  **********************************************************************/
 
-/**
- * This type of frame is the first thing packed in each tab
- *
- */
-GtkWidget *create_frame (GtkWidget *parent, const gchar *text, gint spacing)
+GtkWidget *create_grid (GtkWidget *parent)
 {
-    GtkWidget *frame = gtk_frame_new (text);
-    g_object_ref (frame);
-    g_object_set_data_full (G_OBJECT (parent), "spaced_frame", frame, g_object_unref);
-    gtk_container_set_border_width (GTK_CONTAINER (frame), spacing);
-    gtk_widget_show (frame);
-    return frame;
-}
+    GtkWidget *grid = gtk_grid_new ();
+    g_object_ref (grid);
+    g_object_set_data_full (G_OBJECT (parent), "grid", grid, g_object_unref);
+    gtk_widget_show (grid);
+    gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
 
-
-GtkWidget *create_tabframe (GtkWidget *parent)
-{
-    GtkWidget *frame = create_frame (parent, "", 6);
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-    return frame;
-}
-
-
-GtkWidget *create_space_frame (GtkWidget *parent, gint space)
-{
-    GtkWidget *frame = create_frame (parent, nullptr, space);
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-    return frame;
-}
-
-
-GtkWidget *create_table (GtkWidget *parent, gint rows, gint cols)
-{
-    GtkWidget *table = gtk_table_new (rows, cols, FALSE);
-    g_object_ref (table);
-    g_object_set_data_full (G_OBJECT (parent), "table", table, g_object_unref);
-    gtk_widget_show (table);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-
-    return table;
+    return grid;
 }
 
 
 GtkWidget *create_vbox (GtkWidget *parent, gboolean h, gint s)
 {
-    GtkWidget *vbox = gtk_vbox_new (h, s);
+    GtkWidget *vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, s);
     g_object_ref (vbox);
+    gtk_box_set_homogeneous (GTK_BOX (vbox), h);
     g_object_set_data_full (G_OBJECT (parent), "vbox", vbox, g_object_unref);
     gtk_widget_show (vbox);
 
@@ -108,8 +78,9 @@ GtkWidget *create_vbox (GtkWidget *parent, gboolean h, gint s)
 
 GtkWidget *create_hbox (GtkWidget *parent, gboolean h, gint s)
 {
-    GtkWidget *hbox = gtk_hbox_new (h, s);
+    GtkWidget *hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, s);
     g_object_ref (hbox);
+    gtk_box_set_homogeneous (GTK_BOX (hbox), h);
     g_object_set_data_full (G_OBJECT (parent), "hbox", hbox, g_object_unref);
     gtk_widget_show (hbox);
 
@@ -125,7 +96,8 @@ GtkWidget *create_label (GtkWidget *parent, const gchar *text)
     g_object_ref (label);
     g_object_set_data_full (G_OBJECT (parent), "label", label, g_object_unref);
     gtk_widget_show (label);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
 
     return label;
 }
@@ -141,7 +113,8 @@ GtkWidget *create_label_with_mnemonic (GtkWidget *parent, const gchar *text, Gtk
     g_object_ref (label);
     g_object_set_data_full (G_OBJECT (parent), "label", label, g_object_unref);
     gtk_widget_show (label);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
 
     return label;
 }
@@ -161,7 +134,7 @@ GtkWidget *create_bold_label (GtkWidget *parent, const gchar *text)
 
 GtkWidget *create_hsep (GtkWidget *parent)
 {
-    GtkWidget *sep = gtk_hseparator_new ();
+    GtkWidget *sep = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
     g_object_ref (sep);
     g_object_set_data_full (G_OBJECT (parent), "sep", sep, g_object_unref);
     gtk_widget_show (sep);
@@ -169,30 +142,20 @@ GtkWidget *create_hsep (GtkWidget *parent)
 }
 
 
-GtkWidget *create_space_hbox (GtkWidget *parent, GtkWidget *content)
-{
-    GtkWidget *hbox = create_hbox (parent, FALSE, 0);
-    GtkWidget *lbl = create_label (parent, "    ");
-
-    gtk_box_pack_start (GTK_BOX (hbox), lbl, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), content, TRUE, TRUE, 0);
-
-    return hbox;
-}
-
-
 GtkWidget *create_category (GtkWidget *parent, GtkWidget *content, const gchar *title)
 {
     GtkWidget *frame = create_vbox (parent, FALSE, 0);
     GtkWidget *label = create_bold_label (parent, title);
-    GtkWidget *hbox = create_space_hbox (parent, content);
-    GtkWidget *inner_frame = create_space_frame (parent, 3);
 
     g_object_set_data (G_OBJECT (frame), "label", label);
 
-    gtk_box_pack_start (GTK_BOX (frame), label, FALSE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (frame), inner_frame, TRUE, TRUE, 0);
-    gtk_container_add (GTK_CONTAINER (inner_frame), hbox);
+    gtk_widget_set_margin_top (content, 3);
+    gtk_widget_set_margin_bottom (content, 3);
+    gtk_widget_set_margin_start (content, 18);
+    gtk_widget_set_margin_end (content, 18);
+
+    gtk_box_append (GTK_BOX (frame), label);
+    gtk_box_append (GTK_BOX (frame), content);
 
     return frame;
 }
@@ -202,9 +165,9 @@ GtkWidget *create_named_button_with_data (GtkWidget *parent, const gchar *label,
 {
     guint key;
     GtkAccelGroup *accel_group = gtk_accel_group_new ();
-    GtkWidget *w = gtk_button_new_with_label ("");
+    GtkWidget *w = gtk_button_new_with_mnemonic (label);
 
-    key = gtk_label_parse_uline (GTK_LABEL (gtk_bin_get_child( GTK_BIN (w))), label);
+    key = gtk_label_get_mnemonic_keyval (GTK_LABEL (gtk_bin_get_child( GTK_BIN (w))));
     gtk_widget_add_accelerator (w, "clicked", accel_group, key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
     gtk_window_add_accel_group (GTK_WINDOW (parent), accel_group);
     g_object_ref (w);
@@ -217,25 +180,13 @@ GtkWidget *create_named_button_with_data (GtkWidget *parent, const gchar *label,
 }
 
 
-GtkWidget *create_named_stock_button_with_data (GtkWidget *parent, gconstpointer stock, const gchar *name, GCallback func, gpointer data)
-{
-    GtkWidget *w = gtk_button_new_from_stock ((const gchar *) stock);
-    g_object_ref (w);
-    g_object_set_data_full (G_OBJECT (parent), name, w, g_object_unref);
-    gtk_widget_show (w);
-    if (func)
-        g_signal_connect (w, "clicked", func, data);
-    return w;
-}
-
-
 GtkWidget *create_entry (GtkWidget *parent, const gchar *name, const gchar *value)
 {
     GtkWidget *w = gtk_entry_new ();
     g_object_ref (w);
     g_object_set_data_full (G_OBJECT (parent), name, w, g_object_unref);
     if (value)
-        gtk_entry_set_text (GTK_ENTRY (w), value);
+        gtk_editable_set_text (GTK_EDITABLE (w), value);
     gtk_widget_show (w);
     return w;
 }
@@ -289,27 +240,12 @@ GtkWidget *create_radio_with_mnemonic (GtkWidget *parent, GSList *group, gchar *
 
 GtkWidget *create_spin (GtkWidget *parent, const gchar *name, gint min, gint max, gint value)
 {
-    GtkObject *adj = gtk_adjustment_new (value, min, max, 1, 10, 0);
-#if defined (__GNUC__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wcast-align"
-#endif
-    GtkWidget *spin = gtk_spin_button_new (GTK_ADJUSTMENT (adj), 1, 0);
-#if defined (__GNUC__)
-#pragma GCC diagnostic pop
-#endif
+    GtkAdjustment *adj = GTK_ADJUSTMENT (gtk_adjustment_new (value, min, max, 1, 10, 0));
+    GtkWidget *spin = gtk_spin_button_new (adj, 1, 0);
     g_object_ref (spin);
     g_object_set_data_full (G_OBJECT (parent), name, spin, g_object_unref);
     gtk_widget_show (spin);
-#if defined (__GNUC__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wcast-align"
-#endif
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spin), TRUE);
-#if defined (__GNUC__)
-#pragma GCC diagnostic pop
-#endif
-
     return spin;
 }
 
@@ -357,8 +293,8 @@ static void icon_button_clicked (GtkButton *button, const gchar* iconPath)
     dialog = gtk_file_chooser_dialog_new (_("Select an Image File"),
                                             GTK_WINDOW (gtk_widget_get_ancestor ((GtkWidget*)button, GTK_TYPE_WINDOW)),
                                             GTK_FILE_CHOOSER_ACTION_OPEN,
-                                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                            GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                            _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                            _("_OK"), GTK_RESPONSE_ACCEPT,
                                             nullptr);
     if (iconPath)
     {
@@ -389,7 +325,7 @@ static void icon_button_clicked (GtkButton *button, const gchar* iconPath)
         gtk_widget_set_tooltip_text(GTK_WIDGET(button), icon_path);
     }
 
-    gtk_widget_destroy (dialog);
+    gtk_window_destroy (GTK_WINDOW (dialog));
 }
 
 
@@ -418,15 +354,7 @@ GtkWidget *create_icon_button_widget (GtkWidget *parent, const gchar *name, cons
 
 GtkWidget *create_scale (GtkWidget *parent, const gchar *name, gint value, gint min, gint max)
 {
-#if defined (__GNUC__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wcast-align"
-#endif
-    GtkWidget *scale = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (value, min, max, 0, 0, 0)));
-#if defined (__GNUC__)
-#pragma GCC diagnostic pop
-#endif
-
+    GtkWidget *scale = gtk_scale_new (GTK_ORIENTATION_HORIZONTAL, GTK_ADJUSTMENT (gtk_adjustment_new (value, min, max, 0, 0, 0)));
     g_object_ref (scale);
     g_object_set_data_full (G_OBJECT (parent), name, scale, g_object_unref);
     gtk_widget_show (scale);
@@ -436,52 +364,68 @@ GtkWidget *create_scale (GtkWidget *parent, const gchar *name, gint value, gint
 }
 
 
-GtkWidget *create_directory_chooser_button (GtkWidget *parent, const gchar *name, const gchar *value)
+static void directory_chooser_response (GtkNativeDialog *chooser, gint response_id, GtkWidget *button)
 {
-    GtkWidget *chooser;
-    chooser = gtk_file_chooser_button_new (_("Folder selection"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
-    if (value == nullptr)
-    {
-        gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser), "");
-    }
-    else
-    {
-        gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser), value);
-    }
-    g_object_ref (chooser);
-    g_object_set_data_full (G_OBJECT (parent), name, chooser, g_object_unref);
-    gtk_widget_show (chooser);
+    if (response_id != GTK_RESPONSE_ACCEPT)
+        return;
 
-    return chooser;
+    GFile *file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (chooser));
+    if (file != nullptr)
+    {
+        directory_chooser_button_set_file (button, file);
+        g_object_unref (file);
+    }
 }
 
 
-GtkWidget *create_file_chooser_button (GtkWidget *parent, const gchar *name, const gchar *value)
+static void on_directory_chooser_click (GtkButton *button, GtkWidget *parent)
 {
-    GtkWidget *chooser;
-    chooser = gtk_file_chooser_button_new (_("File selection"), GTK_FILE_CHOOSER_ACTION_OPEN);
-    if (value == nullptr)
-    {
-        gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (chooser), "");
-    }
-    else
-    {
-        gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (chooser), value);
-    }
+    gboolean local_only = reinterpret_cast<size_t> (g_object_get_data (G_OBJECT (button), "local_only")) != 0;
 
-    g_object_ref (chooser);
-    g_object_set_data_full (G_OBJECT (parent), name, chooser, g_object_unref);
-    gtk_widget_show (chooser);
+    auto chooser = gtk_file_chooser_native_new (_("Select Directory"),
+        GTK_WINDOW (parent),
+        GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+        nullptr,
+        nullptr);
+    gtk_native_dialog_set_modal (GTK_NATIVE_DIALOG (chooser), true);
+    gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (chooser), local_only);
+    g_signal_connect (chooser, "response", G_CALLBACK (directory_chooser_response), button);
 
-    return chooser;
+    if (GFile *file = directory_chooser_button_get_file (GTK_WIDGET (button)))
+        gtk_file_chooser_set_file (GTK_FILE_CHOOSER (chooser), file, nullptr);
+
+    gtk_native_dialog_show (GTK_NATIVE_DIALOG (chooser));
 }
 
 
-GtkWidget *create_treeview (GtkWidget *parent, const gchar *name, GtkTreeModel *model, gint rowh, GtkSignalFunc on_selection_changed, GtkSignalFunc on_rows_reordered)
+GtkWidget *create_directory_chooser_button (GtkWidget *parent, const gchar *name, bool local_only)
+{
+    GtkWidget *button = create_named_button (parent, _("(None)"), name, G_CALLBACK (on_directory_chooser_click));
+    g_object_set_data (G_OBJECT (button), "local_only", reinterpret_cast<gpointer>((size_t) local_only));
+    return button;
+}
+
+
+GFile *directory_chooser_button_get_file (GtkWidget *button)
+{
+    return (GFile *) g_object_get_data (G_OBJECT (button), "file");
+}
+
+
+void directory_chooser_button_set_file (GtkWidget *button, GFile *file)
+{
+    g_object_set_data_full (G_OBJECT (button), "file", g_object_ref (file), g_object_unref);
+    gchar *label = file ? g_file_get_basename (file) : _("(None)");
+    gtk_button_set_label (GTK_BUTTON (button), label);
+    g_free (label);
+}
+
+
+GtkWidget *create_treeview (GtkWidget *parent, const gchar *name, GtkTreeModel *model, gint rowh, GCallback on_selection_changed, GCallback on_rows_reordered)
 {
     GtkWidget *sw, *view;
 
-    sw = gtk_scrolled_window_new (nullptr, nullptr);
+    sw = gtk_scrolled_window_new ();
     g_object_ref (sw);
     g_object_set_data_full (G_OBJECT (parent), "sw", sw, g_object_unref);
     gtk_widget_show (sw);
@@ -495,7 +439,7 @@ GtkWidget *create_treeview (GtkWidget *parent, const gchar *name, GtkTreeModel *
     gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (view), TRUE);
     gtk_tree_view_set_headers_clickable (GTK_TREE_VIEW (view), FALSE);
     gtk_widget_show (view);
-    gtk_container_add (GTK_CONTAINER (sw), view);
+    gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (sw), view);
 
     g_object_unref (model);
 
@@ -519,20 +463,24 @@ void create_treeview_column (GtkWidget *sw, gint col, gint width, const gchar *l
     GtkCellRenderer *renderer;
     const gchar *attribute;
     GType type = gtk_tree_model_get_column_type (model, col);
-    switch (type)
+    if (type == G_TYPE_STRING)
     {
-        case G_TYPE_STRING:
-            renderer = gtk_cell_renderer_text_new ();
-            attribute = "text";
-            break;
-        default:
-            if (type == GDK_TYPE_PIXBUF)
-            {
-                renderer = gtk_cell_renderer_pixbuf_new ();
-                attribute = "pixbuf";
-                break;
-            }
-            return;
+        renderer = gtk_cell_renderer_text_new ();
+        attribute = "text";
+    }
+    else if (type == G_TYPE_ICON)
+    {
+        renderer = gtk_cell_renderer_pixbuf_new ();
+        attribute = "gicon";
+    }
+    else if (type == GDK_TYPE_PIXBUF)
+    {
+        renderer = gtk_cell_renderer_pixbuf_new ();
+        attribute = "pixbuf";
+    }
+    else
+    {
+        return;
     }
 
     gtk_cell_renderer_set_fixed_size (renderer, -1, rowh);
@@ -550,7 +498,7 @@ void create_treeview_column (GtkWidget *sw, gint col, gint width, const gchar *l
 
 GtkWidget *create_vbuttonbox (GtkWidget *parent)
 {
-    GtkWidget *w = gtk_vbutton_box_new ();
+    GtkWidget *w = gtk_button_box_new (GTK_ORIENTATION_VERTICAL);
     g_object_ref (w);
     g_object_set_data_full (G_OBJECT (parent), "vbuttonbox", w, g_object_unref);
     gtk_widget_show (w);
@@ -562,7 +510,7 @@ GtkWidget *create_vbuttonbox (GtkWidget *parent)
 
 GtkWidget *create_hbuttonbox (GtkWidget *parent)
 {
-    GtkWidget *w = gtk_hbutton_box_new ();
+    GtkWidget *w = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
     g_object_ref (w);
     g_object_set_data_full (G_OBJECT (parent), "hbuttonbox", w, g_object_unref);
     gtk_widget_show (w);
@@ -586,8 +534,9 @@ GtkWidget *create_combo_box_text (GtkWidget *parent, const gchar **items)
     g_object_set_data_full (G_OBJECT (parent), "combo", combo, g_object_unref);
     gtk_widget_show (combo);
 
-    for (gint i = 0; items[i]; i++)
-        gtk_combo_box_text_append_text ((GtkComboBoxText*) combo, items[i]);
+    if (items)
+        for (gint i = 0; items[i]; i++)
+            gtk_combo_box_text_append_text ((GtkComboBoxText*) combo, items[i]);
 
     return combo;
 }
@@ -606,7 +555,7 @@ GtkWidget *create_progress_bar (GtkWidget *parent)
 
 GtkWidget *create_sw (GtkWidget *parent)
 {
-    GtkWidget *scrolledwindow = gtk_scrolled_window_new (nullptr, nullptr);
+    GtkWidget *scrolledwindow = gtk_scrolled_window_new ();
     g_object_ref (scrolledwindow);
     g_object_set_data_full (G_OBJECT (parent), "scrolledwindow", scrolledwindow, g_object_unref);
     gtk_widget_show (scrolledwindow);
@@ -621,28 +570,110 @@ const char *get_entry_text (GtkWidget *parent, const gchar *entry_name)
     if (!entry) return nullptr;
     if (!GTK_IS_ENTRY (entry)) return nullptr;
 
-    return gtk_entry_get_text (GTK_ENTRY (entry));
+    return gtk_editable_get_text (GTK_EDITABLE (entry));
 }
 
 
-static void on_response (GtkDialog *dialog, gint id, gpointer data)
+struct ActionAcceleratorClosure
 {
-    gtk_widget_destroy (GTK_WIDGET (dialog));
-}
+    GActionGroup *action_group;
+    gchar *action_name;
+    GVariant *parameter;
+};
 
-void create_error_dialog (const gchar *msg, ...)
+
+static gboolean action_accelerator_closure_handle(GtkAccelGroup *accel_group,
+                                                  GObject *acceleratable,
+                                                  guint keyval,
+                                                  GdkModifierType modifier,
+                                                  gpointer user_data)
 {
-    va_list      argptr;
-    gchar        string[1024];
-    GtkWidget    *dialog;
+    ActionAcceleratorClosure *obj = static_cast<ActionAcceleratorClosure*> (user_data);
+    GVariant *parameter = obj->parameter ? g_variant_ref (obj->parameter) : nullptr;
 
-    va_start (argptr, msg);
-    vsprintf (string, msg, argptr);
-    va_end (argptr);
+    if (obj->action_group != nullptr)
+    {
+        const gchar *action_name = strchr (obj->action_name, '.');
+        if (action_name != nullptr)
+            action_name += 1;
+        else
+            action_name = obj->action_name;
 
-    dialog = gtk_message_dialog_new (GTK_WINDOW (main_win_widget), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", string);
-
-    g_signal_connect (dialog, "response", G_CALLBACK (on_response), dialog);
-
-    gtk_widget_show (dialog);
+        g_action_group_activate_action (obj->action_group, action_name, parameter);
+    }
+    else
+    {
+        g_warning ("Cannot activate action %s.", obj->action_name);
+    }
+    return TRUE;
 }
+
+
+static void action_accelerator_closure_free(gpointer user_data, GClosure *closure)
+{
+    ActionAcceleratorClosure *obj = static_cast<ActionAcceleratorClosure*> (user_data);
+    if (obj)
+    {
+        g_clear_object (&obj->action_group);
+        g_clear_pointer (&obj->action_name, g_free);
+        g_clear_pointer (&obj->parameter, g_variant_unref);
+    }
+}
+
+
+static GClosure *action_accelerator_closure_new (GActionGroup *action_group,
+                                                 const gchar *detailed_action)
+{
+    gchar *action_name;
+    GVariant *parameter;
+    GError *error;
+    if (!g_action_parse_detailed_name (detailed_action, &action_name, &parameter, &error))
+    {
+        g_message("g_action_parse_detailed_name error: %s\n", error->message);
+        g_error_free (error);
+        return nullptr;
+    }
+
+    ActionAcceleratorClosure* obj = new ActionAcceleratorClosure {
+        action_group = g_object_ref (action_group),
+        action_name,
+        parameter,
+    };
+    return g_cclosure_new (G_CALLBACK(action_accelerator_closure_handle), obj, action_accelerator_closure_free);
+}
+
+
+MenuBuilder MenuBuilder::item(GMenuItem *item) &&
+{
+    g_menu_append_item (menu, item);
+    g_object_unref (item);
+    return *this;
+}
+
+
+MenuBuilder MenuBuilder::item(const gchar *label,
+                              const gchar *detailed_action,
+                              const gchar *accelerator,
+                              const gchar *icon) &&
+{
+    GMenuItem *item = g_menu_item_new (label, detailed_action);
+    if (accelerator)
+    {
+        g_menu_item_set_attribute_value(item, "accel", g_variant_new_string (accelerator));
+
+        guint accelerator_key;
+        GdkModifierType accelerator_mods;
+        gtk_accelerator_parse (accelerator, &accelerator_key, &accelerator_mods);
+        gtk_accel_group_connect (accel_group,
+                                 accelerator_key,
+                                 accelerator_mods,
+                                 GTK_ACCEL_VISIBLE,
+                                 action_accelerator_closure_new (action_group, detailed_action));
+    }
+    if (icon)
+        g_menu_item_set_icon (item, g_themed_icon_new (icon));
+    g_menu_append_item (menu, item);
+    g_object_unref (item);
+    return *this;
+}
+
