@@ -21,31 +21,6 @@
 
 #pragma once
 
-#define TEST_PLUGIN(obj) \
-    G_TYPE_CHECK_INSTANCE_CAST (obj, test_plugin_get_type (), TestPlugin)
-#define TEST_PLUGIN_CLASS(klass) \
-    G_TYPE_CHECK_CLASS_CAST (klass, test_plugin_get_type (), TestPluginClass)
-#define IS_TEST_PLUGIN(obj) \
-    G_TYPE_CHECK_INSTANCE_TYPE (obj, test_plugin_get_type ())
-
-
-typedef struct _TestPlugin TestPlugin;
-typedef struct _TestPluginClass TestPluginClass;
-
-struct _TestPlugin
-{
-    GnomeCmdPlugin parent;
-};
-
-struct _TestPluginClass
-{
-    GnomeCmdPluginClass parent_class;
-};
-
-
-GType test_plugin_get_type ();
-
-GnomeCmdPlugin *test_plugin_new ();
 extern "C"
 {
     GnomeCmdPlugin *create_plugin   ();
