@@ -37,8 +37,8 @@ static void response_callback (GtkDialog *dialog, int response_id, GnomeCmd::Reg
     switch (response_id)
     {
         case GTK_RESPONSE_OK:
-            rx->assign(gtk_entry_get_text (GTK_ENTRY (lookup_widget (GTK_WIDGET (dialog), "pattern"))),
-                       gtk_entry_get_text (GTK_ENTRY (lookup_widget (GTK_WIDGET (dialog), "replace"))),
+            rx->assign(gtk_editable_get_text (GTK_EDITABLE (lookup_widget (GTK_WIDGET (dialog), "pattern"))),
+                       gtk_editable_get_text (GTK_EDITABLE (lookup_widget (GTK_WIDGET (dialog), "replace"))),
                        gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (lookup_widget (GTK_WIDGET (dialog), "match_case"))));
             break;
 
@@ -58,58 +58,57 @@ gboolean gnome_cmd_advrename_regex_dialog_new (const gchar *title, GtkWindow *pa
     GtkWidget *dialog = gtk_dialog_new_with_buttons (title, parent,
                                                      GtkDialogFlags (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
                                                      // GTK_STOCK_HELP, GTK_RESPONSE_HELP,             //  FIXME: ???
-                                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                                     GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                                     _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                                     _("_OK"), GTK_RESPONSE_OK,
                                                      NULL);
     GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
     gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-    gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
     // HIG defaults
-    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-    gtk_box_set_spacing (GTK_BOX (content_area), 2);
-    gtk_container_set_border_width (GTK_CONTAINER (content_area), 5);
-    gtk_box_set_spacing (GTK_BOX (content_area),6);
+    gtk_widget_set_margin_top (content_area, 10);
+    gtk_widget_set_margin_bottom (content_area, 10);
+    gtk_widget_set_margin_start (content_area, 10);
+    gtk_widget_set_margin_end (content_area, 10);
+    gtk_box_set_spacing (GTK_BOX (content_area), 6);
 
-    GtkWidget *table, *align, *label, *entry, *check;
+    GtkWidget *grid, *label, *entry, *check;
 
-    table = gtk_table_new (3, 2, FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (table), 5);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-    gtk_container_add (GTK_CONTAINER (content_area), table);
+    grid = gtk_grid_new ();
+    gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
+    gtk_box_append (GTK_BOX (content_area), grid);
 
     label = gtk_label_new_with_mnemonic (_("_Search for:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
 
     entry = gtk_entry_new ();
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
-    gtk_entry_set_text (GTK_ENTRY (entry), rx ? rx->pattern.c_str() : nullptr);
+    gtk_editable_set_text (GTK_EDITABLE (entry), rx ? rx->pattern.c_str() : nullptr);
     g_object_set_data (G_OBJECT (dialog), "pattern", entry);
     gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-    gtk_table_attach_defaults (GTK_TABLE (table), entry, 1, 2, 0, 1);
+    gtk_grid_attach (GTK_GRID (grid), entry, 1, 0, 1, 1);
 
     label = gtk_label_new_with_mnemonic (_("_Replace with:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
 
     entry = gtk_entry_new ();
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
-    gtk_entry_set_text (GTK_ENTRY (entry), rx ? rx->replacement.c_str() : nullptr);
+    gtk_editable_set_text (GTK_EDITABLE (entry), rx ? rx->replacement.c_str() : nullptr);
     g_object_set_data (G_OBJECT (dialog), "replace", entry);
     gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-    gtk_table_attach_defaults (GTK_TABLE (table), entry, 1, 2, 1, 2);
-
-    align = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (align), 6, 0, 12, 0);
-    gtk_table_attach_defaults (GTK_TABLE (table), align, 0, 2, 2, 3);
+    gtk_grid_attach (GTK_GRID (grid), entry, 1, 1, 1, 1);
 
     check = gtk_check_button_new_with_mnemonic (_("_Match case"));
     g_object_set_data (G_OBJECT (dialog), "match_case", check);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), rx ? rx->match_case : FALSE);
-    gtk_container_add (GTK_CONTAINER (align), check);
+    gtk_widget_set_margin_top (check, 6);
+    gtk_widget_set_margin_start (check, 12);
+    gtk_grid_attach (GTK_GRID (grid), check, 0, 2, 2, 1);
 
     gtk_widget_show_all (content_area);
 
@@ -119,7 +118,7 @@ gboolean gnome_cmd_advrename_regex_dialog_new (const gchar *title, GtkWindow *pa
 
     gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
-    gtk_widget_destroy (dialog);
+    gtk_window_destroy (GTK_WINDOW (dialog));
 
     return result==GTK_RESPONSE_OK;
 }
