@@ -25,7 +25,6 @@
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-file-list.h"
-#include "gnome-cmd-main-win.h"
 #include "utils.h"
 #include "dialogs/gnome-cmd-delete-dialog.h"
 
@@ -119,27 +118,30 @@ inline void create_delete_progress_win (DeleteData *deleteData)
 
     deleteData->progwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title (GTK_WINDOW (deleteData->progwin), _("Deleting…"));
-    gtk_window_set_policy (GTK_WINDOW (deleteData->progwin), FALSE, FALSE, FALSE);
+    gtk_window_set_resizable (GTK_WINDOW (deleteData->progwin), FALSE);
     gtk_window_set_position (GTK_WINDOW (deleteData->progwin), GTK_WIN_POS_CENTER);
     gtk_widget_set_size_request (GTK_WIDGET (deleteData->progwin), 300, -1);
     g_signal_connect (deleteData->progwin, "destroy-event", G_CALLBACK (on_progwin_destroy), deleteData);
 
     vbox = create_vbox (deleteData->progwin, FALSE, 6);
     gtk_container_add (GTK_CONTAINER (deleteData->progwin), vbox);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
+    gtk_widget_set_margin_top (vbox, 5);
+    gtk_widget_set_margin_bottom (vbox, 5);
+    gtk_widget_set_margin_start (vbox, 5);
+    gtk_widget_set_margin_end (vbox, 5);
 
     deleteData->proglabel = create_label (deleteData->progwin, "");
-    gtk_container_add (GTK_CONTAINER (vbox), deleteData->proglabel);
+    gtk_box_append (GTK_BOX (vbox), deleteData->proglabel);
 
     deleteData->progbar = create_progress_bar (deleteData->progwin);
-    gtk_container_add (GTK_CONTAINER (vbox), deleteData->progbar);
+    gtk_box_append (GTK_BOX (vbox), deleteData->progbar);
 
     bbox = create_hbuttonbox (deleteData->progwin);
-    gtk_container_add (GTK_CONTAINER (vbox), bbox);
+    gtk_box_append (GTK_BOX (vbox), bbox);
 
-    button = create_stock_button_with_data (deleteData->progwin, GTK_STOCK_CANCEL, GTK_SIGNAL_FUNC (on_cancel), deleteData);
+    button = create_button_with_data (deleteData->progwin, _("_Cancel"), G_CALLBACK (on_cancel), deleteData);
     gtk_widget_set_can_default (button, TRUE);
-    gtk_container_add (GTK_CONTAINER (bbox), button);
+    gtk_box_append (GTK_BOX (bbox), button);
 
     g_object_ref (deleteData->progwin);
     gtk_widget_show (deleteData->progwin);
@@ -207,7 +209,7 @@ static gboolean perform_delete_operation_r(DeleteData *deleteData, GList *gnomeC
         auto gnomeCmdFile = static_cast<GnomeCmdFile*>(gCmdFileGListItem->data);
 
         g_return_val_if_fail (GNOME_CMD_IS_FILE(gnomeCmdFile), FALSE);
-        g_return_val_if_fail (G_IS_FILE_INFO(gnomeCmdFile->gFileInfo), FALSE);
+        g_return_val_if_fail (G_IS_FILE_INFO(gnomeCmdFile->get_file_info()), FALSE);
 
         auto filenameTmp = gnomeCmdFile->get_name();
 
@@ -218,13 +220,13 @@ static gboolean perform_delete_operation_r(DeleteData *deleteData, GList *gnomeC
         {
             case DeleteData::OriginAction::FORCE_DELETE:
             case DeleteData::OriginAction::MOVE:
-                g_file_delete (gnomeCmdFile->gFile, deleteData->cancellable, &tmpError);
+                g_file_delete (gnomeCmdFile->get_file(), deleteData->cancellable, &tmpError);
                 break;
             case DeleteData::OriginAction::DELETE:
             default:
                 gnome_cmd_data.options.deleteToTrash
-                    ? g_file_trash (gnomeCmdFile->gFile, deleteData->cancellable, &tmpError)
-                    : g_file_delete (gnomeCmdFile->gFile, deleteData->cancellable, &tmpError);
+                    ? g_file_trash (gnomeCmdFile->get_file(), deleteData->cancellable, &tmpError)
+                    : g_file_delete (gnomeCmdFile->get_file(), deleteData->cancellable, &tmpError);
                 break;
         }
 
@@ -233,7 +235,7 @@ static gboolean perform_delete_operation_r(DeleteData *deleteData, GList *gnomeC
             g_error_free(tmpError);
             tmpError = nullptr;
             auto gnomeCmdDir = GNOME_CMD_DIR (gnomeCmdFile);
-            gnome_cmd_dir_list_files (gnomeCmdDir, FALSE);
+            gnome_cmd_dir_list_files (deleteData->parent_window, gnomeCmdDir, FALSE);
 
             if (perform_delete_subdirs(gnomeCmdDir, deleteData))
             {
@@ -297,7 +299,7 @@ static gboolean update_delete_status_widgets (DeleteData *deleteData)
                                         deleteData->error->message);
 
         deleteData->problem_action = run_simple_dialog (
-            *main_win, TRUE, GTK_MESSAGE_ERROR, msg, _("Delete problem"),
+            deleteData->parent_window, TRUE, GTK_MESSAGE_ERROR, msg, _("Delete problem"),
             -1, _("Abort"), _("Retry"), _("Skip"), NULL);
 
         g_free (msg);
@@ -312,7 +314,7 @@ static gboolean update_delete_status_widgets (DeleteData *deleteData)
         g_thread_join (deleteData->thread);
 
         if (deleteData->error)
-            gnome_cmd_show_message (*main_win, deleteData->error->message);
+            gnome_cmd_show_message (deleteData->parent_window, deleteData->error->message);
 
         if (deleteData->deletedGnomeCmdFiles)
         {
@@ -328,7 +330,7 @@ static gboolean update_delete_status_widgets (DeleteData *deleteData)
 
         if (deleteData->progwin)
         {
-            gtk_widget_destroy (deleteData->progwin);
+            gtk_window_destroy (GTK_WINDOW (deleteData->progwin));
         }
 
         cleanup (deleteData);
@@ -353,7 +355,7 @@ void do_delete (DeleteData *deleteData, gboolean showProgress = true)
 
     for(auto fileListItem = deleteData->gnomeCmdFiles; fileListItem; fileListItem = fileListItem->next)
     {
-        auto gFile = GNOME_CMD_FILE(fileListItem->data)->gFile;
+        auto gFile = GNOME_CMD_FILE(fileListItem->data)->get_file();
         g_return_if_fail(G_IS_FILE(gFile));
 
         if (showProgress)
@@ -400,7 +402,7 @@ void do_delete (DeleteData *deleteData, gboolean showProgress = true)
  * This happens as of user interaction.
  * The returned list has to be free'ed by g_list_free.
  */
-static GList *remove_items_from_list_to_be_deleted(GList *files)
+static GList *remove_items_from_list_to_be_deleted(GtkWindow *parent_window, GList *files)
 {
     if (!gnome_cmd_data.options.confirm_delete)
     {
@@ -423,7 +425,7 @@ static GList *remove_items_from_list_to_be_deleted(GList *files)
             guint64 num_files;
             gboolean canNotMeasure = FALSE;
 
-            g_file_measure_disk_usage (gnomeCmdFile->gFile,
+            g_file_measure_disk_usage (gnomeCmdFile->get_file(),
                        G_FILE_MEASURE_NONE,
                        nullptr, nullptr, nullptr, nullptr,
                        &num_dirs,
@@ -442,7 +444,7 @@ static GList *remove_items_from_list_to_be_deleted(GList *files)
 
                 gchar *msg = g_strdup_printf (_("Error while deleting: \n\n%s"), error->message);
 
-                run_simple_dialog (*main_win, FALSE, GTK_MESSAGE_ERROR, msg, _("Delete problem"), -1, _("Abort"), NULL);
+                run_simple_dialog (parent_window, FALSE, GTK_MESSAGE_ERROR, msg, _("Delete problem"), -1, _("Abort"), NULL);
                 g_free (msg);
 
                 g_error_free (error);
@@ -456,7 +458,7 @@ static GList *remove_items_from_list_to_be_deleted(GList *files)
                     ? g_strdup_printf (_("Do you really want to delete “%s”?"), gnomeCmdFile->get_name())
                     : g_strdup_printf (_("The directory “%s” is not empty. Do you really want to delete it?"), gnomeCmdFile->get_name());
 
-                guiResponse = run_simple_dialog (*main_win, FALSE, GTK_MESSAGE_WARNING, msg, _("Delete"),
+                guiResponse = run_simple_dialog (parent_window, FALSE, GTK_MESSAGE_WARNING, msg, _("Delete"),
                                   gnome_cmd_data.options.confirm_delete_default==GTK_BUTTONS_CANCEL ? 0 : 3,
                                   _("Cancel"), _("Skip"),
                                   dirCount++ == 0 ? _("Delete All") : _("Delete Remaining"),
@@ -505,7 +507,7 @@ static GList *remove_items_from_list_to_be_deleted(GList *files)
 /**
  * Creates a delete dialog for the given list of GnomeCmdFiles
  */
-void gnome_cmd_delete_dialog_show (GList *files, gboolean forceDelete)
+void gnome_cmd_delete_dialog_show (GtkWindow *parent_window, GList *files, gboolean forceDelete)
 {
     g_return_if_fail (files != nullptr);
 
@@ -542,7 +544,7 @@ void gnome_cmd_delete_dialog_show (GList *files, gboolean forceDelete)
                                    n_files);
         }
 
-        response = run_simple_dialog (*main_win, FALSE,
+        response = run_simple_dialog (parent_window, FALSE,
                                       forceDelete || !gnome_cmd_data.options.deleteToTrash
                                         ? GTK_MESSAGE_WARNING
                                         : GTK_MESSAGE_QUESTION,
@@ -559,13 +561,14 @@ void gnome_cmd_delete_dialog_show (GList *files, gboolean forceDelete)
     }
 
     // eventually remove non-empty dirs from list
-    files = remove_items_from_list_to_be_deleted(files);
+    files = remove_items_from_list_to_be_deleted(parent_window, files);
 
     if (files == nullptr)
         return;
 
     DeleteData *deleteData = g_new0 (DeleteData, 1);
 
+    deleteData->parent_window = parent_window;
     deleteData->gnomeCmdFiles = files;
     deleteData->originAction = forceDelete
         ? DeleteData::OriginAction::FORCE_DELETE
