@@ -35,7 +35,7 @@ static void response_callback (GtkDialog *dialog, int response_id, gpointer unus
     {
         case GTK_RESPONSE_OK:
             {
-                const gchar *name = gtk_entry_get_text (GTK_ENTRY (lookup_widget (GTK_WIDGET (dialog), "name")));
+                const gchar *name = gtk_editable_get_text (GTK_EDITABLE (lookup_widget (GTK_WIDGET (dialog), "name")));
 
                 if (!name || !*name)
                 {
@@ -44,7 +44,7 @@ static void response_callback (GtkDialog *dialog, int response_id, gpointer unus
                     break;
                 }
 
-                const gchar *path = gtk_entry_get_text (GTK_ENTRY (lookup_widget (GTK_WIDGET (dialog), "path")));
+                const gchar *path = gtk_editable_get_text (GTK_EDITABLE (lookup_widget (GTK_WIDGET (dialog), "path")));
 
                 if (!path || !*path)
                 {
@@ -71,50 +71,59 @@ gboolean gnome_cmd_edit_bookmark_dialog (GtkWindow *parent, const gchar *title,
 {
     GtkWidget *dialog = gtk_dialog_new_with_buttons (title, parent,
                                                      GtkDialogFlags (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-                                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                                     GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                                     _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                                     _("_OK"), GTK_RESPONSE_OK,
                                                      NULL);
 
     GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
     gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-    gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
     // HIG defaults
-    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-    gtk_box_set_spacing (GTK_BOX (content_area), 2);
-    gtk_container_set_border_width (GTK_CONTAINER (content_area), 5);
-    gtk_box_set_spacing (GTK_BOX (content_area),6);
+    gtk_widget_set_margin_top (content_area, 10);
+    gtk_widget_set_margin_bottom (content_area, 10);
+    gtk_widget_set_margin_start (content_area, 10);
+    gtk_widget_set_margin_end (content_area, 10);
+    gtk_box_set_spacing (GTK_BOX (content_area), 6);
 
-    GtkWidget *table, *label, *entry;
+    GtkWidget *grid, *label, *entry;
 
-    table = gtk_table_new (3, 2, FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (table), 5);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-    gtk_container_add (GTK_CONTAINER (content_area), table);
+    grid = gtk_grid_new ();
+    gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
+    gtk_box_append (GTK_BOX (content_area), grid);
 
     label = gtk_label_new_with_mnemonic (_("Bookmark _name:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+    gtk_widget_set_hexpand (label, TRUE);
+    gtk_widget_set_vexpand (label, TRUE);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
 
     entry = gtk_entry_new ();
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
-    gtk_entry_set_text (GTK_ENTRY (entry), name);
+    gtk_editable_set_text (GTK_EDITABLE (entry), name);
     g_object_set_data (G_OBJECT (dialog), "name", entry);
     gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-    gtk_table_attach_defaults (GTK_TABLE (table), entry, 1, 2, 0, 1);
+    gtk_widget_set_hexpand (entry, TRUE);
+    gtk_widget_set_vexpand (entry, TRUE);
+    gtk_grid_attach (GTK_GRID (grid), entry, 1, 0, 1, 1);
 
     label = gtk_label_new_with_mnemonic (_("Bookmark _target:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+    gtk_widget_set_hexpand (label, TRUE);
+    gtk_widget_set_vexpand (label, TRUE);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
 
     entry = gtk_entry_new ();
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
-    gtk_entry_set_text (GTK_ENTRY (entry), path);
+    gtk_editable_set_text (GTK_EDITABLE (entry), path);
     g_object_set_data (G_OBJECT (dialog), "path", entry);
     gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-    gtk_table_attach_defaults (GTK_TABLE (table), entry, 1, 2, 1, 2);
+    gtk_widget_set_hexpand (entry, TRUE);
+    gtk_widget_set_vexpand (entry, TRUE);
+    gtk_grid_attach (GTK_GRID (grid), entry, 1, 1, 1, 1);
 
     gtk_widget_show_all (content_area);
 
@@ -127,12 +136,12 @@ gboolean gnome_cmd_edit_bookmark_dialog (GtkWindow *parent, const gchar *title,
     if (result==GTK_RESPONSE_OK)
     {
         g_free (name);
-        name = g_strdup (gtk_entry_get_text (GTK_ENTRY (lookup_widget (GTK_WIDGET (dialog), "name"))));
+        name = g_strdup (gtk_editable_get_text (GTK_EDITABLE (lookup_widget (GTK_WIDGET (dialog), "name"))));
         g_free (path);
-        path = g_strdup (gtk_entry_get_text (GTK_ENTRY (lookup_widget (GTK_WIDGET (dialog), "path"))));
+        path = g_strdup (gtk_editable_get_text (GTK_EDITABLE (lookup_widget (GTK_WIDGET (dialog), "path"))));
     }
 
-    gtk_widget_destroy (dialog);
+    gtk_window_destroy (GTK_WINDOW (dialog));
 
     return result==GTK_RESPONSE_OK;
 }
