@@ -60,7 +60,7 @@ namespace GnomeCmd
                 break;
 
             case GTK_RESPONSE_OK:
-                dlg->component->profile.name = gtk_entry_get_text (GTK_ENTRY (lookup_widget (GTK_WIDGET (dialog), "name")));
+                dlg->component->profile.name = gtk_editable_get_text (GTK_EDITABLE (lookup_widget (GTK_WIDGET (dialog), "name")));
                 dlg->component->copy();
                 break;
 
@@ -79,47 +79,42 @@ namespace GnomeCmd
     {
         GtkWidget *dialog = gtk_dialog_new_with_buttons (_("Edit Profile"), parent,
                                                          GtkDialogFlags (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-                                                         GTK_STOCK_HELP, GTK_RESPONSE_HELP,
+                                                         _("_Help"), GTK_RESPONSE_HELP,
                                                          _("Reset"), GCMD_RESPONSE_RESET,
-                                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                                         GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                                         _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                                         _("_OK"), GTK_RESPONSE_OK,
                                                          NULL);
 
         GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
         gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
         // HIG defaults
-        gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-        gtk_box_set_spacing (GTK_BOX (content_area), 2);
-        gtk_container_set_border_width (GTK_CONTAINER (content_area), 5);
-        gtk_box_set_spacing (GTK_BOX (content_area),6);
-
-        GtkWidget *vbox = gtk_vbox_new (FALSE, 6);
-        gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
-        gtk_box_pack_start (GTK_BOX (content_area), vbox, TRUE, TRUE, 0);
+        gtk_widget_set_margin_top (content_area, 10);
+        gtk_widget_set_margin_bottom (content_area, 10);
+        gtk_widget_set_margin_start (content_area, 10);
+        gtk_widget_set_margin_end (content_area, 10);
+        gtk_box_set_spacing (GTK_BOX (content_area), 6);
 
         gchar *str = g_strdup_printf ("<b>%s</b>", _("_Name"));
         GtkWidget *label = gtk_label_new_with_mnemonic (str);
         g_free (str);
 
         gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-        gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-
-        GtkWidget *align = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
-        gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 6, 12, 0);
-        gtk_container_add (GTK_CONTAINER (vbox), align);
+        gtk_widget_set_halign (label, GTK_ALIGN_START);
+        gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+        gtk_box_append (GTK_BOX (content_area), label);
 
         GtkWidget *entry = gtk_entry_new ();
         g_object_set_data (G_OBJECT (dialog), "name", entry);
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
-        gtk_entry_set_text (GTK_ENTRY (entry), profile.name.c_str());
-        gtk_container_add (GTK_CONTAINER (align), entry);
+        gtk_editable_set_text (GTK_EDITABLE (entry), profile.name.c_str());
+        gtk_widget_set_margin_bottom (entry, 6);
+        gtk_widget_set_margin_start (entry, 12);
+        gtk_box_append (GTK_BOX (content_area), entry);
 
         component = new COMPONENT(profile);
-        gtk_container_add (GTK_CONTAINER (vbox), *component);
+        gtk_box_append (GTK_BOX (content_area), *component);
 
         component->update();
 
@@ -131,6 +126,6 @@ namespace GnomeCmd
 
         result = gtk_dialog_run (GTK_DIALOG (dialog));
 
-        gtk_widget_destroy (dialog);
+        gtk_window_destroy (GTK_WINDOW (dialog));
     }
 }
