@@ -174,7 +174,7 @@ static void on_dialog_ok (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
 
     gboolean retValue = true;
 
-    const gchar *filename = gtk_entry_get_text (GTK_ENTRY (data->filename_entry));
+    const gchar *filename = gtk_editable_get_text (GTK_EDITABLE (data->filename_entry));
 
     if (strcmp (filename, data->f->get_name()) != 0)
     {
@@ -188,7 +188,7 @@ static void on_dialog_ok (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
     {
         auto perms = gnome_cmd_chmod_component_get_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component));
 
-        if (perms != (get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_MODE) & 0xFFF ))
+        if (perms != (get_gfile_attribute_uint32(data->f->get_file(), G_FILE_ATTRIBUTE_UNIX_MODE) & 0xFFF ))
             retValue = data->f->chmod(perms, &error);
     }
 
@@ -197,8 +197,8 @@ static void on_dialog_ok (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
         uid_t uid = gnome_cmd_chown_component_get_owner (GNOME_CMD_CHOWN_COMPONENT (data->chown_component));
         gid_t gid = gnome_cmd_chown_component_get_group (GNOME_CMD_CHOWN_COMPONENT (data->chown_component));
 
-        if (   uid != get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_UID)
-            || gid != get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_GID))
+        if (   uid != get_gfile_attribute_uint32(data->f->get_file(), G_FILE_ATTRIBUTE_UNIX_UID)
+            || gid != get_gfile_attribute_uint32(data->f->get_file(), G_FILE_ATTRIBUTE_UNIX_GID))
         {
             retValue = data->f->chown(uid, gid, &error);
         }
@@ -211,13 +211,13 @@ static void on_dialog_ok (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
         return;
     }
 
-    gtk_widget_destroy (data->dialog);
+    gtk_window_destroy (GTK_WINDOW (data->dialog));
 }
 
 
 static void on_dialog_cancel (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
 {
-    gtk_widget_destroy (data->dialog);
+    gtk_window_destroy (GTK_WINDOW (data->dialog));
 }
 
 
@@ -262,19 +262,19 @@ static void on_dialog_help (GtkButton *button, GnomeCmdFilePropsDialogPrivate *d
 }
 
 
-static void on_notebook_page_change (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, GnomeCmdFilePropsDialogPrivate *data)
+static void on_notebook_page_change (GtkNotebook *notebook, gpointer page, guint page_num, GnomeCmdFilePropsDialogPrivate *data)
 {
     gtk_widget_set_sensitive (data->copy_button, page_num==2);
 }
 
 
-inline void add_sep (GtkWidget *table, gint y)
+inline void add_sep (GtkWidget *grid, gint y)
 {
-    gtk_table_attach (GTK_TABLE (table), create_hsep (table), 0, 2, y, y+1, GTK_FILL, GTK_FILL, 0, 0);
+    gtk_grid_attach (GTK_GRID (grid), create_hsep (grid), 0, y, 2, 1);
 }
 
 
-static void add_tag (GtkWidget *dialog, GtkWidget *table, gint &y, GnomeCmdFileMetadata &metadata, GnomeCmdTag tag, const gchar *appended_text=nullptr)
+static void add_tag (GtkWidget *dialog, GtkWidget *grid, gint &y, GnomeCmdFileMetadata &metadata, GnomeCmdTag tag, const gchar *appended_text=nullptr)
 {
     if (!metadata.has_tag (tag))
         return;
@@ -285,7 +285,7 @@ static void add_tag (GtkWidget *dialog, GtkWidget *table, gint &y, GnomeCmdFileM
     title += ':';
 
     label = create_bold_label (dialog, title.c_str());
-    table_add (table, label, 0, y, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
     string value = truncate (metadata[tag],120);
 
@@ -293,11 +293,11 @@ static void add_tag (GtkWidget *dialog, GtkWidget *table, gint &y, GnomeCmdFileM
         value += appended_text;
 
     label = create_label (dialog, value.c_str());
-    table_add (table, label, 1, y++, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 1, y++, 1, 1);
 }
 
 
-inline void add_width_height_tag (GtkWidget *dialog, GtkWidget *table, gint &y, GnomeCmdFileMetadata &metadata)
+inline void add_width_height_tag (GtkWidget *dialog, GtkWidget *grid, gint &y, GnomeCmdFileMetadata &metadata)
 {
     if (!metadata.has_tag (TAG_IMAGE_WIDTH) || !metadata.has_tag (TAG_IMAGE_HEIGHT))
         return;
@@ -305,14 +305,14 @@ inline void add_width_height_tag (GtkWidget *dialog, GtkWidget *table, gint &y,
     GtkWidget *label;
 
     label = create_bold_label (dialog, _("Image:"));
-    table_add (table, label, 0, y, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
     string value = metadata[TAG_IMAGE_WIDTH];
     value += " x ";
     value += metadata[TAG_IMAGE_HEIGHT];
 
     label = create_label (dialog, value.c_str());
-    table_add (table, label, 1, y++, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 1, y++, 1, 1);
 }
 
 
@@ -320,31 +320,33 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
 {
     gint y = 0;
     GtkWidget *dialog = data->dialog;
-    GtkWidget *table;
+    GtkWidget *grid;
     GtkWidget *label;
 
-    GtkWidget *space_frame = create_space_frame (dialog, 6);
-
-    table = create_table (dialog, 6, 3);
-    gtk_container_add (GTK_CONTAINER (space_frame), table);
+    grid = create_grid (dialog);
+    gtk_widget_set_margin_top (grid, 6);
+    gtk_widget_set_margin_bottom (grid, 6);
+    gtk_widget_set_margin_start (grid, 6);
+    gtk_widget_set_margin_end (grid, 6);
 
     label = create_bold_label (dialog, GNOME_CMD_IS_DIR (data->f) ? _("Directory name:") : _("File name:"));
-    table_add (table, label, 0, y, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
-    data->filename_entry = create_entry (dialog, "filename_entry", g_file_info_get_edit_name (data->f->gFileInfo));
-    table_add (table, data->filename_entry, 1, y++, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND));
+    data->filename_entry = create_entry (dialog, "filename_entry", g_file_info_get_edit_name (data->f->get_file_info()));
+    gtk_widget_set_hexpand (data->filename_entry, TRUE);
+    gtk_grid_attach (GTK_GRID (grid), data->filename_entry, 1, y++, 1, 1);
     gtk_editable_set_position (GTK_EDITABLE (data->filename_entry), 0);
 
-    if (g_file_info_get_is_symlink(data->f->gFileInfo))
+    if (g_file_info_get_is_symlink(data->f->get_file_info()))
     {
         label = create_bold_label (dialog, _("Symlink target:"));
-        table_add (table, label, 0, y, GTK_FILL);
+        gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
-        label = create_label (dialog, g_file_info_get_symlink_target (data->f->gFileInfo));
-        table_add (table, label, 1, y++, GTK_FILL);
+        label = create_label (dialog, g_file_info_get_symlink_target (data->f->get_file_info()));
+        gtk_grid_attach (GTK_GRID (grid), label, 1, y++, 1, 1);
     }
 
-    add_sep (table, y++);
+    add_sep (grid, y++);
 
     if (data->f->is_local())
     {
@@ -353,15 +355,15 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
         gchar *location = data->f->get_dirname();
 
         label = create_bold_label (dialog, _("Location:"));
-        table_add (table, label, 0, y, GTK_FILL);
+        gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
         label = create_label (dialog, location);
-        table_add (table, label, 1, y++, GTK_FILL);
+        gtk_grid_attach (GTK_GRID (grid), label, 1, y++, 1, 1);
 
         g_free (location);
 
         label = create_bold_label (dialog, _("Volume:"));
-        table_add (table, label, 0, y, GTK_FILL);
+        gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
         if (GNOME_CMD_IS_CON_DEVICE (con))
         {
@@ -383,29 +385,29 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
         else
             label = create_label (dialog, gnome_cmd_con_get_alias (con));
 
-        table_add (table, label, 1, y++, GTK_FILL);
+        gtk_grid_attach (GTK_GRID (grid), label, 1, y++, 1, 1);
 
         if (dir && gnome_cmd_con_can_show_free_space (con))
             if (gchar *free_space = gnome_cmd_dir_get_free_space (dir))
             {
                 label = create_bold_label (dialog, _("Free space:"));
-                table_add (table, label, 0, y, GTK_FILL);
+                gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
                 label = create_label (dialog, free_space);
-                table_add (table, label, 1, y++, GTK_FILL);
+                gtk_grid_attach (GTK_GRID (grid), label, 1, y++, 1, 1);
 
                 g_free (free_space);
             }
 
-        add_sep (table, y++);
+        add_sep (grid, y++);
     }
 
     label = create_bold_label (dialog, _("Content Type:"));
-    table_add (table, label, 0, y, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
     auto contentTypeString = data->f->GetGfileAttributeString(G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
     label = create_label (dialog, contentTypeString);
-    table_add (table, label, 1, y++, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 1, y++, 1, 1);
     g_free(contentTypeString);
 
     if (data->f->GetGfileAttributeUInt32(G_FILE_ATTRIBUTE_STANDARD_TYPE) != G_FILE_TYPE_DIRECTORY)
@@ -413,7 +415,7 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
         GtkWidget *hbox;
 
         label = create_bold_label (dialog, _("Opens with:"));
-        table_add (table, label, 0, y, GTK_FILL);
+        gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
         auto default_application_string = data->f->GetDefaultApplicationNameString();
 
@@ -426,37 +428,37 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
             label = create_label (dialog, _("No default application registered"));
 
         hbox = create_hbox (dialog, FALSE, 6);
-        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
+        gtk_box_append (GTK_BOX (hbox), label);
         label = create_label (dialog, " ");
-        gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-        table_add (table, hbox, 1, y++, GTK_FILL);
+        gtk_box_append (GTK_BOX (hbox), label);
+        gtk_grid_attach (GTK_GRID (grid), hbox, 1, y++, 1, 1);
     }
 
-    add_sep (table, y++);
+    add_sep (grid, y++);
 
     label = create_bold_label (dialog, _("Modified:"));
-    table_add (table, label, 0, y, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
     label = create_label (dialog, data->f->get_mdate(TRUE));
-    table_add (table, label, 1, y++, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 1, y++, 1, 1);
 
 #ifdef GLIB_2_70
     label = create_bold_label (dialog, _("Accessed:"));
-    table_add (table, label, 0, y, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
     label = create_label (dialog, data->f->get_adate(TRUE));
-    table_add (table, label, 1, y++, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 1, y++, 1, 1);
 #endif
 
-    add_sep (table, y++);
+    add_sep (grid, y++);
 
 
     label = create_bold_label (dialog, _("Size:"));
-    table_add (table, label, 0, y, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, y, 1, 1);
 
-    gchar *s = create_nice_size_str (g_file_info_get_size (data->f->gFileInfo));
+    gchar *s = create_nice_size_str (g_file_info_get_size (data->f->get_file_info()));
     label = create_label (dialog, s);
-    table_add (table, label, 1, y++, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (grid), label, 1, y++, 1, 1);
     g_free (s);
     if (data->f->GetGfileAttributeUInt32(G_FILE_ATTRIBUTE_STANDARD_TYPE) == G_FILE_TYPE_DIRECTORY)
         do_calc_tree_size (data);
@@ -468,18 +470,18 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
 
     if (data->f->metadata)
     {
-        add_tag (dialog, table, y, *data->f->metadata, TAG_FILE_DESCRIPTION);
-        add_tag (dialog, table, y, *data->f->metadata, TAG_FILE_PUBLISHER);
-        add_tag (dialog, table, y, *data->f->metadata, TAG_DOC_TITLE);
-        add_tag (dialog, table, y, *data->f->metadata, TAG_DOC_PAGECOUNT);
-        add_width_height_tag (dialog, table, y, *data->f->metadata);
-        add_tag (dialog, table, y, *data->f->metadata, TAG_AUDIO_ALBUMARTIST);
-        add_tag (dialog, table, y, *data->f->metadata, TAG_AUDIO_TITLE);
-        add_tag (dialog, table, y, *data->f->metadata, TAG_AUDIO_BITRATE, " kbps");
-        add_tag (dialog, table, y, *data->f->metadata, TAG_AUDIO_DURATIONMMSS);
+        add_tag (dialog, grid, y, *data->f->metadata, TAG_FILE_DESCRIPTION);
+        add_tag (dialog, grid, y, *data->f->metadata, TAG_FILE_PUBLISHER);
+        add_tag (dialog, grid, y, *data->f->metadata, TAG_DOC_TITLE);
+        add_tag (dialog, grid, y, *data->f->metadata, TAG_DOC_PAGECOUNT);
+        add_width_height_tag (dialog, grid, y, *data->f->metadata);
+        add_tag (dialog, grid, y, *data->f->metadata, TAG_AUDIO_ALBUMARTIST);
+        add_tag (dialog, grid, y, *data->f->metadata, TAG_AUDIO_TITLE);
+        add_tag (dialog, grid, y, *data->f->metadata, TAG_AUDIO_BITRATE, " kbps");
+        add_tag (dialog, grid, y, *data->f->metadata, TAG_AUDIO_DURATIONMMSS);
     }
 
-    return space_frame;
+    return grid;
 }
 
 
@@ -487,32 +489,30 @@ inline GtkWidget *create_permissions_tab (GnomeCmdFilePropsDialogPrivate *data)
 {
     GtkWidget *vbox = create_vbox (data->dialog, FALSE, 6);
 
-    GtkWidget *space_frame = create_space_frame (data->dialog, 6);
-    gtk_container_add (GTK_CONTAINER (space_frame), vbox);
+    gtk_widget_set_margin_top (vbox, 6);
+    gtk_widget_set_margin_bottom (vbox, 6);
+    gtk_widget_set_margin_start (vbox, 6);
+    gtk_widget_set_margin_end (vbox, 6);
 
     data->chown_component = gnome_cmd_chown_component_new ();
-    g_object_ref (data->chown_component);
-    g_object_set_data_full (G_OBJECT (data->dialog), "chown_component", data->chown_component, g_object_unref);
     gtk_widget_show (data->chown_component);
     gnome_cmd_chown_component_set (GNOME_CMD_CHOWN_COMPONENT (data->chown_component),
-        get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_UID),
-        get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_GID));
+        get_gfile_attribute_uint32(data->f->get_file(), G_FILE_ATTRIBUTE_UNIX_UID),
+        get_gfile_attribute_uint32(data->f->get_file(), G_FILE_ATTRIBUTE_UNIX_GID));
 
     GtkWidget *cat = create_category (data->dialog, data->chown_component, _("Owner and group"));
-    gtk_box_pack_start (GTK_BOX (vbox), cat, TRUE, TRUE, 0);
+    gtk_box_append (GTK_BOX (vbox), cat);
 
 
     data->chmod_component = gnome_cmd_chmod_component_new (0);
-    g_object_ref (data->chmod_component);
-    g_object_set_data_full (G_OBJECT (data->dialog), "chmod_component", data->chmod_component, g_object_unref);
     gtk_widget_show (data->chmod_component);
     gnome_cmd_chmod_component_set_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component),
-        get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_MODE) & 0xFFF);
+        get_gfile_attribute_uint32(data->f->get_file(), G_FILE_ATTRIBUTE_UNIX_MODE) & 0xFFF);
 
     cat = create_category (data->dialog, data->chmod_component, _("Access permissions"));
-    gtk_box_pack_start (GTK_BOX (vbox), cat, TRUE, TRUE, 0);
+    gtk_box_append (GTK_BOX (vbox), cat);
 
-    return space_frame;
+    return vbox;
 }
 
 
@@ -631,38 +631,30 @@ static GtkWidget *create_view_and_model (GnomeCmdFile *f)
 
 inline GtkWidget *create_metadata_tab (GnomeCmdFilePropsDialogPrivate *data)
 {
-    GtkWidget *vbox = create_vbox (data->dialog, FALSE, 1);
-
-    GtkWidget *space_frame = create_space_frame (data->dialog, 1);
-    gtk_container_add (GTK_CONTAINER (space_frame), vbox);
-
-    GtkWidget *scrolledwindow = gtk_scrolled_window_new (nullptr, nullptr);
+    GtkWidget *scrolledwindow = gtk_scrolled_window_new ();
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-    gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow), 10);
-
-    gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (scrolledwindow), TRUE, TRUE, 0);
 
     GtkWidget *view = create_view_and_model (data->f);
 
-    gtk_container_add (GTK_CONTAINER (scrolledwindow), view);
+    gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (scrolledwindow), view);
 
-    gtk_widget_show_all (vbox);
+    gtk_widget_show_all (scrolledwindow);
 
-    return space_frame;
+    return scrolledwindow;
 }
 
 
-GtkWidget *gnome_cmd_file_props_dialog_create (GnomeCmdFile *f)
+GtkWidget *gnome_cmd_file_props_dialog_create (GtkWindow *parent_window, GnomeCmdFile *f)
 {
     g_return_val_if_fail (f != nullptr, nullptr);
-    g_return_val_if_fail (f->gFileInfo != nullptr, nullptr);
+    g_return_val_if_fail (f->get_file_info() != nullptr, nullptr);
 
     if (f->is_dotdot)
         return nullptr;
 
     GnomeCmdFilePropsDialogPrivate *data = g_new0 (GnomeCmdFilePropsDialogPrivate, 1);
 
-    GtkWidget *dialog = gnome_cmd_dialog_new (_("File Properties"));
+    GtkWidget *dialog = gnome_cmd_dialog_new (parent_window, _("File Properties"));
     g_signal_connect (dialog, "destroy", G_CALLBACK (on_dialog_destroy), data);
     gtk_window_set_resizable(GTK_WINDOW (dialog), TRUE);
 
@@ -674,27 +666,21 @@ GtkWidget *gnome_cmd_file_props_dialog_create (GnomeCmdFile *f)
     data->notebook = notebook;
     f->ref();
 
-    g_object_ref (notebook);
-    g_object_set_data_full (G_OBJECT (dialog), "notebook", notebook, g_object_unref);
     gtk_widget_show (notebook);
     gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), notebook);
 
-    gtk_container_add (GTK_CONTAINER (notebook), create_properties_tab (data));
-    gtk_container_add (GTK_CONTAINER (notebook), create_permissions_tab (data));
-    gtk_container_add (GTK_CONTAINER (notebook), create_metadata_tab (data));
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), create_properties_tab (data), gtk_label_new (_("Properties")));
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), create_permissions_tab (data), gtk_label_new (_("Permissions")));
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), create_metadata_tab (data), gtk_label_new (_("Metadata")));
 
-    gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 0), gtk_label_new (_("Properties")));
-    gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 1), gtk_label_new (_("Permissions")));
-    gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 2), gtk_label_new (_("Metadata")));
-
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_HELP, GTK_SIGNAL_FUNC (on_dialog_help), data);
-    data->copy_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_COPY, GTK_SIGNAL_FUNC (on_copy_clipboard), data);
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_SIGNAL_FUNC (on_dialog_cancel), data);
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK, GTK_SIGNAL_FUNC (on_dialog_ok), data);
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_Help"), G_CALLBACK (on_dialog_help), data);
+    data->copy_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("Co_py"), G_CALLBACK (on_copy_clipboard), data);
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_Cancel"), G_CALLBACK (on_dialog_cancel), data);
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_OK"), G_CALLBACK (on_dialog_ok), data);
 
     gtk_widget_set_sensitive (data->copy_button, gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook))==2);
 
-    g_signal_connect (GTK_OBJECT (notebook), "switch-page", GTK_SIGNAL_FUNC (on_notebook_page_change), data);
+    g_signal_connect (G_OBJECT (notebook), "switch-page", G_CALLBACK (on_notebook_page_change), data);
 
     return dialog;
 }
