@@ -39,6 +39,9 @@ using namespace std;
 #define GNOME_CMD_IS_KEY_SHORTCUTS_DIALOG(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_CMD_TYPE_KEY_SHORTCUTS_DIALOG)
 
 
+GType gnome_cmd_key_shortcuts_dialog_get_type ();
+
+
 GtkTreeViewColumn *create_new_accel_column (GtkTreeView *view, GtkCellRenderer *&renderer, gint COL_KEYS_ID, gint COL_MODS_ID, const gchar *title);
 GtkTreeViewColumn *create_new_combo_column (GtkTreeView *view, GtkTreeModel *model, GtkCellRenderer *&renderer, gint COL_ID, const gchar *title);
 gboolean conflict_confirm (GtkWidget *view, const gchar *action, guint accel_key, GdkModifierType accel_mask);
@@ -76,14 +79,8 @@ GnomeCmdKeyShortcutsDialogPrivate::GnomeCmdKeyShortcutsDialogPrivate()
 GnomeCmdUserActions *GnomeCmdKeyShortcutsDialog::user_actions = NULL;
 
 
-#if defined (__GNUC__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wmissing-declarations"
-#endif
 G_DEFINE_TYPE (GnomeCmdKeyShortcutsDialog, gnome_cmd_key_shortcuts_dialog, GTK_TYPE_DIALOG)
-#if defined (__GNUC__)
-#pragma GCC diagnostic pop
-#endif
+
 
 static void gnome_cmd_key_shortcuts_dialog_finalize (GObject *object)
 {
@@ -141,21 +138,21 @@ static void response_callback (GnomeCmdKeyShortcutsDialog *dialog, int response_
                     g_free (options);
                 }
 
-                dialog->user_actions->unregister(GDK_F3);
-                dialog->user_actions->unregister(GDK_F4);
-                dialog->user_actions->unregister(GDK_F5);
-                dialog->user_actions->unregister(GDK_F6);
-                dialog->user_actions->unregister(GDK_F7);
-                dialog->user_actions->unregister(GDK_F8);
-                dialog->user_actions->unregister(GDK_F9);
+                dialog->user_actions->unregister(GDK_KEY_F3);
+                dialog->user_actions->unregister(GDK_KEY_F4);
+                dialog->user_actions->unregister(GDK_KEY_F5);
+                dialog->user_actions->unregister(GDK_KEY_F6);
+                dialog->user_actions->unregister(GDK_KEY_F7);
+                dialog->user_actions->unregister(GDK_KEY_F8);
+                dialog->user_actions->unregister(GDK_KEY_F9);
 
-                dialog->user_actions->register_action(GDK_F3, "file.view");
-                dialog->user_actions->register_action(GDK_F4, "file.edit");
-                dialog->user_actions->register_action(GDK_F5, "file.copy");
-                dialog->user_actions->register_action(GDK_F6, "file.rename");
-                dialog->user_actions->register_action(GDK_F7, "file.mkdir");
-                dialog->user_actions->register_action(GDK_F8, "file.delete");
-                dialog->user_actions->register_action(GDK_F9, "edit.search");
+                dialog->user_actions->register_action(GDK_KEY_F3, "file.view");
+                dialog->user_actions->register_action(GDK_KEY_F4, "file.edit");
+                dialog->user_actions->register_action(GDK_KEY_F5, "file.copy");
+                dialog->user_actions->register_action(GDK_KEY_F6, "file.rename");
+                dialog->user_actions->register_action(GDK_KEY_F7, "file.mkdir");
+                dialog->user_actions->register_action(GDK_KEY_F8, "file.delete");
+                dialog->user_actions->register_action(GDK_KEY_F9, "edit.search");
             }
 
             break;
@@ -199,56 +196,64 @@ static void gnome_cmd_key_shortcuts_dialog_init (GnomeCmdKeyShortcutsDialog *dia
 
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
     gtk_window_set_title (GTK_WINDOW (dialog), _("Keyboard Shortcuts"));
-    gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-    gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
+
+    GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
+    gtk_widget_set_margin_top (content_area, 10);
+    gtk_widget_set_margin_bottom (content_area, 10);
+    gtk_widget_set_margin_start (content_area, 10);
+    gtk_widget_set_margin_end (content_area, 10);
+    gtk_box_set_spacing (GTK_BOX (content_area), 6);
+
     gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 
-    GtkWidget *vbox = gtk_vbox_new (FALSE, 12);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
-    gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), vbox);
+    GtkWidget *vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
+    gtk_widget_set_vexpand (vbox, TRUE);
+    gtk_box_append (GTK_BOX (content_area), vbox);
     gtk_widget_show (vbox);
 
-    GtkWidget *hbox = gtk_hbox_new (FALSE, 12);
-    gtk_container_add (GTK_CONTAINER (vbox), hbox);
+    GtkWidget *hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+    gtk_widget_set_vexpand (hbox, TRUE);
+    gtk_box_append (GTK_BOX (vbox), hbox);
     gtk_widget_show (hbox);
 
-    GtkWidget *scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+    GtkWidget *scrolled_window = gtk_scrolled_window_new ();
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window), GTK_SHADOW_IN);
-    gtk_box_pack_start (GTK_BOX (hbox), scrolled_window, TRUE, TRUE, 0);
+    gtk_scrolled_window_set_has_frame (GTK_SCROLLED_WINDOW (scrolled_window), TRUE);
+    gtk_widget_set_hexpand (scrolled_window, TRUE);
+    gtk_box_append (GTK_BOX (hbox), scrolled_window);
     gtk_widget_show (scrolled_window);
 
     GtkWidget *view = create_view_and_model (*dialog->user_actions);
     gtk_widget_set_size_request (view, 600, 400);
-    gtk_container_add (GTK_CONTAINER (scrolled_window), view);
+    gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (scrolled_window), view);
     gtk_widget_show (view);
 
     GtkWidget *box = gnome_cmd_hint_box_new (_("To edit a shortcut key, click on the "
                                                "corresponding row and type a new "
                                                "accelerator, or press escape to "
                                                "cancel."));
-    gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (vbox), box);
     gtk_widget_show (box);
 
-    vbox = gtk_vbox_new (FALSE, 12);
-    gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
+    gtk_box_append (GTK_BOX (hbox), vbox);
     gtk_widget_show (vbox);
 
-    GtkWidget *button = gtk_button_new_from_stock (GTK_STOCK_ADD);
+    GtkWidget *button = gtk_button_new_with_mnemonic (_("_Add"));
     g_signal_connect (button, "clicked", G_CALLBACK (add_clicked_callback), view);
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (vbox), button);
     gtk_widget_show (button);
 
-    button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
+    button = gtk_button_new_with_mnemonic (_("_Remove"));
     g_signal_connect (button, "clicked", G_CALLBACK (remove_clicked_callback), view);
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (vbox), button);
     gtk_widget_show (button);
 
     gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                            GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            _("_Help"), GTK_RESPONSE_HELP,
+                            _("_Cancel"), GTK_RESPONSE_CANCEL,
+                            _("_OK"), GTK_RESPONSE_OK,
                             NULL);
 
     gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
@@ -263,13 +268,13 @@ gboolean gnome_cmd_key_shortcuts_dialog_new (GnomeCmdUserActions &user_actions)
 {
     GnomeCmdKeyShortcutsDialog::user_actions = &user_actions;        // ugly hack, but can't come to any better method of passing data to gnome_cmd_key_shortcuts_dialog_init ()
 
-    GtkWidget *dialog = gtk_widget_new (GNOME_CMD_TYPE_KEY_SHORTCUTS_DIALOG, NULL);
+    GtkWidget *dialog = GTK_WIDGET (g_object_new (GNOME_CMD_TYPE_KEY_SHORTCUTS_DIALOG, NULL));
 
     g_return_val_if_fail (dialog != NULL, FALSE);
 
     gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
-    gtk_widget_destroy (dialog);
+    gtk_window_destroy (GTK_WINDOW (dialog));
 
     return result==GTK_RESPONSE_OK;
 }
@@ -496,7 +501,7 @@ gboolean conflict_confirm (GtkWidget *view, const gchar *action, guint accel_key
                                              GTK_BUTTONS_NONE,
                                              _("Shortcut “%s” is already taken by “%s”."),
                                              accel_string, action);
-    gtk_dialog_add_buttons (GTK_DIALOG (dlg), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+    gtk_dialog_add_buttons (GTK_DIALOG (dlg), _("_Cancel"), GTK_RESPONSE_CANCEL,
                                               _("_Reassign shortcut"), GTK_RESPONSE_OK,
                                               NULL);
     gtk_dialog_set_default_response (GTK_DIALOG (dlg), GTK_RESPONSE_CANCEL);
@@ -506,7 +511,7 @@ gboolean conflict_confirm (GtkWidget *view, const gchar *action, guint accel_key
     gtk_widget_show_all (dlg);
     gint response = gtk_dialog_run (GTK_DIALOG (dlg));
 
-    gtk_widget_destroy (dlg);
+    gtk_window_destroy (GTK_WINDOW (dlg));
 
     g_free (accel_string);
 
