@@ -36,7 +36,7 @@ struct GnomeCmdMakeCopyDialogPrivate
 };
 
 
-static GnomeCmdStringDialogClass *parent_class = NULL;
+G_DEFINE_TYPE_WITH_PRIVATE (GnomeCmdMakeCopyDialog, gnome_cmd_make_copy_dialog, GNOME_CMD_TYPE_STRING_DIALOG)
 
 
 inline void copy_file (GnomeCmdFile *f, GnomeCmdDir *dir, const gchar *filename)
@@ -57,8 +57,8 @@ inline void copy_file (GnomeCmdFile *f, GnomeCmdDir *dir, const gchar *filename)
 static gboolean on_ok (GnomeCmdStringDialog *string_dialog, const gchar **values, GnomeCmdMakeCopyDialog *dialog)
 {
     g_return_val_if_fail (dialog, TRUE);
-    g_return_val_if_fail (dialog->priv, TRUE);
-    g_return_val_if_fail (dialog->priv->f, TRUE);
+    auto priv = static_cast<GnomeCmdMakeCopyDialogPrivate*>(gnome_cmd_make_copy_dialog_get_instance_private (dialog));
+    g_return_val_if_fail (priv->f, TRUE);
 
     const gchar *filename = values[0];
 
@@ -73,17 +73,17 @@ static gboolean on_ok (GnomeCmdStringDialog *string_dialog, const gchar **values
         gchar *parent_dir = g_path_get_dirname (filename);
         gchar *dest_fn = g_path_get_basename (filename);
 
-        auto con = gnome_cmd_dir_get_connection (dialog->priv->dir);
+        auto con = gnome_cmd_dir_get_connection (priv->dir);
         auto conPath = gnome_cmd_con_create_path (con, parent_dir);
         auto dir = gnome_cmd_dir_new (con, conPath);
         delete conPath;
         g_free (parent_dir);
 
-        copy_file (dialog->priv->f, dir, dest_fn);
+        copy_file (priv->f, dir, dest_fn);
         g_free (dest_fn);
     }
     else
-        copy_file (dialog->priv->f, dialog->priv->dir, filename);
+        copy_file (priv->f, priv->dir, filename);
 
     return TRUE;
 }
@@ -91,7 +91,8 @@ static gboolean on_ok (GnomeCmdStringDialog *string_dialog, const gchar **values
 
 static void on_cancel (GtkWidget *widget, GnomeCmdMakeCopyDialog *dialog)
 {
-    dialog->priv->f->unref();
+    auto priv = static_cast<GnomeCmdMakeCopyDialogPrivate*>(gnome_cmd_make_copy_dialog_get_instance_private (dialog));
+    priv->f->unref();
 }
 
 
@@ -99,38 +100,13 @@ static void on_cancel (GtkWidget *widget, GnomeCmdMakeCopyDialog *dialog)
  * Gtk class implementation
  *******************************/
 
-static void destroy (GtkObject *object)
+static void gnome_cmd_make_copy_dialog_class_init (GnomeCmdMakeCopyDialogClass *klass)
 {
-    GnomeCmdMakeCopyDialog *dialog = GNOME_CMD_MAKE_COPY_DIALOG (object);
-
-    g_free (dialog->priv);
-
-    if (GTK_OBJECT_CLASS (parent_class)->destroy)
-        (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
 
-static void map (GtkWidget *widget)
+static void gnome_cmd_make_copy_dialog_init (GnomeCmdMakeCopyDialog *dialog)
 {
-    if (GTK_WIDGET_CLASS (parent_class)->map != NULL)
-        GTK_WIDGET_CLASS (parent_class)->map (widget);
-}
-
-
-static void class_init (GnomeCmdMakeCopyDialogClass *klass)
-{
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-
-    parent_class = (GnomeCmdStringDialogClass *) gtk_type_class (GNOME_CMD_TYPE_STRING_DIALOG);
-    object_class->destroy = destroy;
-    widget_class->map = ::map;
-}
-
-
-static void init (GnomeCmdMakeCopyDialog *dialog)
-{
-    dialog->priv = g_new0 (GnomeCmdMakeCopyDialogPrivate, 1);
 }
 
 
@@ -145,9 +121,10 @@ GtkWidget *gnome_cmd_make_copy_dialog_new (GnomeCmdFile *f, GnomeCmdDir *dir)
     const gchar *labels[] = {""};
 
     GnomeCmdMakeCopyDialog *dialog = (GnomeCmdMakeCopyDialog *) g_object_new (GNOME_CMD_TYPE_MAKE_COPY_DIALOG, NULL);
+    auto priv = static_cast<GnomeCmdMakeCopyDialogPrivate*>(gnome_cmd_make_copy_dialog_get_instance_private (dialog));
 
-    dialog->priv->f = f->ref();
-    dialog->priv->dir = gnome_cmd_dir_ref (dir);
+    priv->f = f->ref();
+    priv->dir = gnome_cmd_dir_ref (dir);
 
     gchar *msg = g_strdup_printf (_("Copy “%s” to"), f->get_name());
     GtkWidget *msg_label = create_label (GTK_WIDGET (dialog), msg);
@@ -160,34 +137,11 @@ GtkWidget *gnome_cmd_make_copy_dialog_new (GnomeCmdFile *f, GnomeCmdDir *dir)
                                                labels,
                                                1,
                                                (GnomeCmdStringDialogCallback) on_ok,
-                                               GTK_SIGNAL_FUNC (on_cancel),
+                                               (GnomeCmdCallback<GtkButton*>) on_cancel,
                                                dialog);
 
-    gnome_cmd_string_dialog_set_value (GNOME_CMD_STRING_DIALOG (dialog), 0, g_file_info_get_display_name(f->gFileInfo));
+    gnome_cmd_string_dialog_set_value (GNOME_CMD_STRING_DIALOG (dialog), 0, g_file_info_get_display_name(f->get_file_info()));
 
     return GTK_WIDGET (dialog);
 }
 
-
-GtkType gnome_cmd_make_copy_dialog_get_type ()
-{
-    static GtkType dlg_type = 0;
-
-    if (dlg_type == 0)
-    {
-        GtkTypeInfo dlg_info =
-        {
-            (gchar*) "GnomeCmdMakeCopyDialog",
-            sizeof (GnomeCmdMakeCopyDialog),
-            sizeof (GnomeCmdMakeCopyDialogClass),
-            (GtkClassInitFunc) class_init,
-            (GtkObjectInitFunc) init,
-            /* reserved_1 */ NULL,
-            /* reserved_2 */ NULL,
-            (GtkClassInitFunc) NULL
-        };
-
-        dlg_type = gtk_type_unique (GNOME_CMD_TYPE_STRING_DIALOG, &dlg_info);
-    }
-    return dlg_type;
-}
