@@ -31,7 +31,6 @@
 #include "gnome-cmd-edit-bookmark-dialog.h"
 #include "gnome-cmd-treeview.h"
 #include "gnome-cmd-user-actions.h"
-#include "gnome-cmd-menu-button.h"
 #include "gnome-cmd-hintbox.h"
 #include "eggcellrendererkeys.h"
 #include "utils.h"
@@ -71,65 +70,65 @@ void gnome_cmd_bookmark_dialog_new (const gchar *title, GtkWindow *parent)
 {
     GtkWidget *dialog = gtk_dialog_new_with_buttons (title, parent,
                                                      GtkDialogFlags (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-                                                     GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-                                                     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-                                                     GTK_STOCK_JUMP_TO, RESPONSE_JUMP_TO,
+                                                     _("_Help"), GTK_RESPONSE_HELP,
+                                                     _("_Close"), GTK_RESPONSE_CLOSE,
+                                                     _("_Jump to"), RESPONSE_JUMP_TO,
                                                      NULL);
 
     GtkWidget *content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 
     GtkWidget *vbox, *hbox, *scrolled_window, *button;
 
-    gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-    gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-    gtk_box_set_spacing (GTK_BOX (content_area), 2);
     gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 
-    vbox = gtk_vbox_new (FALSE, 12);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
-   gtk_container_add (GTK_CONTAINER (content_area), vbox);
+    gtk_widget_set_margin_top (content_area, 10);
+    gtk_widget_set_margin_bottom (content_area, 10);
+    gtk_widget_set_margin_start (content_area, 10);
+    gtk_widget_set_margin_end (content_area, 10);
+    gtk_box_set_spacing (GTK_BOX (content_area), 12);
 
-    hbox = gtk_hbox_new (FALSE, 12);
-    gtk_container_add (GTK_CONTAINER (vbox), hbox);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+    gtk_widget_set_vexpand (hbox, TRUE);
+    gtk_box_append (GTK_BOX (content_area), hbox);
 
-    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+    scrolled_window = gtk_scrolled_window_new ();
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window), GTK_SHADOW_IN);
-    gtk_box_pack_start (GTK_BOX (hbox), scrolled_window, TRUE, TRUE, 0);
+    gtk_scrolled_window_set_has_frame (GTK_SCROLLED_WINDOW (scrolled_window), TRUE);
+    gtk_widget_set_hexpand (scrolled_window, TRUE);
+    gtk_box_append (GTK_BOX (hbox), scrolled_window);
 
     view = create_view_and_model ();
     gtk_window_set_default_size (GTK_WINDOW (dialog), gnome_cmd_data.bookmarks_defaults.width, gnome_cmd_data.bookmarks_defaults.height);
     gtk_widget_set_size_request (view, 400, 250);
     g_signal_connect (view, "cursor-changed", G_CALLBACK (cursor_changed_callback), dialog);
     g_signal_connect (view, "row-activated", G_CALLBACK (row_activated_callback), dialog);
-    gtk_container_add (GTK_CONTAINER (scrolled_window), view);
+    gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (scrolled_window), view);
 
-    vbox = gtk_vbox_new (FALSE, 12);
-    gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
+    gtk_box_append (GTK_BOX (hbox), vbox);
 
-    button = gtk_button_new_from_stock (GTK_STOCK_EDIT);
+    button = gtk_button_new_with_mnemonic (_("_Edit"));
     gtk_widget_set_sensitive (button, FALSE);
     g_signal_connect (button, "clicked", G_CALLBACK (edit_clicked_callback), view);
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (vbox), button);
     g_object_set_data (G_OBJECT (dialog), "edit-button", button);
 
-    button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
+    button = gtk_button_new_with_mnemonic (_("_Remove"));
     gtk_widget_set_sensitive (button, FALSE);
     g_signal_connect (button, "clicked", G_CALLBACK (remove_clicked_callback), view);
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (vbox), button);
     g_object_set_data (G_OBJECT (dialog), "remove-button", button);
 
-    button = gtk_button_new_from_stock (GTK_STOCK_GO_UP);
+    button = gtk_button_new_with_mnemonic (_("_Up"));
     gtk_widget_set_sensitive (button, FALSE);
     g_signal_connect (button, "clicked", G_CALLBACK (up_clicked_callback), view);
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (vbox), button);
     g_object_set_data (G_OBJECT (dialog), "up-button", button);
 
-    button = gtk_button_new_from_stock (GTK_STOCK_GO_DOWN);
+    button = gtk_button_new_with_mnemonic (_("_Down"));
     gtk_widget_set_sensitive (button, FALSE);
     g_signal_connect (button, "clicked", G_CALLBACK (down_clicked_callback), view);
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (vbox), button);
     g_object_set_data (G_OBJECT (dialog), "down-button", button);
 
     gtk_widget_grab_focus (view);
@@ -144,7 +143,7 @@ void gnome_cmd_bookmark_dialog_new (const gchar *title, GtkWindow *parent)
 
     gtk_dialog_run (GTK_DIALOG (dialog));
 
-    gtk_widget_destroy (dialog);
+    gtk_window_destroy (GTK_WINDOW (dialog));
     view = NULL;
 }
 
