@@ -22,7 +22,6 @@
 #pragma once
 
 #include "gnome-cmd-data.h"
-#include "gnome-cmd-menu-button.h"
 #include "gnome-cmd-treeview.h"
 #include "gnome-cmd-edit-profile-dialog.h"
 #include "gnome-cmd-hintbox.h"
@@ -287,59 +286,59 @@ namespace GnomeCmd
 
         GtkWidget *dialog = gtk_dialog_new_with_buttons (title, parent,
                                                          GtkDialogFlags (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-                                                         GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-                                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                                         GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                                         _("_Help"), GTK_RESPONSE_HELP,
+                                                         _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                                         _("_OK"), GTK_RESPONSE_OK,
                                                          NULL);
 
         GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
         GtkWidget *vbox, *hbox, *scrolled_window, *view, *box, *button;
 
-        gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-        gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-        gtk_box_set_spacing (GTK_BOX (content_area), 2);
         gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 
-        vbox = gtk_vbox_new (FALSE, 12);
-        gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
-        gtk_container_add (GTK_CONTAINER (content_area), vbox);
+        gtk_widget_set_margin_top (content_area, 10);
+        gtk_widget_set_margin_bottom (content_area, 10);
+        gtk_widget_set_margin_start (content_area, 10);
+        gtk_widget_set_margin_end (content_area, 10);
+        gtk_box_set_spacing (GTK_BOX (content_area), 12);
 
-        hbox = gtk_hbox_new (FALSE, 12);
-        gtk_container_add (GTK_CONTAINER (vbox), hbox);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+        gtk_widget_set_hexpand (hbox, TRUE);
+        gtk_widget_set_vexpand (hbox, TRUE);
+        gtk_box_append (GTK_BOX (content_area), hbox);
 
-        scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+        scrolled_window = gtk_scrolled_window_new ();
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-        gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window), GTK_SHADOW_IN);
-        gtk_box_pack_start (GTK_BOX (hbox), scrolled_window, TRUE, TRUE, 0);
+        gtk_scrolled_window_set_has_frame (GTK_SCROLLED_WINDOW (scrolled_window), TRUE);
+        gtk_widget_set_hexpand (scrolled_window, TRUE);
+        gtk_widget_set_vexpand (scrolled_window, TRUE);
+        gtk_box_append (GTK_BOX (hbox), scrolled_window);
 
         view = create_view_and_model();
         gtk_widget_set_size_request (view, 400, 200);
         g_signal_connect (view, "row-activated", G_CALLBACK (row_activated_callback), NULL);
-        gtk_container_add (GTK_CONTAINER (scrolled_window), view);
+        gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (scrolled_window), view);
 
         box = gnome_cmd_hint_box_new (_("To rename a profile, click on the "
                                         "corresponding row and type a new "
                                         "name, or press escape to cancel."));
-        gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 0);
+        gtk_box_append (GTK_BOX (content_area), box);
 
-        vbox = gtk_vbox_new (FALSE, 12);
-        gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
+        gtk_box_append (GTK_BOX (hbox), vbox);
 
         button = gtk_button_new_with_mnemonic (_("_Duplicate"));
-        gtk_button_set_image (GTK_BUTTON (button),
-                              gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON));
         g_signal_connect (button, "clicked", G_CALLBACK (duplicate_clicked_callback), view);
-        gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+        gtk_box_append (GTK_BOX (vbox), button);
 
-        button = gtk_button_new_from_stock (GTK_STOCK_EDIT);
+        button = gtk_button_new_with_mnemonic (_("_Edit"));
         g_signal_connect (button, "clicked", G_CALLBACK (edit_clicked_callback), view);
-        gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+        gtk_box_append (GTK_BOX (vbox), button);
 
-        button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
+        button = gtk_button_new_with_mnemonic (_("_Remove"));
         g_signal_connect (button, "clicked", G_CALLBACK (remove_clicked_callback), view);
-        gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+        gtk_box_append (GTK_BOX (vbox), button);
 
         gtk_widget_show_all (content_area);
 
@@ -372,7 +371,7 @@ namespace GnomeCmd
             }
         }
 
-        gtk_widget_destroy (dialog);
+        gtk_window_destroy (GTK_WINDOW (dialog));
     }
 
     template <typename CONFIG, typename PROFILE, typename COMPONENT>
