@@ -97,7 +97,7 @@ static void response_callback (GtkDialog *dialog, int response_id, GnomeCmdDir *
 
         case GTK_RESPONSE_OK:
             {
-                const gchar *filename = gtk_entry_get_text (GTK_ENTRY (lookup_widget (GTK_WIDGET (dialog), "name")));
+                const gchar *filename = gtk_editable_get_text (GTK_EDITABLE (lookup_widget (GTK_WIDGET (dialog), "name")));
 
                 // don't create any directory if no name was passed or cancel was selected
                 if (!filename || *filename==0)
@@ -167,38 +167,39 @@ gboolean gnome_cmd_mkdir_dialog_new (GnomeCmdDir *dir, GnomeCmdFile *selected_fi
 {
     GtkWidget *dialog = gtk_dialog_new_with_buttons (_("Make Directory"), *main_win,
                                                      GtkDialogFlags (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-                                                     GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-                                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                                     GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                                     _("_Help"), GTK_RESPONSE_HELP,
+                                                     _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                                     _("_OK"), GTK_RESPONSE_OK,
                                                      NULL);
     GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
     gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-    gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
     // HIG defaults
-    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-    gtk_box_set_spacing (GTK_BOX (content_area), 2);
-    gtk_container_set_border_width (GTK_CONTAINER (content_area), 5);
-    gtk_box_set_spacing (GTK_BOX (content_area),6);
-    GtkWidget *table, *label, *entry;
+    gtk_widget_set_margin_top (content_area, 10);
+    gtk_widget_set_margin_bottom (content_area, 10);
+    gtk_widget_set_margin_start (content_area, 10);
+    gtk_widget_set_margin_end (content_area, 10);
+    gtk_box_set_spacing (GTK_BOX (content_area), 6);
 
-    table = gtk_table_new (3, 2, FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (table), 5);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-    gtk_container_add (GTK_CONTAINER (content_area), table);
+    GtkWidget *grid, *label, *entry;
+
+    grid = gtk_grid_new ();
+    gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
+    gtk_box_append (GTK_BOX (content_area), grid);
 
     label = gtk_label_new_with_mnemonic (_("Directory name:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
 
     entry = gtk_entry_new ();
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
     if (selected_file)
     {
         if (GNOME_CMD_IS_DIR (selected_file))
-            gtk_entry_set_text (GTK_ENTRY (entry), selected_file->get_name());
+            gtk_editable_set_text (GTK_EDITABLE (entry), selected_file->get_name());
         else
         {
             gchar *fname = g_strdup (selected_file->get_name());
@@ -208,14 +209,15 @@ gboolean gnome_cmd_mkdir_dialog_new (GnomeCmdDir *dir, GnomeCmdFile *selected_fi
             if (ext)
                 *ext = 0;
 
-            gtk_entry_set_text (GTK_ENTRY (entry), fname);
+            gtk_editable_set_text (GTK_EDITABLE (entry), fname);
 
             g_free (fname);
         }
     }
     g_object_set_data (G_OBJECT (dialog), "name", entry);
     gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-    gtk_table_attach_defaults (GTK_TABLE (table), entry, 1, 2, 0, 1);
+    gtk_widget_set_hexpand (entry, TRUE);
+    gtk_grid_attach (GTK_GRID (grid), entry, 1, 0, 1, 1);
 
     gtk_widget_show_all (content_area);
 
@@ -225,7 +227,7 @@ gboolean gnome_cmd_mkdir_dialog_new (GnomeCmdDir *dir, GnomeCmdFile *selected_fi
 
     gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
-    gtk_widget_destroy (dialog);
+    gtk_window_destroy (GTK_WINDOW (dialog));
 
     return result==GTK_RESPONSE_OK;
 }
