@@ -52,7 +52,7 @@ static void on_ok (GtkButton *button, GnomeCmdPatternselDialog *dialog)
     gboolean case_sens = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->case_check));
     gnome_cmd_data.search_defaults.default_profile.syntax = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (lookup_widget (GTK_WIDGET (dialog), "regex_radio"))) ? Filter::TYPE_REGEX : Filter::TYPE_FNMATCH;
 
-    const gchar *s = gtk_entry_get_text (GTK_ENTRY (dialog->priv->pattern_entry));
+    const gchar *s = gtk_editable_get_text (GTK_EDITABLE (dialog->priv->pattern_entry));
 
     Filter pattern(s, case_sens, gnome_cmd_data.search_defaults.default_profile.syntax);
 
@@ -94,8 +94,8 @@ static void gnome_cmd_patternsel_dialog_init (GnomeCmdPatternselDialog *dialog)
 
     dialog->priv = g_new0 (GnomeCmdPatternselDialogPrivate, 1);
 
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_SIGNAL_FUNC (on_cancel), dialog);
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK, GTK_SIGNAL_FUNC (on_ok), dialog);
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_Cancel"), G_CALLBACK(on_cancel), dialog);
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_OK"), G_CALLBACK(on_ok), dialog);
 
     vbox = create_vbox (GTK_WIDGET (dialog), FALSE, 6);
     hbox = create_hbox (GTK_WIDGET (dialog), FALSE, 6);
@@ -105,28 +105,29 @@ static void gnome_cmd_patternsel_dialog_init (GnomeCmdPatternselDialog *dialog)
         gtk_combo_box_text_append_text ((GtkComboBoxText*) dialog->priv->pattern_combo, (const gchar*) list->data);
     if (defaults.name_patterns.ents)
         gtk_combo_box_set_active ((GtkComboBox*) dialog->priv->pattern_combo, 0);
-    dialog->priv->pattern_entry = gtk_bin_get_child (GTK_BIN (dialog->priv->pattern_combo));
-    g_signal_connect_swapped (dialog->priv->pattern_entry, "activate", G_CALLBACK (gtk_window_activate_default), dialog);
+    dialog->priv->pattern_entry = gtk_combo_box_get_child (GTK_COMBO_BOX (dialog->priv->pattern_combo));
+    gtk_entry_set_activates_default (GTK_ENTRY (dialog->priv->pattern_entry), TRUE);
     gtk_editable_select_region (GTK_EDITABLE (dialog->priv->pattern_entry), 0, -1);
 
     label = create_label_with_mnemonic (GTK_WIDGET (dialog), _("_Pattern:"), dialog->priv->pattern_entry);
 
     dialog->priv->case_check = create_check_with_mnemonic (GTK_WIDGET (dialog), _("Case _sensitive"), "case_sens");
 
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), dialog->priv->pattern_combo, TRUE, TRUE, 0);
+    gtk_box_append (GTK_BOX (vbox), hbox);
+    gtk_box_append (GTK_BOX (hbox), label);
+    gtk_widget_set_hexpand (dialog->priv->pattern_combo, TRUE);
+    gtk_box_append (GTK_BOX (hbox), dialog->priv->pattern_combo);
 
     hbox = create_hbox (GTK_WIDGET (dialog), FALSE, 6);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (hbox), dialog->priv->case_check, TRUE, FALSE, 0);
+    gtk_box_append (GTK_BOX (vbox), hbox);
+    gtk_box_append (GTK_BOX (hbox), dialog->priv->case_check);
 
     radio = create_radio_with_mnemonic (GTK_WIDGET (dialog), NULL, _("She_ll syntax"), "shell_radio");
-    gtk_box_pack_end (GTK_BOX (hbox), radio, TRUE, FALSE, 0);
+    gtk_box_append (GTK_BOX (hbox), radio);
     if (gnome_cmd_data.search_defaults.default_profile.syntax == Filter::TYPE_FNMATCH)
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
     radio = create_radio_with_mnemonic (GTK_WIDGET (dialog), get_radio_group (radio), _("Rege_x syntax"), "regex_radio");
-    gtk_box_pack_end (GTK_BOX (hbox), radio, TRUE, FALSE, 0);
+    gtk_box_append (GTK_BOX (hbox), radio);
     if (gnome_cmd_data.search_defaults.default_profile.syntax == Filter::TYPE_REGEX)
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
 
