@@ -33,7 +33,7 @@
 using namespace std;
 
 
-static GnomeCmdDialogClass *parent_class = nullptr;
+G_DEFINE_TYPE (GnomeCmdPrepareXferDialog, gnome_cmd_prepare_xfer_dialog, GNOME_CMD_TYPE_DIALOG)
 
 
 inline gboolean con_device_has_path (FileSelectorID fsID, GnomeCmdCon *&dev, const gchar *user_path)
@@ -48,11 +48,11 @@ inline gboolean con_device_has_path (FileSelectorID fsID, GnomeCmdCon *&dev, con
 static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
 {
     GnomeCmdCon *con = gnome_cmd_dir_get_connection (dialog->default_dest_dir);
-    gchar *user_path = g_strstrip (g_strdup (gtk_entry_get_text (GTK_ENTRY (dialog->dest_dir_entry))));
+    gchar *user_path = g_strstrip (g_strdup (gtk_editable_get_text (GTK_EDITABLE (dialog->dest_dir_entry))));
 
     if (!user_path)
     {
-        gtk_widget_destroy (GTK_WIDGET (dialog));
+        gtk_window_destroy (GTK_WINDOW (dialog));
         return;
     }
 
@@ -153,7 +153,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                         // the parent dir was a file, abort!
                         g_free (parent_dir);
                         g_free (dest_path);
-                        gtk_widget_destroy (GTK_WIDGET (dialog));
+                        gtk_window_destroy (GTK_WINDOW (dialog));
                         return;
                     }
                     else
@@ -161,7 +161,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                         // Nothing exists, ask the user if a new directory might be suitable in the path that he specified
                         gchar *msg = g_strdup_printf (_("The directory “%s” doesn’t exist, do you want to create it?"),
                                                       g_path_get_basename (parent_dir));
-                        gint choice = run_simple_dialog (GTK_WIDGET (dialog), TRUE, GTK_MESSAGE_QUESTION, msg, "",
+                        gint choice = run_simple_dialog (GTK_WINDOW (dialog), TRUE, GTK_MESSAGE_QUESTION, msg, "",
                                                          -1, _("No"), _("Yes"), nullptr);
                         g_free (msg);
 
@@ -173,14 +173,14 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                                 gnome_cmd_show_message (*main_win, error ? error->message : _("Unknown error"));
                                 g_error_free(error);
                                 g_free (dest_path);
-                                gtk_widget_destroy (GTK_WIDGET (dialog));
+                                gtk_window_destroy (GTK_WINDOW (dialog));
                                 return;
                             }
                         }
                         else
                         {
                             g_free (dest_path);
-                            gtk_widget_destroy (GTK_WIDGET (dialog));
+                            gtk_window_destroy (GTK_WINDOW (dialog));
                             return;
                         }
 
@@ -202,7 +202,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
             {
                 // There exists something which is not a directory, abort!
                 g_free (dest_path);
-                gtk_widget_destroy (GTK_WIDGET (dialog));
+                gtk_window_destroy (GTK_WINDOW (dialog));
                 return;
             }
             else
@@ -217,7 +217,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                                                             "%s",
                                                             msg);
                 gint choice = gtk_dialog_run (GTK_DIALOG (dir_dialog));
-                gtk_widget_destroy (dir_dialog);
+                gtk_window_destroy (GTK_WINDOW (dir_dialog));
                 g_free (msg);
 
                 if (choice == GTK_RESPONSE_OK)
@@ -228,14 +228,14 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                         gnome_cmd_show_message (*main_win, error->message);
                         g_error_free(error);
                         g_free (dest_path);
-                        gtk_widget_destroy (GTK_WIDGET (dialog));
+                        gtk_window_destroy (GTK_WINDOW (dialog));
                         return;
                     }
                 }
                 else
                 {
                     g_free (dest_path);
-                    gtk_widget_destroy (GTK_WIDGET (dialog));
+                    gtk_window_destroy (GTK_WINDOW (dialog));
                     return;
                 }
                 dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, dest_path));
@@ -245,7 +245,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
     if (!GNOME_CMD_IS_DIR (dest_dir))
     {
         g_free (dest_path);
-        gtk_widget_destroy (GTK_WIDGET (dialog));
+        gtk_window_destroy (GTK_WINDOW (dialog));
         return;
     }
 
@@ -283,7 +283,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
     }
 
     g_free (dest_path);
-    gtk_widget_destroy (GTK_WIDGET (dialog));
+    gtk_window_destroy (GTK_WINDOW (dialog));
 }
 
 
@@ -291,21 +291,23 @@ static void on_cancel (GtkButton *button, gpointer user_data)
 {
     GnomeCmdPrepareXferDialog *dialog = GNOME_CMD_PREPARE_XFER_DIALOG (user_data);
 
-    gtk_widget_destroy (GTK_WIDGET (dialog));
+    gtk_window_destroy (GTK_WINDOW (dialog));
 }
 
 
-static gboolean on_dest_dir_entry_keypressed (GtkEntry *entry, GdkEventKey *event, GnomeCmdPrepareXferDialog *dialog)
+static gboolean on_dest_dir_entry_keypressed (GtkEventControllerKey *controller, guint keyval, guint keycode, GdkModifierType state, gpointer user_data)
 {
-    switch (event->keyval)
+    auto dialog = static_cast<GnomeCmdPrepareXferDialog*>(user_data);
+
+    switch (keyval)
     {
-        case GDK_Return:
-        case GDK_KP_Enter:
-            gtk_signal_emit_by_name (GTK_OBJECT (dialog->ok_button), "clicked", dialog, NULL);
+        case GDK_KEY_Return:
+        case GDK_KEY_KP_Enter:
+            g_signal_emit_by_name (dialog->ok_button, "clicked", dialog, NULL);
             return TRUE;
 
-        case GDK_F5:
-        case GDK_F6:
+        case GDK_KEY_F5:
+        case GDK_KEY_F6:
             gnome_cmd_toggle_file_name_selection (dialog->dest_dir_entry);
             return TRUE;
 
@@ -319,37 +321,23 @@ static gboolean on_dest_dir_entry_keypressed (GtkEntry *entry, GdkEventKey *even
  * Gtk class implementation
  *******************************/
 
-static void destroy (GtkObject *object)
+static void dispose (GObject *object)
 {
     GnomeCmdPrepareXferDialog *dialog = GNOME_CMD_PREPARE_XFER_DIALOG (object);
 
-    gnome_cmd_file_list_unref (dialog->src_files);
+    g_clear_pointer (&dialog->src_files, gnome_cmd_file_list_unref);
 
-    if (GTK_OBJECT_CLASS (parent_class)->destroy)
-        (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+    G_OBJECT_CLASS (gnome_cmd_prepare_xfer_dialog_parent_class)->dispose (object);
 }
 
 
-static void map (GtkWidget *widget)
+static void gnome_cmd_prepare_xfer_dialog_class_init (GnomeCmdPrepareXferDialogClass *klass)
 {
-    if (GTK_WIDGET_CLASS (parent_class)->map != NULL)
-        GTK_WIDGET_CLASS (parent_class)->map (widget);
+    G_OBJECT_CLASS (klass)->dispose = dispose;
 }
 
 
-static void class_init (GnomeCmdPrepareXferDialogClass *klass)
-{
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-
-    parent_class = (GnomeCmdDialogClass *) gtk_type_class (GNOME_CMD_TYPE_DIALOG);
-
-    object_class->destroy = destroy;
-    widget_class->map = ::map;
-}
-
-
-static void init (GnomeCmdPrepareXferDialog *dialog)
+static void gnome_cmd_prepare_xfer_dialog_init (GnomeCmdPrepareXferDialog *dialog)
 {
     GtkWidget *dest_dir_vbox, *dir_entry;
 
@@ -360,12 +348,14 @@ static void init (GnomeCmdPrepareXferDialog *dialog)
     gnome_cmd_dialog_add_category (GNOME_CMD_DIALOG (dialog), dialog->dest_dir_frame);
 
     dir_entry = gtk_entry_new ();
-    gtk_box_pack_start (GTK_BOX (dest_dir_vbox), dir_entry, TRUE, TRUE, 0);
+    gtk_widget_set_vexpand (dir_entry, TRUE);
+    gtk_box_append (GTK_BOX (dest_dir_vbox), dir_entry);
     dialog->dest_dir_entry = dir_entry;
 
     gtk_widget_show_all (dialog->dest_dir_entry);
 
-    g_signal_connect (dialog->dest_dir_entry, "key-press-event", G_CALLBACK (on_dest_dir_entry_keypressed), dialog);
+    GtkEventController *key_controller = gtk_event_controller_key_new (dialog->dest_dir_entry);
+    g_signal_connect (key_controller, "key-pressed", G_CALLBACK (on_dest_dir_entry_keypressed), dialog);
 
     // options
     GtkWidget *options_hbox = create_hbox (GTK_WIDGET (dialog), TRUE, 6);
@@ -375,14 +365,14 @@ static void init (GnomeCmdPrepareXferDialog *dialog)
     dialog->right_vbox = create_vbox (GTK_WIDGET (dialog), FALSE, 0);
 
     dialog->left_vbox_frame = create_category (GTK_WIDGET (dialog), dialog->left_vbox, "");
-    gtk_container_add (GTK_CONTAINER (options_hbox), dialog->left_vbox_frame);
+    gtk_box_append (GTK_BOX (options_hbox), dialog->left_vbox_frame);
 
     dialog->right_vbox_frame = create_category (GTK_WIDGET (dialog), dialog->right_vbox, "");
-    gtk_container_add (GTK_CONTAINER (options_hbox), dialog->right_vbox_frame);
+    gtk_box_append (GTK_BOX (options_hbox), dialog->right_vbox_frame);
 
     // buttons
-    dialog->cancel_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CANCEL, NULL, NULL);
-    dialog->ok_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK, NULL, NULL);
+    dialog->cancel_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_Cancel"), NULL, NULL);
+    dialog->ok_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_OK"), NULL, NULL);
 
     g_signal_connect_after (dialog->cancel_button, "clicked", G_CALLBACK (on_cancel), dialog);
     g_signal_connect_after (dialog->ok_button, "clicked", G_CALLBACK (on_ok), dialog);
@@ -395,30 +385,6 @@ static void init (GnomeCmdPrepareXferDialog *dialog)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_prepare_xfer_dialog_get_type ()
-{
-    static GtkType dlg_type = 0;
-
-    if (dlg_type == 0)
-    {
-        GtkTypeInfo dlg_info =
-        {
-            (gchar*) "GnomeCmdPrepareXferDialog",
-            sizeof (GnomeCmdPrepareXferDialog),
-            sizeof (GnomeCmdPrepareXferDialogClass),
-            (GtkClassInitFunc) class_init,
-            (GtkObjectInitFunc) init,
-            /* reserved_1 */ NULL,
-            /* reserved_2 */ NULL,
-            (GtkClassInitFunc) NULL
-        };
-
-        dlg_type = gtk_type_unique (GNOME_CMD_TYPE_DIALOG, &dlg_info);
-    }
-    return dlg_type;
-}
-
-
 inline gboolean path_points_at_directory (GnomeCmdFileSelector *to, const gchar *dest_path)
 {
     GFileType type;
@@ -480,7 +446,7 @@ GtkWidget *gnome_cmd_prepare_xfer_dialog_new (GnomeCmdFileSelector *from, GnomeC
     }
     if (destString)
     {
-        gtk_entry_set_text (GTK_ENTRY (dialog->dest_dir_entry), destString);
+        gtk_editable_set_text (GTK_EDITABLE (dialog->dest_dir_entry), destString);
         g_free (destString);
     }
 
