@@ -146,21 +146,10 @@ struct GnomeCmdSearchDialog::Private
     explicit Private(GnomeCmdSearchDialog *dlg);
     ~Private();
 
-    static gchar *translate_menu(const gchar *path, gpointer data);
-
-    GtkWidget *create_placeholder_menu(GnomeCmdData::SearchConfig &cfg);
-    GtkWidget *create_button_with_menu(gchar *label_text, GnomeCmdData::SearchConfig &cfg);
-
-    static void manage_profiles(GnomeCmdSearchDialog::Private *priv, guint unused, GtkWidget *menu);
-    static void load_profile(GnomeCmdSearchDialog::Private *priv, guint profile_idx, GtkWidget *menu);
-
     static gboolean join_thread_func(GnomeCmdSearchDialog::Private *priv);
 
-    static gboolean on_list_keypressed (GtkWidget *result_list, GdkEventKey *event, gpointer unused);
-
     static void on_dialog_show (GtkWidget *widget, GnomeCmdSearchDialog *dialog);
     static void on_dialog_hide (GtkWidget *widget, GnomeCmdSearchDialog *dialog);
-    static gboolean on_dialog_delete (GtkWidget *widget, GdkEvent *event, GnomeCmdSearchDialog *dialog);
     static void on_dialog_size_allocate (GtkWidget *widget, GtkAllocation *allocation, GnomeCmdSearchDialog *dialog);
     static void on_dialog_response (GtkDialog *window, int response_id, GnomeCmdSearchDialog *dialog);
 };
@@ -183,103 +172,70 @@ inline GnomeCmdSearchDialog::Private::~Private()
 }
 
 
-gchar *GnomeCmdSearchDialog::Private::translate_menu(const gchar *path, gpointer data)
+static GMenu *create_placeholder_menu(GnomeCmdData::SearchConfig &cfg)
 {
-    return _(path);
-}
+    GMenu *menu = g_menu_new ();
 
-
-inline GtkWidget *GnomeCmdSearchDialog::Private::create_placeholder_menu(GnomeCmdData::SearchConfig &cfg)
-{
-    guint items_size = cfg.profiles.empty() ? 1 : cfg.profiles.size()+3;
-    GtkItemFactoryEntry *items = g_try_new0 (GtkItemFactoryEntry, items_size);
-
-    g_return_val_if_fail (items!=nullptr, nullptr);
-
-    GtkItemFactoryEntry *i = items;
-
-    i->path = g_strdup (_("/_Save Profile As…"));
-    i->callback = (GtkItemFactoryCallback) manage_profiles;
-    i->callback_action = TRUE;
-    i->item_type = (gchar*) "<StockItem>";
-    i->extra_data = GTK_STOCK_SAVE_AS;
-    ++i;
+    g_menu_append (menu, _("_Save Profile As…"), "search.save-profile");
 
     if (!cfg.profiles.empty())
     {
-        i->path = g_strdup (_("/_Manage Profiles…"));
-        i->callback = (GtkItemFactoryCallback) manage_profiles;
-        i->item_type = (gchar*) "<StockItem>";
-        i->extra_data = GTK_STOCK_EDIT;
-        ++i;
+        g_menu_append (menu, _("_Manage Profiles…"), "search.manage-profiles");
 
-        i->path = g_strdup ("/");
-        i->item_type = (gchar*) "<Separator>";
-        ++i;
+        GMenu *profiles = g_menu_new ();
 
+        gint i = 0;
         for (vector<GnomeCmdData::SearchProfile>::const_iterator p=cfg.profiles.begin(); p!=cfg.profiles.end(); ++p, ++i)
         {
-            i->path = g_strconcat ("/", p->name.c_str(), nullptr);
-            i->callback = (GtkItemFactoryCallback) load_profile;
-            i->callback_action = (i-items)-3;
-            i->item_type = (gchar*) "<StockItem>";
-            i->extra_data = GTK_STOCK_REVERT_TO_SAVED;
+            GMenuItem *item = g_menu_item_new (p->name.c_str(), nullptr);
+            g_menu_item_set_action_and_target (item, "search.load-profile", "i", i);
+            g_menu_append_item (profiles, item);
         }
+        g_menu_append_section (menu, nullptr, G_MENU_MODEL (profiles));
     }
 
-    GtkItemFactory *ifac = gtk_item_factory_new (GTK_TYPE_MENU, "<main>", nullptr);
-
-    gtk_item_factory_create_items (ifac, items_size, items, this);
-
-    for (guint ii=0; ii<items_size; ++ii)
-        g_free (items[ii].path);
-
-    g_free (items);
-
-    return gtk_item_factory_get_widget (ifac, "<main>");
+    return menu;
 }
 
 
-inline GtkWidget *GnomeCmdSearchDialog::Private::create_button_with_menu(gchar *label_text, GnomeCmdData::SearchConfig &cfg)
+static void do_manage_profiles(GnomeCmdSearchDialog *dialog, bool new_profile)
 {
-    profile_menu_button = gnome_cmd_button_menu_new (label_text, create_placeholder_menu(cfg));
-
-    return profile_menu_button;
-}
-
-
-void GnomeCmdSearchDialog::Private::manage_profiles(GnomeCmdSearchDialog::Private *priv, guint new_profile, GtkWidget *widget)
-{
-    auto *dialog = reinterpret_cast<GnomeCmdSearchDialog*> (gtk_widget_get_ancestor (priv->profile_menu_button, GNOME_CMD_TYPE_SEARCH_DIALOG));
-
-    g_return_if_fail (dialog != nullptr);
-
     if (new_profile)
-        priv->profile_component->copy();
+        dialog->priv->profile_component->copy();
 
     if (GnomeCmd::ManageProfilesDialog<GnomeCmdData::SearchConfig,GnomeCmdData::SearchProfile,GnomeCmdSelectionProfileComponent> (*dialog,dialog->defaults,new_profile,_("Profiles"),"gnome-commander-search"))
     {
-        GtkWidget *menu = gtk_widget_get_parent (widget);
-
-        gnome_cmd_button_menu_disconnect_handler (priv->profile_menu_button, menu);
-        g_object_unref (gtk_item_factory_from_widget (menu));
-        gnome_cmd_button_menu_connect_handler (priv->profile_menu_button, priv->create_placeholder_menu(dialog->defaults));
+        gtk_menu_button_set_menu_model (
+            GTK_MENU_BUTTON (dialog->priv->profile_menu_button),
+            G_MENU_MODEL (create_placeholder_menu(dialog->defaults)));
     }
 }
 
-
-void GnomeCmdSearchDialog::Private::load_profile(GnomeCmdSearchDialog::Private *priv, guint profile_idx, GtkWidget *widget)
+static void save_profile(GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-    GtkWidget *dialog = gtk_widget_get_ancestor (priv->profile_menu_button, GNOME_CMD_TYPE_SEARCH_DIALOG);
+    auto dialog = static_cast<GnomeCmdSearchDialog*>(user_data);
+    do_manage_profiles(dialog, true);
+}
 
-    g_return_if_fail (dialog!=nullptr);
 
-    GnomeCmdData::SearchConfig &cfg = GNOME_CMD_SEARCH_DIALOG(dialog)->defaults;
+static void manage_profiles(GSimpleAction *action, GVariant *parameter, gpointer user_data)
+{
+    auto dialog = static_cast<GnomeCmdSearchDialog*>(user_data);
+    do_manage_profiles(dialog, false);
+}
 
-    g_return_if_fail (profile_idx<cfg.profiles.size());
+
+static void load_profile(GSimpleAction *action, GVariant *parameter, gpointer user_data)
+{
+    auto dialog = static_cast<GnomeCmdSearchDialog*>(user_data);
+    gsize profile_idx = g_variant_get_int32 (parameter);
+
+    GnomeCmdData::SearchConfig &cfg = dialog->defaults;
+
+    g_return_if_fail (profile_idx < cfg.profiles.size());
 
     cfg.default_profile = cfg.profiles[profile_idx];
-    priv->profile_component->update();
+    dialog->priv->profile_component->update();
 }
 
 
@@ -400,23 +356,6 @@ inline gboolean SearchData::ContentMatches(GFile *f, GFileInfo *info)
 }
 
 
-inline gboolean handle_list_keypress (GnomeCmdFileList *fl, GdkEventKey *event)
-{
-    switch (event->keyval)
-    {
-        case GDK_F3:
-            gnome_cmd_file_list_view (fl, gnome_cmd_data.options.use_internal_viewer);
-            return TRUE;
-
-        case GDK_F4:
-            gnome_cmd_file_list_edit (fl);
-            return TRUE;
-        default:
-            return FALSE;
-    }
-}
-
-
 inline void SearchData::set_statusmsg(const gchar *msg)
 {
     gtk_statusbar_push (GTK_STATUSBAR (dialog->priv->statusbar), context_id, msg ? msg : "");
@@ -449,8 +388,8 @@ void SearchData::SearchDirRecursive(GnomeCmdDir *dir, long level)
     if (!files || gnome_cmd_dir_is_local (dir))
     {
         // if list is not available or it's a local directory then create a new list, otherwise use already available list
-        // gnome_cmd_dir_list_files is not used for creating a list, beacause it's tied to the GUI and that's not usable from other threads
-        files = sync_dir_list(GNOME_CMD_FILE (dir)->gFile, cancellable);
+        // gnome_cmd_dir_list_files is not used for creating a list, because it's tied to the GUI and that's not usable from other threads
+        files = sync_dir_list(GNOME_CMD_FILE (dir)->get_file(), cancellable);
         isGnomeCmdFile = FALSE;
     }
 
@@ -460,7 +399,7 @@ void SearchData::SearchDirRecursive(GnomeCmdDir *dir, long level)
         if (stopped)         // if the stop button was pressed, let's abort here
             break;
 
-        GFileInfo *info = isGnomeCmdFile ? ((GnomeCmdFile *) i->data)->gFileInfo : (GFileInfo *) i->data;
+        GFileInfo *info = isGnomeCmdFile ? ((GnomeCmdFile *) i->data)->get_file_info() : (GFileInfo *) i->data;
 
         // if the file is a regular one, it might match the search criteria
         if (g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_STANDARD_TYPE) == G_FILE_TYPE_REGULAR)
@@ -472,7 +411,7 @@ void SearchData::SearchDirRecursive(GnomeCmdDir *dir, long level)
             // if the user wants to we should do some content matching here
             if (dialog->defaults.default_profile.content_search)
             {
-                GFile *file = isGnomeCmdFile ? ((GnomeCmdFile *) i->data)->gFile : g_file_get_child (((GnomeCmdFile *) dir)->gFile, g_file_info_get_name (info));
+                GFile *file = isGnomeCmdFile ? ((GnomeCmdFile *) i->data)->get_file() : g_file_get_child (((GnomeCmdFile *) dir)->get_file(), g_file_info_get_name (info));
                 gboolean matches = ContentMatches (file, info);
                 if (!isGnomeCmdFile)
                     g_object_unref (file);
@@ -506,7 +445,7 @@ void SearchData::SearchDirRecursive(GnomeCmdDir *dir, long level)
             if (stopped)         // if the stop button was pressed, let's abort here
                 break;
 
-            GFileInfo *info = isGnomeCmdFile ? ((GnomeCmdFile *) i->data)->gFileInfo : (GFileInfo *) i->data;
+            GFileInfo *info = isGnomeCmdFile ? ((GnomeCmdFile *) i->data)->get_file_info() : (GFileInfo *) i->data;
 
             // if the current file is a directory, let's continue our recursion
             if (g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_STANDARD_TYPE) == G_FILE_TYPE_DIRECTORY)
@@ -984,16 +923,26 @@ gboolean SearchData::StartLocalSearch()
 }
 
 
-gboolean GnomeCmdSearchDialog::Private::on_list_keypressed(GtkWidget *result_list, GdkEventKey *event, gpointer unused)
+static gboolean on_list_keypressed (GtkEventControllerKey *controller, guint keyval, guint keycode, GdkModifierType state, gpointer user_data)
 {
-    if (GNOME_CMD_FILE_LIST (result_list)->key_pressed(event) ||
-        handle_list_keypress (GNOME_CMD_FILE_LIST (result_list), event))
-    {
-        g_signal_stop_emission_by_name (result_list, "key-press-event");
-        return TRUE;
-    }
+    auto dialog = GNOME_CMD_SEARCH_DIALOG (user_data);
 
-    return FALSE;
+    GnomeCmdKeyPress key_press_event = { .keyval = keyval, .state = state };
+    if (dialog->priv->result_list->key_pressed(&key_press_event))
+        return TRUE;
+
+    switch (keyval)
+    {
+        case GDK_KEY_F3:
+            gnome_cmd_file_list_view (dialog->priv->result_list, gnome_cmd_data.options.use_internal_viewer);
+            return TRUE;
+
+        case GDK_KEY_F4:
+            gnome_cmd_file_list_edit (dialog->priv->result_list);
+            return TRUE;
+        default:
+            return FALSE;
+    }
 }
 
 
@@ -1003,9 +952,7 @@ void GnomeCmdSearchDialog::Private::on_dialog_show(GtkWidget *widget, GnomeCmdSe
 
     dialog->priv->data.start_dir = main_win->fs(ACTIVE)->get_directory();
 
-    gchar *uri = gnome_cmd_dir_get_uri_str (dialog->priv->data.start_dir);
-    gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (dialog->priv->dir_browser), uri);
-    g_free (uri);
+    directory_chooser_button_set_file (dialog->priv->dir_browser, GNOME_CMD_FILE(dialog->priv->data.start_dir)->get_file());
 }
 
 
@@ -1013,13 +960,7 @@ void GnomeCmdSearchDialog::Private::on_dialog_hide(GtkWidget *widget, GnomeCmdSe
 {
     dialog->priv->profile_component->copy();
 
-    dialog->priv->result_list->remove_all_files();
-}
-
-
-gboolean GnomeCmdSearchDialog::Private::on_dialog_delete(GtkWidget *widget, GdkEvent *event, GnomeCmdSearchDialog *dialog)
-{
-    return event->type==GDK_DELETE;
+    dialog->priv->result_list->clear();
 }
 
 
@@ -1073,7 +1014,8 @@ void GnomeCmdSearchDialog::Private::on_dialog_response(GtkDialog *window, int re
                 data.content_regex = nullptr;
                 data.match_dirs = nullptr;
 
-                auto uriString = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (dialog->priv->dir_browser));
+                GFile *file = directory_chooser_button_get_file (dialog->priv->dir_browser);
+                auto uriString = file ? g_file_get_uri (file) : nullptr;
                 auto gUri = g_uri_parse (uriString, G_URI_FLAGS_NONE, nullptr);
 
                 g_free (uriString);
@@ -1119,7 +1061,7 @@ void GnomeCmdSearchDialog::Private::on_dialog_response(GtkDialog *window, int re
                 data.search_done = FALSE;
                 data.stopped = FALSE;
 
-                dialog->priv->result_list->remove_all_files();
+                dialog->priv->result_list->clear();
 
                 gchar *base_dir_utf8 = GNOME_CMD_FILE (data.start_dir)->get_real_path();
                 dialog->priv->result_list->set_base_dir(base_dir_utf8);
@@ -1195,41 +1137,52 @@ void GnomeCmdSearchDialog::Private::on_dialog_response(GtkDialog *window, int re
 
 static void gnome_cmd_search_dialog_init (GnomeCmdSearchDialog *dialog)
 {
+    static GActionEntry action_entries[] = {
+        { "save-profile", save_profile },
+        { "manage-profiles", manage_profiles },
+        { "load-profile", load_profile, "i" }
+    };
+    GSimpleActionGroup* action_group = g_simple_action_group_new ();
+    g_action_map_add_action_entries (G_ACTION_MAP (action_group), action_entries, G_N_ELEMENTS(action_entries), dialog);
+    gtk_widget_insert_action_group (GTK_WIDGET (dialog), "search", G_ACTION_GROUP (action_group));
+
     dialog->priv = new GnomeCmdSearchDialog::Private(dialog);
 
     gtk_window_set_title (*dialog, _("Search…"));
     gtk_window_set_resizable (*dialog, TRUE);
-    gtk_dialog_set_has_separator (*dialog, FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-    gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
 
-    dialog->priv->vbox = gtk_vbox_new (FALSE, 6);
-    gtk_container_set_border_width (GTK_CONTAINER (dialog->priv->vbox), 5);
-    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), dialog->priv->vbox, TRUE, TRUE, 0);
+    GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
+    gtk_widget_set_margin_top (content_area, 10);
+    gtk_widget_set_margin_bottom (content_area, 10);
+    gtk_widget_set_margin_start (content_area, 10);
+    gtk_widget_set_margin_end (content_area, 10);
+    gtk_box_set_spacing (GTK_BOX (content_area), 6);
+
+    dialog->priv->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+    gtk_box_append (GTK_BOX (content_area), dialog->priv->vbox);
 
     // file list
-    GtkWidget *sw = gtk_scrolled_window_new (nullptr, nullptr);
-    gtk_box_pack_start (GTK_BOX (dialog->priv->vbox), sw, TRUE, TRUE, 0);
+    GtkWidget *sw = gtk_scrolled_window_new ();
+    gtk_widget_set_vexpand (sw, TRUE);
+    gtk_box_append (GTK_BOX (dialog->priv->vbox), sw);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
     dialog->priv->result_list = new GnomeCmdFileList(GnomeCmdFileList::COLUMN_NAME,GTK_SORT_ASCENDING);
     gtk_widget_set_size_request (*dialog->priv->result_list, -1, 200);
-    gtk_container_add (GTK_CONTAINER (sw), *dialog->priv->result_list);
-    gtk_container_set_border_width (GTK_CONTAINER (dialog->priv->result_list), 4);
-
+    gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (sw), *dialog->priv->result_list);
 
     // status
     dialog->priv->statusbar = gtk_statusbar_new ();
-    gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (dialog->priv->statusbar), FALSE);
-    gtk_box_pack_start (GTK_BOX (dialog->priv->vbox), dialog->priv->statusbar, FALSE, TRUE, 0);
+    gtk_window_set_has_resize_grip (GTK_WINDOW (dialog), FALSE);
+    gtk_box_append (GTK_BOX (dialog->priv->vbox), dialog->priv->statusbar);
 
 
     // progress
     dialog->priv->pbar = create_progress_bar (*dialog);
     gtk_progress_bar_set_show_text (GTK_PROGRESS_BAR (dialog->priv->pbar), FALSE);
     gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (dialog->priv->pbar), 1.0 / (gdouble) PBAR_MAX);
-    gtk_box_pack_start (GTK_BOX (dialog->priv->statusbar),dialog->priv-> pbar, FALSE, TRUE, 0);
+    gtk_box_append (GTK_BOX (dialog->priv->statusbar),dialog->priv-> pbar);
 
 
     dialog->priv->result_list->update_style();
@@ -1240,6 +1193,9 @@ static void gnome_cmd_search_dialog_init (GnomeCmdSearchDialog *dialog)
     gtk_widget_hide (dialog->priv->pbar);
 
     g_mutex_init(&dialog->priv->data.pdata.mutex);
+
+    GtkEventController *key_controller = gtk_event_controller_key_new (GTK_WIDGET (dialog->priv->result_list));
+    g_signal_connect (key_controller, "key-pressed", G_CALLBACK (on_list_keypressed), dialog);
 }
 
 
@@ -1298,16 +1254,20 @@ GnomeCmdSearchDialog::GnomeCmdSearchDialog(GnomeCmdData::SearchConfig &cfg): def
         gtk_window_set_type_hint (*this, GDK_WINDOW_TYPE_HINT_NORMAL);
     }
 
-    GtkWidget *button = priv->create_button_with_menu(_("Profiles…"), cfg);
+    priv->profile_menu_button = gtk_menu_button_new ();
+    gtk_button_set_label (GTK_BUTTON (priv->profile_menu_button), _("Profiles…"));
+    gtk_menu_button_set_menu_model (
+        GTK_MENU_BUTTON (priv->profile_menu_button),
+        G_MENU_MODEL (create_placeholder_menu(cfg)));
 
-    gtk_dialog_add_action_widget (*this, button, GCMD_RESPONSE_PROFILES);
+    gtk_dialog_add_action_widget (*this, priv->profile_menu_button, GCMD_RESPONSE_PROFILES);
 
     gtk_dialog_add_buttons (*this,
-                            GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-                            GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-                            GTK_STOCK_JUMP_TO, GCMD_RESPONSE_GOTO,
-                            GTK_STOCK_STOP, GCMD_RESPONSE_STOP,
-                            GTK_STOCK_FIND, GCMD_RESPONSE_FIND,
+                            _("_Help"), GTK_RESPONSE_HELP,
+                            _("_Close"), GTK_RESPONSE_CLOSE,
+                            _("_Jump to"), GCMD_RESPONSE_GOTO,
+                            _("_Stop"), GCMD_RESPONSE_STOP,
+                            _("_Find"), GCMD_RESPONSE_FIND,
                             nullptr);
 
     gtk_dialog_set_response_sensitive (*this, GCMD_RESPONSE_GOTO, FALSE);
@@ -1315,13 +1275,14 @@ GnomeCmdSearchDialog::GnomeCmdSearchDialog(GnomeCmdData::SearchConfig &cfg): def
 
     gtk_dialog_set_default_response (*this, GCMD_RESPONSE_FIND);
 
+    gtk_window_set_hide_on_close (*this, TRUE);
+
     // search in
-    priv->dir_browser =  gtk_file_chooser_button_new (_("Select Directory"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
-    gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (priv->dir_browser), FALSE);
+    priv->dir_browser = create_directory_chooser_button (*this, "dir_browser", FALSE);
 
     priv->profile_component = new GnomeCmdSelectionProfileComponent(cfg.default_profile, priv->dir_browser, _("_Look in folder:"));
 
-    gtk_box_pack_start (GTK_BOX (priv->vbox), *priv->profile_component, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (priv->vbox), *priv->profile_component);
     gtk_box_reorder_child (GTK_BOX (priv->vbox), *priv->profile_component, 0);
 
     if (!defaults.name_patterns.empty())
@@ -1331,14 +1292,11 @@ GnomeCmdSearchDialog::GnomeCmdSearchDialog(GnomeCmdData::SearchConfig &cfg): def
 
     priv->profile_component->set_default_activation(*this);
 
-    gtk_widget_show_all (button);
+    gtk_widget_show_all (priv->profile_menu_button);
     gtk_widget_show (*priv->profile_component);
 
-    g_signal_connect (priv->result_list, "key-press-event", G_CALLBACK (Private::on_list_keypressed), this);
-
     g_signal_connect (this, "show", G_CALLBACK (Private::on_dialog_show), this);
     g_signal_connect (this, "hide", G_CALLBACK (Private::on_dialog_hide), this);
-    g_signal_connect (this, "delete-event", G_CALLBACK (Private::on_dialog_delete), this);
     g_signal_connect (this, "size-allocate", G_CALLBACK (Private::on_dialog_size_allocate), this);
     g_signal_connect (this, "response", G_CALLBACK (Private::on_dialog_response), this);
 }
