@@ -27,11 +27,6 @@
 using namespace std;
 
 
-#define CALL_PARENT(parent_class_cast, parent, name, args)               \
-        ((parent_class_cast(parent##_parent_class)->name != nullptr) ?      \
-                 parent_class_cast(parent##_parent_class)->name args : (void)0)
-
-
 struct GnomeCmdAboutPluginPrivate
 {
     gchar *name;
@@ -48,7 +43,7 @@ struct GnomeCmdAboutPluginPrivate
     GtkWidget *comments_label;
     GtkWidget *copyright_label;
 
-    GtkWidget *credits_dialog;
+    GWeakRef credits_dialog;
     GtkWidget *web_button;
 };
 
@@ -71,7 +66,6 @@ static void gnome_cmd_about_plugin_finalize (GObject *object);
 static void gnome_cmd_about_plugin_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static void gnome_cmd_about_plugin_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
 
-//GNOME_CLASS_BOILERPLATE (GnomeCmdAboutPlugin, gnome_cmd_about_plugin, GtkDialog, (GTypeFlags) GTK_TYPE_DIALOG)
 G_DEFINE_TYPE (GnomeCmdAboutPlugin, gnome_cmd_about_plugin, GTK_TYPE_DIALOG)
 
 static void gnome_cmd_about_plugin_update_authors_label (GnomeCmdAboutPlugin *about, GtkWidget *label)
@@ -157,8 +151,12 @@ inline GtkWidget *_create_label ()
     GtkWidget *label = gtk_label_new ("");
 
     gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
-    gtk_misc_set_padding (GTK_MISC (label), 8, 8);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_START);
+    gtk_widget_set_margin_start (label, 8);
+    gtk_widget_set_margin_end (label, 8);
+    gtk_widget_set_margin_top (label, 8);
+    gtk_widget_set_margin_bottom (label, 8);
 
     gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
 
@@ -170,38 +168,43 @@ static void gnome_cmd_about_plugin_display_credits_dialog (GnomeCmdAboutPlugin *
 {
     GtkWidget *dialog, *label, *notebook, *sw;
 
-    if (about->priv->credits_dialog != nullptr)
+    dialog = GTK_WIDGET (g_weak_ref_get (&about->priv->credits_dialog));
+    if (dialog != nullptr)
     {
-        gtk_window_present (GTK_WINDOW (about->priv->credits_dialog));
+        gtk_window_present (GTK_WINDOW (dialog));
         return;
     }
 
     dialog = gtk_dialog_new_with_buttons (_("Credits"),
                           GTK_WINDOW (about),
                           GTK_DIALOG_DESTROY_WITH_PARENT,
-                          GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                          _("_Close"), GTK_RESPONSE_CLOSE,
                           nullptr);
-    about->priv->credits_dialog = dialog;
+    g_weak_ref_set (&about->priv->credits_dialog, dialog);
     gtk_window_set_default_size (GTK_WINDOW (dialog), 360, 260);
     gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
-    gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-    gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
-    g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), dialog);
-    g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &(about->priv->credits_dialog));
+
+    GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
+    gtk_widget_set_margin_top (content_area, 10);
+    gtk_widget_set_margin_bottom (content_area, 10);
+    gtk_widget_set_margin_start (content_area, 10);
+    gtk_widget_set_margin_end (content_area, 10);
+    gtk_box_set_spacing (GTK_BOX (content_area), 6);
+
+    g_signal_connect (dialog, "response", G_CALLBACK (gtk_window_destroy), dialog);
 
     notebook = gtk_notebook_new ();
-    gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
-    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), notebook, TRUE, TRUE, 0);
+    gtk_widget_set_vexpand (notebook, TRUE);
+    gtk_box_append (GTK_BOX (content_area), notebook);
 
     if (about->priv->authors != nullptr)
     {
         label = _create_label ();
 
-        sw = gtk_scrolled_window_new (nullptr, nullptr);
+        sw = gtk_scrolled_window_new ();
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-        gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (sw), label);
-        gtk_viewport_set_shadow_type (GTK_VIEWPORT (gtk_bin_get_child (GTK_BIN (sw))), GTK_SHADOW_NONE);
+        gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (sw), label);
 
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sw, gtk_label_new (_("Written by")));
         gnome_cmd_about_plugin_update_authors_label (about, label);
@@ -211,10 +214,9 @@ static void gnome_cmd_about_plugin_display_credits_dialog (GnomeCmdAboutPlugin *
     {
         label = _create_label ();
 
-        sw = gtk_scrolled_window_new (nullptr, nullptr);
+        sw = gtk_scrolled_window_new ();
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-        gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (sw), label);
-        gtk_viewport_set_shadow_type (GTK_VIEWPORT (gtk_bin_get_child (GTK_BIN (sw))), GTK_SHADOW_NONE);
+        gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (sw), label);
 
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sw, gtk_label_new (_("Documented by")));
         gnome_cmd_about_plugin_update_documenters_label (about, label);
@@ -224,10 +226,9 @@ static void gnome_cmd_about_plugin_display_credits_dialog (GnomeCmdAboutPlugin *
     {
         label = _create_label ();
 
-        sw = gtk_scrolled_window_new (nullptr, nullptr);
+        sw = gtk_scrolled_window_new ();
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-        gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (sw), label);
-        gtk_viewport_set_shadow_type (GTK_VIEWPORT (gtk_bin_get_child (GTK_BIN (sw))), GTK_SHADOW_NONE);
+        gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (sw), label);
 
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sw, gtk_label_new (_("Translated by")));
         gnome_cmd_about_plugin_update_translation_information_label (about, label);
@@ -241,14 +242,14 @@ static void link_button_clicked_callback (GtkWidget *widget, gpointer data)
 {
     const gchar *link;
 
-	link = gtk_link_button_get_uri (GTK_LINK_BUTTON (widget));
-	gtk_show_uri (nullptr, link, gtk_get_current_event_time(), nullptr);
+    link = gtk_link_button_get_uri (GTK_LINK_BUTTON (widget));
+    gtk_show_uri (nullptr, link, gtk_get_current_event_time(), nullptr);
 }
 
 
 static void gnome_cmd_about_plugin_init (GnomeCmdAboutPlugin *about)
 {
-    GtkWidget *vbox, *hbox, *image, *label, *alignment, *button;
+    GtkWidget *button;
 
     // Data
     GnomeCmdAboutPluginPrivate *priv = g_new0 (GnomeCmdAboutPluginPrivate, 1);
@@ -263,98 +264,75 @@ static void gnome_cmd_about_plugin_init (GnomeCmdAboutPlugin *about)
     // priv->documenters = nullptr;
     // priv->webpage = nullptr;
 
-    gtk_dialog_set_has_separator (GTK_DIALOG (about), FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (about), 5);
-    gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (about))), 5);
+    GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (about));
+
+    gtk_widget_set_margin_top (content_area, 10);
+    // gtk_widget_set_margin_bottom (content_area, 10);
+    gtk_widget_set_margin_start (content_area, 10);
+    gtk_widget_set_margin_end (content_area, 10);
+    gtk_box_set_spacing (GTK_BOX (content_area), 8);
 
     // Widgets
-    vbox = gtk_vbox_new (FALSE, 8);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
-
-    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (about))), vbox, TRUE, TRUE, 0);
-
     priv->name_label = gtk_label_new (nullptr);
     gtk_widget_show (priv->name_label);
     gtk_label_set_selectable (GTK_LABEL (priv->name_label), TRUE);
     gtk_label_set_justify (GTK_LABEL (priv->name_label), GTK_JUSTIFY_CENTER);
-    gtk_box_pack_start (GTK_BOX (vbox), priv->name_label, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (content_area), priv->name_label);
 
     priv->comments_label = gtk_label_new (nullptr);
     gtk_widget_show (priv->comments_label);
     gtk_label_set_selectable (GTK_LABEL (priv->comments_label), TRUE);
     gtk_label_set_justify (GTK_LABEL (priv->comments_label), GTK_JUSTIFY_CENTER);
     gtk_label_set_line_wrap (GTK_LABEL (priv->comments_label), TRUE);
-    gtk_box_pack_start (GTK_BOX (vbox), priv->comments_label, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (content_area), priv->comments_label);
 
     priv->copyright_label = gtk_label_new (nullptr);
     gtk_widget_show (priv->copyright_label);
     gtk_label_set_selectable (GTK_LABEL (priv->copyright_label), TRUE);
     gtk_label_set_justify (GTK_LABEL (priv->copyright_label), GTK_JUSTIFY_CENTER);
-    gtk_box_pack_start (GTK_BOX (vbox), priv->copyright_label, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (content_area), priv->copyright_label);
 
     priv->web_button = gtk_link_button_new_with_label ("", _("Plugin Webpage"));
     g_signal_connect (priv->web_button, "clicked", G_CALLBACK (link_button_clicked_callback), NULL);
 
-    gtk_box_pack_start (GTK_BOX (vbox), priv->web_button, FALSE, FALSE, 0);
+    gtk_box_append (GTK_BOX (content_area), priv->web_button);
 
-    gtk_widget_show (vbox);
-
-    // Add the close button
-    gtk_dialog_add_button (GTK_DIALOG (about), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
-    gtk_dialog_set_default_response (GTK_DIALOG (about), GTK_RESPONSE_CLOSE);
+    GtkWidget *bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+    GtkSizeGroup *size_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
 
     // Add the credits button
-    image = gtk_image_new_from_stock (GTK_STOCK_ABOUT, GTK_ICON_SIZE_BUTTON);
+    button = gtk_button_new_with_mnemonic (_("C_redits"));
+    g_signal_connect_swapped (button, "clicked", G_CALLBACK (gnome_cmd_about_plugin_display_credits_dialog), about);
+    gtk_size_group_add_widget (size_group, button);
+    gtk_widget_set_hexpand (button, TRUE);
+    gtk_widget_set_halign (button, GTK_ALIGN_START);
+    gtk_box_append (GTK_BOX (bbox), button);
 
-    label = gtk_label_new_with_mnemonic (_("C_redits"));
+    // Add the close button
+    button = gtk_button_new_with_mnemonic (_("_Close"));
+    g_signal_connect_swapped (button, "clicked", G_CALLBACK (gtk_window_destroy), about);
+    gtk_size_group_add_widget (size_group, button);
+    gtk_box_append (GTK_BOX (bbox), button);
 
-    hbox = gtk_hbox_new (FALSE, 2);
-    gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-    gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-    alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-    gtk_container_add (GTK_CONTAINER (alignment), hbox);
-
-    button = gtk_button_new ();
-    gtk_container_add (GTK_CONTAINER (button), alignment);
-    gtk_widget_show_all (button);
-
-    gtk_dialog_add_action_widget (GTK_DIALOG (about), button, GNOME_RESPONSE_CREDITS);
-    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (gtk_dialog_get_action_area (GTK_DIALOG (about))), button, TRUE);
+    gtk_box_append (GTK_BOX (content_area), bbox);
 
     gtk_window_set_resizable (GTK_WINDOW (about), FALSE);
 
-    priv->credits_dialog = nullptr;
-}
+    gtk_widget_show_all (content_area);
 
-
-static void gnome_cmd_about_plugin_response (GtkDialog *dialog, gint response)
-{
-    switch (response)
-    {
-        case GNOME_RESPONSE_CREDITS:
-            gnome_cmd_about_plugin_display_credits_dialog (GNOME_CMD_ABOUT_PLUGIN (dialog));
-            break;
-
-        default:
-            gtk_widget_destroy (GTK_WIDGET (dialog));
-            break;
-    }
+    priv->credits_dialog = { { nullptr } };
 }
 
 
 static void gnome_cmd_about_plugin_class_init (GnomeCmdAboutPluginClass *klass)
 {
     GObjectClass *object_class = (GObjectClass *) klass;
-    GtkDialogClass *dialog_class = (GtkDialogClass *) klass;
 
     object_class->set_property = gnome_cmd_about_plugin_set_property;
     object_class->get_property = gnome_cmd_about_plugin_get_property;
 
     object_class->finalize = gnome_cmd_about_plugin_finalize;
 
-    dialog_class->response = gnome_cmd_about_plugin_response;
-
     g_object_class_install_property (object_class,
                      PROP_NAME,
                      g_param_spec_string ("name",
@@ -529,16 +507,6 @@ static void gnome_cmd_about_plugin_set_name (GnomeCmdAboutPlugin *about, const g
 }
 
 
-inline void gnome_cmd_about_plugin_free_person_list (GSList *list)
-{
-    if (list == nullptr)
-        return;
-
-    g_slist_foreach (list, (GFunc) g_free, nullptr);
-    g_slist_free (list);
-}
-
-
 static void gnome_cmd_about_plugin_finalize (GObject *object)
 {
     GnomeCmdAboutPlugin *about = GNOME_CMD_ABOUT_PLUGIN (object);
@@ -548,8 +516,8 @@ static void gnome_cmd_about_plugin_finalize (GObject *object)
     g_free (about->priv->copyright);
     g_free (about->priv->comments);
 
-    gnome_cmd_about_plugin_free_person_list (about->priv->authors);
-    gnome_cmd_about_plugin_free_person_list (about->priv->documenters);
+    g_clear_slist (&about->priv->authors, g_free);
+    g_clear_slist (&about->priv->documenters, g_free);
 
     g_free (about->priv->translator_credits);
     g_free (about->priv->webpage);
@@ -557,35 +525,31 @@ static void gnome_cmd_about_plugin_finalize (GObject *object)
     g_free (about->priv);
     about->priv = nullptr;
 
-    CALL_PARENT (G_OBJECT_CLASS, gnome_cmd_about_plugin, finalize, (object));
+    G_OBJECT_CLASS (gnome_cmd_about_plugin_parent_class)->finalize (object);
 }
 
 
 static void gnome_cmd_about_plugin_set_persons (GnomeCmdAboutPlugin *about, guint prop_id, const GValue *persons)
 {
-    GSList *list = nullptr;
-
     // Free the old list
     switch (prop_id)
     {
         case PROP_AUTHORS:
-            list = about->priv->authors;
+            g_clear_slist (&about->priv->authors, g_free);
             break;
         case PROP_DOCUMENTERS:
-            list = about->priv->documenters;
+            g_clear_slist (&about->priv->documenters, g_free);
             break;
         default:
             g_assert_not_reached ();
     }
 
-    gnome_cmd_about_plugin_free_person_list (list);
-    list = nullptr;
-
     GValueArray *value_array = (GValueArray *) g_value_get_boxed (persons);
 
     if (!value_array)
         return;
 
+    GSList *list = nullptr;
     for (guint i = 0; i < value_array->n_values; i++)
         list = g_slist_prepend (list, g_value_dup_string (&value_array->values[i]));
 
