@@ -45,12 +45,16 @@ struct GnomeCmdChmodComponentPrivate
 enum {PERMS_CHANGED, LAST_SIGNAL};
 
 
-static GtkVBoxClass *parent_class = NULL;
 static guint chmod_component_signals[LAST_SIGNAL] = { 0 };
 
 
+G_DEFINE_TYPE_WITH_PRIVATE (GnomeCmdChmodComponent, gnome_cmd_chmod_component, GTK_TYPE_BOX)
+
+
 static void on_perms_changed (GnomeCmdChmodComponent *comp)
 {
+    auto priv = static_cast<GnomeCmdChmodComponentPrivate*>(gnome_cmd_chmod_component_get_instance_private (comp));
+
     static gchar text_view[10];
     static gchar number_view[4];
 
@@ -58,14 +62,14 @@ static void on_perms_changed (GnomeCmdChmodComponent *comp)
 
     perm2textstring (permissions, text_view, sizeof(text_view));
     perm2numstring (permissions, number_view, sizeof(number_view));
-    gtk_label_set_text (GTK_LABEL (comp->priv->textview_label), text_view);
-    gtk_label_set_text (GTK_LABEL (comp->priv->numberview_label), number_view);
+    gtk_label_set_text (GTK_LABEL (priv->textview_label), text_view);
+    gtk_label_set_text (GTK_LABEL (priv->numberview_label), number_view);
 }
 
 
 static void on_check_toggled (GtkToggleButton *togglebutton, GnomeCmdChmodComponent *component)
 {
-    gtk_signal_emit (GTK_OBJECT (component), chmod_component_signals[PERMS_CHANGED]);
+    g_signal_emit (component, chmod_component_signals[PERMS_CHANGED], 0);
 }
 
 
@@ -73,98 +77,76 @@ static void on_check_toggled (GtkToggleButton *togglebutton, GnomeCmdChmodCompon
  * Gtk class implementation
  *******************************/
 
-static void destroy (GtkObject *object)
+static void gnome_cmd_chmod_component_class_init (GnomeCmdChmodComponentClass *klass)
 {
-    GnomeCmdChmodComponent *comp = GNOME_CMD_CHMOD_COMPONENT (object);
-
-    g_free (comp->priv);
-
-    if (GTK_OBJECT_CLASS (parent_class)->destroy)
-        (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
-}
-
-
-static void map (GtkWidget *widget)
-{
-    if (GTK_WIDGET_CLASS (parent_class)->map != NULL)
-        GTK_WIDGET_CLASS (parent_class)->map (widget);
-}
-
-
-static void class_init (GnomeCmdChmodComponentClass *klass)
-{
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-
-    parent_class = (GtkVBoxClass *) gtk_type_class (gtk_vbox_get_type ());
-    object_class->destroy = destroy;
-    widget_class->map = ::map;
-
     klass->perms_changed = on_perms_changed;
 
     chmod_component_signals[PERMS_CHANGED] =
-        gtk_signal_new ("perms-changed",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdChmodComponentClass, perms_changed),
-            gtk_marshal_NONE__NONE,
-            GTK_TYPE_NONE,
+        g_signal_new ("perms-changed",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdChmodComponentClass, perms_changed),
+            nullptr, nullptr,
+            g_cclosure_marshal_VOID__VOID,
+            G_TYPE_NONE,
             0);
 }
 
 
-static void init (GnomeCmdChmodComponent *comp)
+static void gnome_cmd_chmod_component_init (GnomeCmdChmodComponent *comp)
 {
+    auto priv = static_cast<GnomeCmdChmodComponentPrivate*>(gnome_cmd_chmod_component_get_instance_private (comp));
+
     GtkWidget *label;
     GtkWidget *hsep;
 
     gchar *check_text[3] = {_("Read"), _("Write"), _("Execute")};
     gchar *check_categories[3] = {_("Owner:"), _("Group:"), _("Others:")};
 
-    comp->priv = g_new (GnomeCmdChmodComponentPrivate, 1);
-
+    g_object_set (comp, "orientation", GTK_ORIENTATION_VERTICAL, NULL);
     gtk_box_set_spacing (GTK_BOX (comp), 5);
 
-    GtkWidget *table = create_table (GTK_WIDGET (comp), 3, 4);
-    gtk_box_pack_start (GTK_BOX (comp), table, FALSE, FALSE, 0);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 6);
+    GtkGrid *grid = GTK_GRID (gtk_grid_new ());
+    gtk_widget_show (GTK_WIDGET (grid));
+    gtk_box_append (GTK_BOX (comp), GTK_WIDGET (grid));
+    gtk_grid_set_row_spacing (grid, 6);
+    gtk_grid_set_column_spacing (grid, 6);
 
     for (gint y=0; y<3; y++)
     {
         GtkWidget *lbl = create_label (GTK_WIDGET (comp), check_categories[y]);
-        table_add (GTK_WIDGET (table), lbl, 0, y, GTK_FILL);
+        gtk_grid_attach (grid, lbl, 0, y, 1, 1);
 
         for (gint x=0; x<3; x++)
         {
-            comp->priv->check_boxes[y][x] = create_check (GTK_WIDGET (comp), check_text[x], "check");
-            g_signal_connect (comp->priv->check_boxes[y][x], "toggled", G_CALLBACK (on_check_toggled), comp);
-            table_add (GTK_WIDGET (table), comp->priv->check_boxes[y][x], x+1, y, GTK_FILL);
+            priv->check_boxes[y][x] = create_check (GTK_WIDGET (comp), check_text[x], "check");
+            g_signal_connect (priv->check_boxes[y][x], "toggled", G_CALLBACK (on_check_toggled), comp);
+            gtk_grid_attach (grid, priv->check_boxes[y][x], x+1, y, 1, 1);
         }
     }
 
     hsep = create_hsep (GTK_WIDGET (comp));
-    gtk_box_pack_start (GTK_BOX (comp), hsep, TRUE, TRUE, 0);
+    gtk_box_append (GTK_BOX (comp), hsep);
 
-    table = create_table (GTK_WIDGET (comp), 2, 2);
-    gtk_box_pack_start (GTK_BOX (comp), table, TRUE, TRUE, 0);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 6);
+    grid = GTK_GRID (gtk_grid_new ());
+    gtk_widget_show (GTK_WIDGET (grid));
+    gtk_box_append (GTK_BOX (comp), GTK_WIDGET (grid));
+    gtk_grid_set_row_spacing (grid, 6);
+    gtk_grid_set_column_spacing (grid, 6);
 
     label = create_label (GTK_WIDGET (comp), _("Text view:"));
-    table_add (table, label, 0, 0, GTK_FILL);
+    gtk_grid_attach (grid, label, 0, 0, 1, 1);
 
     label = create_label (GTK_WIDGET (comp), _("Number view:"));
-    table_add (table, label, 0, 1, GTK_FILL);
+    gtk_grid_attach (grid, label, 0, 1, 1, 1);
 
-    comp->priv->textview_label = create_label (GTK_WIDGET (comp), "");
-    table_add (table, comp->priv->textview_label, 1, 0, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND));
+    priv->textview_label = create_label (GTK_WIDGET (comp), "");
+    gtk_grid_attach (grid, priv->textview_label, 1, 0, 1, 1);
 
-    comp->priv->numberview_label = create_label (GTK_WIDGET (comp), "");
-    table_add (table, comp->priv->numberview_label, 1, 1, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND));
+    priv->numberview_label = create_label (GTK_WIDGET (comp), "");
+    gtk_grid_attach (grid, priv->numberview_label, 1, 1, 1, 1);
 }
 
-
 /***********************************
  * Public functions
  ***********************************/
@@ -179,36 +161,15 @@ GtkWidget *gnome_cmd_chmod_component_new (guint32 perms)
 }
 
 
-GtkType gnome_cmd_chmod_component_get_type ()
-{
-    static GtkType type = 0;
-
-    if (type == 0)
-    {
-        GtkTypeInfo info =
-        {
-            (gchar*) "GnomeCmdChmodComponent",
-            sizeof (GnomeCmdChmodComponent),
-            sizeof (GnomeCmdChmodComponentClass),
-            (GtkClassInitFunc) class_init,
-            (GtkObjectInitFunc) init,
-            /* reserved_1 */ NULL,
-            /* reserved_2 */ NULL,
-            (GtkClassInitFunc) NULL
-        };
-
-        type = gtk_type_unique (gtk_vbox_get_type (), &info);
-    }
-    return type;
-}
-
 guint32 gnome_cmd_chmod_component_get_perms (GnomeCmdChmodComponent *comp)
 {
+    auto priv = static_cast<GnomeCmdChmodComponentPrivate*>(gnome_cmd_chmod_component_get_instance_private (comp));
+
     guint32 perms = 0;
 
     for (gint y=0; y<3; y++)
         for (gint x=0; x<3; x++)
-            if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (comp->priv->check_boxes[y][x])))
+            if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_boxes[y][x])))
                 perms |= check_perm[y][x];
 
     return perms;
@@ -217,7 +178,9 @@ guint32 gnome_cmd_chmod_component_get_perms (GnomeCmdChmodComponent *comp)
 
 void gnome_cmd_chmod_component_set_perms (GnomeCmdChmodComponent *component, guint32 permissions)
 {
+    auto priv = static_cast<GnomeCmdChmodComponentPrivate*>(gnome_cmd_chmod_component_get_instance_private (component));
+
     for (gint y=0; y<3; y++)
         for (gint x=0; x<3; x++)
-            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (component->priv->check_boxes[y][x]), permissions & check_perm[y][x]);
+            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->check_boxes[y][x]), permissions & check_perm[y][x]);
 }
