@@ -33,20 +33,20 @@ struct GnomeCmdCmdlinePrivate;
 
 struct GnomeCmdCmdline
 {
-    GtkHBox parent;
+    GtkBox parent;
     GnomeCmdCmdlinePrivate *priv;
 };
 
 
 struct GnomeCmdCmdlineClass
 {
-    GtkHBoxClass parent_class;
+    GtkBoxClass parent_class;
 };
 
 
-GtkWidget *gnome_cmd_cmdline_new ();
+GnomeCmdCmdline *gnome_cmd_cmdline_new ();
 
-GtkType gnome_cmd_cmdline_get_type ();
+GType gnome_cmd_cmdline_get_type ();
 
 void gnome_cmd_cmdline_set_dir (GnomeCmdCmdline *cmdline, const gchar *cwd);
 
@@ -65,5 +65,3 @@ void gnome_cmd_cmdline_update_style (GnomeCmdCmdline *cmdline);
 GList *gnome_cmd_cmdline_get_history (GnomeCmdCmdline *cmdline);
 void gnome_cmd_cmdline_set_history  (GnomeCmdCmdline *cmdline, GList *history);
 void gnome_cmd_cmdline_show_history (GnomeCmdCmdline *cmdline);
-
-gboolean gnome_cmd_cmdline_keypressed (GnomeCmdCmdline *cmdline, GdkEventKey *event);
