@@ -38,21 +38,22 @@ using namespace std;
 
 struct GnomeCmdConDevicePrivate
 {
-    gchar *alias {nullptr};
     gchar *device_fn {nullptr}; // The device identifier (either a linux device string or a uuid)
     gchar *mountp {nullptr};
-    gchar *icon_path {nullptr};
+    GIcon *icon {nullptr};
     gboolean autovolume;
     GMount *gMount;
     GVolume *gVolume;
 };
 
 
-static GnomeCmdConClass *parent_class = nullptr;
+G_DEFINE_TYPE_WITH_PRIVATE (GnomeCmdConDevice, gnome_cmd_con_device, GNOME_CMD_TYPE_CON)
 
 
 static gboolean is_mounted (GnomeCmdConDevice *dev_con)
 {
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev_con));
+
     FILE *fd = fopen ("/etc/mtab", "r");
 
     if (!fd)
@@ -69,7 +70,7 @@ static gboolean is_mounted (GnomeCmdConDevice *dev_con)
         if (v[1])
         {
             gchar *dir = g_strcompress (v[1]);
-            if (strcmp (dir, dev_con->priv->mountp) == 0)
+            if (strcmp (dir, priv->mountp) == 0)
                 ret = TRUE;
             g_free (dir);
         }
@@ -91,6 +92,7 @@ static void do_legacy_mount(GnomeCmdCon *con)
     g_return_if_fail (GNOME_CMD_IS_CON_DEVICE (con));
 
     GnomeCmdConDevice *dev_con = GNOME_CMD_CON_DEVICE (con);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev_con));
 
     gint ret, estatus;
 
@@ -99,17 +101,17 @@ static void do_legacy_mount(GnomeCmdCon *con)
         gchar *cmd = nullptr;
         gchar *emsg = nullptr;
 
-        if (strlen(dev_con->priv->device_fn) == 0)
+        if (strlen(priv->device_fn) == 0)
             return;
 
-        DEBUG ('m', "mounting %s\n", dev_con->priv->device_fn);
-        if (dev_con->priv->device_fn[0] == G_DIR_SEPARATOR)
+        DEBUG ('m', "mounting %s\n", priv->device_fn);
+        if (priv->device_fn[0] == G_DIR_SEPARATOR)
         {
-            cmd = g_strdup_printf ("mount %s", dev_con->priv->device_fn);
+            cmd = g_strdup_printf ("mount %s", priv->device_fn);
         }
         else
         {
-            cmd = g_strdup_printf ("mount -L %s", dev_con->priv->device_fn);
+            cmd = g_strdup_printf ("mount -L %s", priv->device_fn);
         }
 
         DEBUG ('m', "Mount command: %s\n", cmd);
@@ -172,6 +174,7 @@ static void mount_finish_callback(GObject *gVol, GAsyncResult *result, gpointer
 {
     GnomeCmdCon *con = GNOME_CMD_CON (user_data);
     GnomeCmdConDevice *dev_con = GNOME_CMD_CON_DEVICE (con);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev_con));
     auto gVolume = G_VOLUME(gVol);
     GError *error = nullptr;
 
@@ -183,10 +186,10 @@ static void mount_finish_callback(GObject *gVol, GAsyncResult *result, gpointer
         g_error_free(error);
         return;
     }
-    dev_con->priv->gMount = g_volume_get_mount (gVolume);
+    priv->gMount = g_volume_get_mount (gVolume);
     if (!con->base_path)
     {
-        set_con_base_path_for_gmount(con, dev_con->priv->gMount);
+        set_con_base_path_for_gmount(con, priv->gMount);
     }
     if (con->base_path)
     {
@@ -199,19 +202,20 @@ static void mount_finish_callback(GObject *gVol, GAsyncResult *result, gpointer
 static void do_legacy_mount_thread_func(GnomeCmdCon *con)
 {
     g_return_if_fail (GNOME_CMD_IS_CON_DEVICE (con));
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (GNOME_CMD_CON_DEVICE (con)));
 
     GError *error = nullptr;
 
     if (!con->base_path)
     {
-        con->base_path = new GnomeCmdPlainPath(GNOME_CMD_CON_DEVICE(con)->priv->mountp);
+        con->base_path = new GnomeCmdPlainPath(priv->mountp);
     }
 
     do_legacy_mount(con);
 
     if (con->open_result == GnomeCmdCon::OPEN_FAILED)
     {
-        con->open_failed_error = g_error_new(G_IO_ERROR, G_IO_ERROR_FAILED, "Unable to mount %s", GNOME_CMD_CON_DEVICE (con)->priv->device_fn);
+        con->open_failed_error = g_error_new(G_IO_ERROR, G_IO_ERROR_FAILED, "Unable to mount %s", priv->device_fn);
         set_con_mount_failed(con);
         return;
     }
@@ -243,22 +247,23 @@ static void do_mount (GnomeCmdCon *con)
     g_return_if_fail (GNOME_CMD_IS_CON_DEVICE (con));
 
     GnomeCmdConDevice *dev_con = GNOME_CMD_CON_DEVICE (con);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev_con));
 
     // This is a legacy-mount: If mount point is given, we mount the device with system calls ('mount')
-    if (dev_con->priv->mountp)
+    if (priv->mountp)
     {
         auto gThread = g_thread_new (nullptr, (GThreadFunc) do_legacy_mount_thread_func, con);
         g_thread_unref(gThread);
     }
 
     // Check if the volume is already mounted:
-    if (dev_con->priv->gVolume)
+    if (priv->gVolume)
     {
-        auto gMount = g_volume_get_mount (dev_con->priv->gVolume);
+        auto gMount = g_volume_get_mount (priv->gVolume);
         if (gMount)
         {
-            dev_con->priv->gMount = gMount;
-            set_con_base_path_for_gmount(con, dev_con->priv->gMount);
+            priv->gMount = gMount;
+            set_con_base_path_for_gmount(con, priv->gMount);
             set_con_base_gfileinfo(con);
             set_con_mount_succeed(con);
             return;
@@ -266,7 +271,7 @@ static void do_mount (GnomeCmdCon *con)
 
         auto gMountOperation = gtk_mount_operation_new ((GtkWindow*) main_win);
 
-        g_volume_mount (dev_con->priv->gVolume,
+        g_volume_mount (priv->gVolume,
             G_MOUNT_MOUNT_NONE,
             gMountOperation,
             nullptr,
@@ -299,7 +304,7 @@ static void show_message_dialog_volume_unmounted()
                                      GTK_BUTTONS_OK,
                                      _("Volume successfully unmounted"));
     gtk_dialog_run (GTK_DIALOG (msgbox));
-    gtk_widget_destroy (msgbox);
+    gtk_window_destroy (GTK_WINDOW (msgbox));
 }
 
 
@@ -322,7 +327,7 @@ static void unmount_callback(GObject *gMnt, GAsyncResult *result, gpointer user_
                                          error->message,
                                          error->code);
         gtk_dialog_run (GTK_DIALOG (msgbox));
-        gtk_widget_destroy (msgbox);
+        gtk_window_destroy (GTK_WINDOW (msgbox));
 
         g_error_free(error);
         return;
@@ -341,6 +346,7 @@ static gboolean dev_close (GnomeCmdCon *con)
     gint ret = 0;
 
     GnomeCmdConDevice *dev_con = GNOME_CMD_CON_DEVICE (con);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev_con));
 
     gnome_cmd_con_set_default_dir (con, nullptr);
 
@@ -349,15 +355,15 @@ static gboolean dev_close (GnomeCmdCon *con)
         DEBUG ('m', "Could not go back to home directory before unmounting\n");
     }
 
-    if (dev_con->priv->autovolume)
+    if (priv->autovolume)
     {
-        if (!g_mount_can_unmount(dev_con->priv->gMount))
+        if (!g_mount_can_unmount(priv->gMount))
             return ret == 0;
 
-        auto gMountName = g_mount_get_name(dev_con->priv->gMount);
+        auto gMountName = g_mount_get_name(priv->gMount);
         DEBUG ('m', "umounting GIO mount \"%s\"\n", gMountName);
         g_free(gMountName);
-        g_mount_unmount_with_operation (dev_con->priv->gMount,
+        g_mount_unmount_with_operation (priv->gMount,
                             G_MOUNT_UNMOUNT_NONE,
                             nullptr,
                             nullptr,
@@ -367,10 +373,10 @@ static gboolean dev_close (GnomeCmdCon *con)
     else
     {
         // Legacy unmount
-        if(dev_con->priv->mountp)
+        if(priv->mountp)
         {
-            DEBUG ('m', "umounting %s\n", dev_con->priv->mountp);
-            gchar *cmd = g_strdup_printf ("umount %s", dev_con->priv->mountp);
+            DEBUG ('m', "umounting %s\n", priv->mountp);
+            gchar *cmd = g_strdup_printf ("umount %s", priv->mountp);
             ret = system (cmd);
             DEBUG ('m', "umount returned %d\n", ret);
             g_free (cmd);
@@ -408,18 +414,19 @@ static GFile *dev_create_gfile (GnomeCmdCon *con, GnomeCmdPath *gnomeCmdPath)
 
     GFile *newGFile = nullptr;
     GnomeCmdConDevice *dev_con = GNOME_CMD_CON_DEVICE (con);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev_con));
 
-    if (dev_con->priv->gMount != nullptr)
+    if (priv->gMount != nullptr)
     {
         if (gnomeCmdPath)
         {
-            auto gMountGFile = g_mount_get_default_location (dev_con->priv->gMount);
+            auto gMountGFile = g_mount_get_default_location (priv->gMount);
             newGFile = g_file_resolve_relative_path(gMountGFile, gnomeCmdPath->get_path());
             g_object_unref(gMountGFile);
         }
         else
         {
-            newGFile = g_mount_get_default_location (dev_con->priv->gMount);
+            newGFile = g_mount_get_default_location (priv->gMount);
         }
     }
     else
@@ -442,42 +449,73 @@ static GnomeCmdPath *dev_create_path (GnomeCmdCon *con, const gchar *path_str)
 }
 
 
+static gchar *dev_get_go_text (GnomeCmdCon *con)
+{
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (GNOME_CMD_CON_DEVICE (con)));
+    const gchar *alias = con->alias;
+    if (priv->mountp)
+        return g_strdup_printf (_("Go to: %s (%s)"), alias, priv->mountp);
+    else
+        return g_strdup_printf (_("Go to: %s"), alias);
+}
+
+
+static gchar *dev_get_open_text (GnomeCmdCon *con)
+{
+    const gchar *alias = con->alias;
+    return g_strdup_printf (_("Mount: %s"), alias);
+}
+
+
+static gchar *dev_get_close_text (GnomeCmdCon *con)
+{
+    const gchar *alias = con->alias;
+    return g_strdup_printf (_("Unmount: %s"), alias);
+}
+
+
+static GIcon *dev_get_icon (GnomeCmdCon *con)
+{
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (GNOME_CMD_CON_DEVICE (con)));
+    return priv->icon ? g_object_ref (priv->icon) : nullptr;
+}
+
+
+static GIcon *dev_get_close_icon (GnomeCmdCon *con)
+{
+    GIcon *icon = dev_get_icon (con);
+    if (!icon)
+        return nullptr;
+
+    GIcon *unmount = g_themed_icon_new (OVERLAY_UMOUNT_ICON);
+    GEmblem *emblem = g_emblem_new (unmount);
+
+    return g_emblemed_icon_new (icon, emblem);
+}
+
+
 /*******************************
  * Gtk class implementation
  *******************************/
 
-static void destroy (GtkObject *object)
+static void dispose (GObject *object)
 {
-    GnomeCmdConDevice *con = GNOME_CMD_CON_DEVICE (object);
+    GnomeCmdConDevice *dev = GNOME_CMD_CON_DEVICE (object);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    if (con->priv->gMount)
-    {
-        g_object_unref(con->priv->gMount);
-        con->priv->gMount = nullptr;
-    }
-    if (con->priv->gVolume)
-    {
-        g_object_unref(con->priv->gVolume);
-        con->priv->gVolume = nullptr;
-    }
+    g_clear_object (&priv->gMount);
+    g_clear_object (&priv->gVolume);
 
-    g_free (con->priv);
-
-    if (GTK_OBJECT_CLASS (parent_class)->destroy)
-        (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+    G_OBJECT_CLASS (gnome_cmd_con_device_parent_class)->dispose (object);
 }
 
 
-static void class_init (GnomeCmdConDeviceClass *klass)
+static void gnome_cmd_con_device_class_init (GnomeCmdConDeviceClass *klass)
 {
-    GtkObjectClass *object_class;
-    GnomeCmdConClass *con_class;
+    GObjectClass *object_class = G_OBJECT_CLASS (klass);
+    GnomeCmdConClass *con_class = GNOME_CMD_CON_CLASS (klass);
 
-    object_class = GTK_OBJECT_CLASS (klass);
-    con_class = GNOME_CMD_CON_CLASS (klass);
-    parent_class = static_cast<GnomeCmdConClass*> (gtk_type_class (GNOME_CMD_TYPE_CON));
-
-    object_class->destroy = destroy;
+    object_class->dispose = dispose;
 
     con_class->open = dev_open;
     con_class->close = dev_close;
@@ -485,15 +523,21 @@ static void class_init (GnomeCmdConDeviceClass *klass)
     con_class->open_is_needed = dev_open_is_needed;
     con_class->create_gfile = dev_create_gfile;
     con_class->create_path = dev_create_path;
+
+    con_class->get_go_text = dev_get_go_text;
+    con_class->get_open_text = dev_get_open_text;
+    con_class->get_close_text = dev_get_close_text;
+
+    con_class->get_go_icon = dev_get_icon;
+    con_class->get_open_icon = dev_get_icon;
+    con_class->get_close_icon = dev_get_close_icon;
 }
 
 
-static void init (GnomeCmdConDevice *dev_con)
+static void gnome_cmd_con_device_init (GnomeCmdConDevice *dev_con)
 {
     GnomeCmdCon *con = GNOME_CMD_CON (dev_con);
 
-    dev_con->priv = g_new0 (GnomeCmdConDevicePrivate, 1);
-
     con->method = CON_FILE;
     con->should_remember_dir = TRUE;
     con->needs_open_visprog = FALSE;
@@ -501,52 +545,24 @@ static void init (GnomeCmdConDevice *dev_con)
     con->can_show_free_space = TRUE;
     con->is_local = TRUE;
     con->is_closeable = TRUE;
-    con->go_pixmap = nullptr;
-    con->open_pixmap = nullptr;
-    con->close_pixmap = nullptr;
 }
 
-
 /***********************************
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_con_device_get_type ()
-{
-    static GtkType type = 0;
-
-    if (type == 0)
-    {
-        GtkTypeInfo info =
-        {
-            (gchar *) "GnomeCmdConDevice",
-            sizeof (GnomeCmdConDevice),
-            sizeof (GnomeCmdConDeviceClass),
-            (GtkClassInitFunc) class_init,
-            (GtkObjectInitFunc) init,
-            /* reserved_1 */ nullptr,
-            /* reserved_2 */ nullptr,
-            (GtkClassInitFunc) nullptr
-        };
-
-        type = gtk_type_unique (GNOME_CMD_TYPE_CON, &info);
-    }
-    return type;
-}
-
-
-GnomeCmdConDevice *gnome_cmd_con_device_new (const gchar *alias, const gchar *device_fn, const gchar *mountp, const gchar *icon_path)
+GnomeCmdConDevice *gnome_cmd_con_device_new (const gchar *alias, const gchar *device_fn, const gchar *mountp, GIcon *icon)
 {
     auto dev = static_cast<GnomeCmdConDevice*> (g_object_new (GNOME_CMD_TYPE_CON_DEVICE, nullptr));
     GnomeCmdCon *con = GNOME_CMD_CON (dev);
 
     gnome_cmd_con_device_set_device_fn (dev, device_fn);
     gnome_cmd_con_device_set_mountp (dev, mountp);
-    gnome_cmd_con_device_set_icon_path (dev, icon_path);
+    gnome_cmd_con_device_set_icon (dev, icon);
     gnome_cmd_con_device_set_autovol(dev, FALSE);
     gnome_cmd_con_device_set_gmount(dev, nullptr);
     gnome_cmd_con_device_set_gvolume(dev, nullptr);
-    gnome_cmd_con_device_set_alias (dev, alias);
+    gnome_cmd_con_set_alias (con, alias);
 
     if (mountp)
         gnome_cmd_con_set_root_path (con, mountp);
@@ -557,205 +573,131 @@ GnomeCmdConDevice *gnome_cmd_con_device_new (const gchar *alias, const gchar *de
 }
 
 
-void gnome_cmd_con_device_set_alias (GnomeCmdConDevice *dev, const gchar *alias)
-{
-    g_return_if_fail (dev != nullptr);
-    g_return_if_fail (dev->priv != nullptr);
-    g_return_if_fail (alias != nullptr);
-
-    g_free (dev->priv->alias);
-
-    dev->priv->alias = g_strdup (alias);
-    GNOME_CMD_CON (dev)->alias = g_strdup (alias);
-    if (dev->priv->mountp)
-        GNOME_CMD_CON (dev)->go_text = g_strdup_printf (_("Go to: %s (%s)"), alias, dev->priv->mountp);
-    else
-        GNOME_CMD_CON (dev)->go_text = g_strdup_printf (_("Go to: %s"), alias);
-    GNOME_CMD_CON (dev)->open_text = g_strdup_printf (_("Mount: %s"), alias);
-    GNOME_CMD_CON (dev)->close_text = g_strdup_printf (_("Unmount: %s"), alias);
-}
-
-
 void gnome_cmd_con_device_set_device_fn (GnomeCmdConDevice *dev, const gchar *device_fn)
 {
     g_return_if_fail (dev != nullptr);
-    g_return_if_fail (dev->priv != nullptr);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    g_free (dev->priv->device_fn);
+    g_free (priv->device_fn);
 
-    dev->priv->device_fn = g_strdup (device_fn ? device_fn : "");
+    priv->device_fn = g_strdup (device_fn ? device_fn : "");
 }
 
 
 void gnome_cmd_con_device_set_mountp (GnomeCmdConDevice *dev, const gchar *mountp)
 {
-    g_return_if_fail (dev != nullptr);
-    g_return_if_fail (dev->priv != nullptr);
+    g_return_if_fail (GNOME_CMD_IS_CON_DEVICE (dev));
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
     if (!mountp) return;
 
-    g_free (dev->priv->mountp);
+    g_free (priv->mountp);
 
-    dev->priv->mountp = g_strdup (mountp);
+    priv->mountp = g_strdup (mountp);
 }
 
 
-void gnome_cmd_con_device_set_icon_path (GnomeCmdConDevice *dev, const gchar *icon_path)
+void gnome_cmd_con_device_set_icon (GnomeCmdConDevice *dev, GIcon *icon)
 {
-    g_return_if_fail (dev != nullptr);
-    g_return_if_fail (dev->priv != nullptr);
+    g_return_if_fail (GNOME_CMD_IS_CON_DEVICE (dev));
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    g_free (dev->priv->icon_path);
-
-    GnomeCmdCon *con = GNOME_CMD_CON (dev);
-
-    gnome_cmd_pixmap_free (con->go_pixmap);
-    gnome_cmd_pixmap_free (con->open_pixmap);
-    gnome_cmd_pixmap_free (con->close_pixmap);
-
-    con->go_pixmap = nullptr;
-    con->open_pixmap = nullptr;
-    con->close_pixmap = nullptr;
-
-    dev->priv->icon_path = g_strdup (icon_path);
-
-    if (icon_path)
-    {
-        guint dev_icon_size = gnome_cmd_data.dev_icon_size;
-
-        con->go_pixmap = gnome_cmd_pixmap_new_from_file (icon_path, dev_icon_size, dev_icon_size);
-        con->open_pixmap = gnome_cmd_pixmap_new_from_file (icon_path, dev_icon_size, dev_icon_size);
-
-        if (con->open_pixmap)
-        {
-            GdkPixbuf *overlay = gdk_pixbuf_copy (con->open_pixmap->pixbuf);
-
-            if (overlay)
-            {
-                GdkPixbuf *umount = IMAGE_get_pixbuf (PIXMAP_OVERLAY_UMOUNT);
-#if defined (__GNUC__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wsign-compare"
-#endif
-                if (umount)
-                {
-                    gdk_pixbuf_copy_area (umount, 0, 0,
-                                          MIN (gdk_pixbuf_get_width (umount), dev_icon_size),
-                                          MIN (gdk_pixbuf_get_height (umount), dev_icon_size),
-                                          overlay, 0, 0);
-
-                    con->close_pixmap = gnome_cmd_pixmap_new_from_pixbuf (overlay);
-                }
-#if defined (__GNUC__)
-#pragma GCC diagnostic pop
-#endif
-                g_object_unref (overlay);
-            }
-        }
-    }
+    g_clear_object (&priv->icon);
+    priv->icon = icon;
 }
 
 
 void gnome_cmd_con_device_set_autovol (GnomeCmdConDevice *dev, const gboolean autovol)
 {
-    g_return_if_fail (dev != nullptr);
-    g_return_if_fail (dev->priv != nullptr);
+    g_return_if_fail (GNOME_CMD_IS_CON_DEVICE (dev));
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    dev->priv->autovolume = autovol;
+    priv->autovolume = autovol;
 }
 
 
 void gnome_cmd_con_device_set_gmount (GnomeCmdConDevice *dev, GMount *gMount)
 {
-    g_return_if_fail (dev != nullptr);
-    g_return_if_fail (dev->priv != nullptr);
+    g_return_if_fail (GNOME_CMD_IS_CON_DEVICE (dev));
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    if (dev->priv->gMount)
+    if (priv->gMount)
     {
-        g_object_unref (dev->priv->gMount);
-        dev->priv->gMount = nullptr;
+        g_object_unref (priv->gMount);
+        priv->gMount = nullptr;
     }
 
-    dev->priv->gMount = gMount;
-    if (dev->priv->gMount)
-        g_object_ref(dev->priv->gMount);
+    priv->gMount = gMount;
+    if (priv->gMount)
+        g_object_ref(priv->gMount);
 }
 
 
 void gnome_cmd_con_device_set_gvolume (GnomeCmdConDevice *dev, GVolume *gVolume)
 {
-    g_return_if_fail (dev != nullptr);
-    g_return_if_fail (dev->priv != nullptr);
+    g_return_if_fail (GNOME_CMD_IS_CON_DEVICE (dev));
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    if (dev->priv->gVolume)
+    if (priv->gVolume)
     {
-        g_object_unref (dev->priv->gVolume);
-        dev->priv->gVolume = nullptr;
+        g_object_unref (priv->gVolume);
+        priv->gVolume = nullptr;
     }
 
-    dev->priv->gVolume = gVolume;
-    if (dev->priv->gVolume)
-        g_object_ref(dev->priv->gVolume);
-}
-
-
-const gchar *gnome_cmd_con_device_get_alias (GnomeCmdConDevice *dev)
-{
-    g_return_val_if_fail (dev != nullptr, nullptr);
-    g_return_val_if_fail (dev->priv != nullptr, nullptr);
-
-    return dev->priv->alias;
+    priv->gVolume = gVolume;
+    if (priv->gVolume)
+        g_object_ref(priv->gVolume);
 }
 
 
 const gchar *gnome_cmd_con_device_get_device_fn (GnomeCmdConDevice *dev)
 {
-    g_return_val_if_fail (dev != nullptr, nullptr);
-    g_return_val_if_fail (dev->priv != nullptr, nullptr);
+    g_return_val_if_fail (GNOME_CMD_IS_CON_DEVICE (dev), nullptr);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    return dev->priv->device_fn != nullptr ? dev->priv->device_fn : "";
+    return priv->device_fn != nullptr ? priv->device_fn : "";
 }
 
 
 const gchar *gnome_cmd_con_device_get_mountp_string (GnomeCmdConDevice *dev)
 {
-    g_return_val_if_fail (dev != nullptr, nullptr);
-    g_return_val_if_fail (dev->priv != nullptr, nullptr);
+    g_return_val_if_fail (GNOME_CMD_IS_CON_DEVICE (dev), nullptr);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    return dev->priv->mountp;
+    return priv->mountp;
 }
 
 
-const gchar *gnome_cmd_con_device_get_icon_path (GnomeCmdConDevice *dev)
+GIcon *gnome_cmd_con_device_get_icon (GnomeCmdConDevice *dev)
 {
-    g_return_val_if_fail (dev != nullptr, nullptr);
-    g_return_val_if_fail (dev->priv != nullptr, nullptr);
+    g_return_val_if_fail (GNOME_CMD_IS_CON_DEVICE (dev), nullptr);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    return dev->priv->icon_path;
+    return priv->icon;
 }
 
 
 gboolean gnome_cmd_con_device_get_autovol (GnomeCmdConDevice *dev)
 {
-    g_return_val_if_fail (dev != nullptr, FALSE);
-    g_return_val_if_fail (dev->priv != nullptr, FALSE);
+    g_return_val_if_fail (GNOME_CMD_IS_CON_DEVICE (dev), FALSE);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    return dev->priv->autovolume;
+    return priv->autovolume;
 }
 
 
 GMount *gnome_cmd_con_device_get_gmount (GnomeCmdConDevice *dev)
 {
-    g_return_val_if_fail (dev != nullptr, nullptr);
-    g_return_val_if_fail (dev->priv != nullptr, nullptr);
+    g_return_val_if_fail (GNOME_CMD_IS_CON_DEVICE (dev), nullptr);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    return dev->priv->gMount;
+    return priv->gMount;
 }
 
 GVolume *gnome_cmd_con_device_get_gvolume (GnomeCmdConDevice *dev)
 {
-    g_return_val_if_fail (dev != nullptr, nullptr);
-    g_return_val_if_fail (dev->priv != nullptr, nullptr);
+    g_return_val_if_fail (GNOME_CMD_IS_CON_DEVICE (dev), nullptr);
+    auto priv = static_cast<GnomeCmdConDevicePrivate *> (gnome_cmd_con_device_get_instance_private (dev));
 
-    return dev->priv->gVolume;
+    return priv->gVolume;
 }
