@@ -30,8 +30,7 @@
 using namespace std;
 
 
-static GnomeCmdConClass *parent_class = nullptr;
-
+G_DEFINE_TYPE (GnomeCmdConHome, gnome_cmd_con_home, GNOME_CMD_TYPE_CON)
 
 
 static void home_open (GnomeCmdCon *con)
@@ -68,46 +67,57 @@ static GnomeCmdPath *home_create_path (GnomeCmdCon *con, const gchar *path_str)
 }
 
 
+static gchar *home_get_go_text (GnomeCmdCon *con)
+{
+    return g_strdup (_("Go to: Home"));
+}
+
+
+static gchar *home_get_open_text (GnomeCmdCon *con)
+{
+    return nullptr;
+}
+
+
+static gchar *home_get_close_text (GnomeCmdCon *con)
+{
+    return nullptr;
+}
+
+
+static GIcon *home_get_icon (GnomeCmdCon *con)
+{
+    return g_themed_icon_new ("user-home");
+}
+
 
 /*******************************
  * Gtk class implementation
  *******************************/
 
-static void destroy (GtkObject *object)
+static void gnome_cmd_con_home_class_init (GnomeCmdConHomeClass *klass)
 {
-    GnomeCmdConHome *con_home = GNOME_CMD_CON_HOME (object);
-
-    gnome_cmd_pixmap_free (con_home->parent.go_pixmap);
-    gnome_cmd_pixmap_free (con_home->parent.open_pixmap);
-    gnome_cmd_pixmap_free (con_home->parent.close_pixmap);
-
-    if (GTK_OBJECT_CLASS (parent_class)->destroy)
-        (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
-}
-
-
-static void class_init (GnomeCmdConHomeClass *klass)
-{
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GnomeCmdConClass *con_class = GNOME_CMD_CON_CLASS (klass);
 
-    parent_class = static_cast<GnomeCmdConClass*>(gtk_type_class (GNOME_CMD_TYPE_CON));
-
-    object_class->destroy = destroy;
-
     con_class->open = home_open;
     con_class->close = home_close;
     con_class->cancel_open = home_cancel_open;
     con_class->open_is_needed = home_open_is_needed;
     con_class->create_gfile = home_create_gfile;
     con_class->create_path = home_create_path;
+
+    con_class->get_go_text = home_get_go_text;
+    con_class->get_open_text = home_get_open_text;
+    con_class->get_close_text = home_get_close_text;
+
+    con_class->get_go_icon = home_get_icon;
+    con_class->get_open_icon = home_get_icon;
+    con_class->get_close_icon = home_get_icon;
 }
 
 
-static void init (GnomeCmdConHome *home_con)
+static void gnome_cmd_con_home_init (GnomeCmdConHome *home_con)
 {
-    guint dev_icon_size = gnome_cmd_data.dev_icon_size;
-
     GnomeCmdCon *con = GNOME_CMD_CON (home_con);
 
     con->state = GnomeCmdCon::STATE_OPEN;
@@ -120,46 +130,16 @@ static void init (GnomeCmdConHome *home_con)
     con->can_show_free_space = TRUE;
     con->is_local = TRUE;
     con->is_closeable = FALSE;
-    con->go_text = g_strdup (_("Go to: Home"));
-    con->go_pixmap = gnome_cmd_pixmap_new_from_icon ("user-home", dev_icon_size);
-    con->open_pixmap = gnome_cmd_pixmap_new_from_icon ("user-home", dev_icon_size);
-    con->close_pixmap = gnome_cmd_pixmap_new_from_icon ("user-home", dev_icon_size);
 
     GnomeCmdDir *dir = gnome_cmd_dir_new (con, new GnomeCmdPlainPath(g_get_home_dir ()));
 
     gnome_cmd_con_set_default_dir (con, dir);
 }
 
-
-
 /***********************************
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_con_home_get_type ()
-{
-    static GtkType type = 0;
-
-    if (type == 0)
-    {
-        GtkTypeInfo info =
-        {
-            (gchar*) "GnomeCmdConHome",
-            sizeof (GnomeCmdConHome),
-            sizeof (GnomeCmdConHomeClass),
-            (GtkClassInitFunc) class_init,
-            (GtkObjectInitFunc) init,
-            /* reserved_1 */ nullptr,
-            /* reserved_2 */ nullptr,
-            (GtkClassInitFunc) nullptr
-        };
-
-        type = gtk_type_unique (GNOME_CMD_TYPE_CON, &info);
-    }
-    return type;
-}
-
-
 GnomeCmdCon *gnome_cmd_con_home_new ()
 {
     auto con = static_cast<GnomeCmdConHome*>(g_object_new (GNOME_CMD_TYPE_CON_HOME, nullptr));
