@@ -34,19 +34,18 @@
 #define GNOME_CMD_CON_LIST_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_CON_LIST, GnomeCmdConListClass))
 
 
-GtkType gnome_cmd_con_list_get_type ();
+GType gnome_cmd_con_list_get_type ();
 
 
 struct GnomeCmdConList
 {
-    GtkObject parent;
+    GObject parent;
 
     class Private;
 
     Private *priv;
 
     operator GObject * () const         {  return G_OBJECT (this);    }
-    operator GtkObject * () const       {  return GTK_OBJECT (this);  }
 
     void lock();
     void unlock();
@@ -70,7 +69,7 @@ struct GnomeCmdConList
 
 struct GnomeCmdConListClass
 {
-    GtkObjectClass parent_class;
+    GObjectClass parent_class;
 
     /* signals */
     void (* list_changed) (GnomeCmdConList *list);
@@ -99,6 +98,8 @@ GList *gnome_cmd_con_list_get_all_quick_ftp (GnomeCmdConList *list);
 GList *gnome_cmd_con_list_get_all_dev (GnomeCmdConList *list);
 void gnome_cmd_con_list_set_all_dev (GnomeCmdConList *list, GList *dev_cons);
 
+GnomeCmdCon *gnome_cmd_con_list_find_by_uuid (GnomeCmdConList *con_list, const gchar *uuid);
+
 inline GnomeCmdCon *get_home_con ()
 {
     return gnome_cmd_con_list_get()->get_home();
@@ -116,4 +117,4 @@ inline GList *get_remote_cons ()
     return gnome_cmd_con_list_get_all_remote (gnome_cmd_con_list_get ());
 }
 
-GnomeCmdCon *get_remote_con_for_gfile(GFile *gFile);
\ No newline at end of file
+GnomeCmdCon *get_remote_con_for_gfile(GFile *gFile);
