@@ -32,6 +32,7 @@ using namespace std;
 
 struct GnomeCmdConPrivate
 {
+    gchar          *uuid;
     GnomeCmdDir    *default_dir;   // the start dir of this connection
     History        *dir_history;
     GnomeCmdBookmarkGroup *bookmarks;
@@ -50,7 +51,8 @@ enum
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-static GtkObjectClass *parent_class = nullptr;
+
+G_DEFINE_TYPE_WITH_PRIVATE (GnomeCmdCon, gnome_cmd_con, G_TYPE_OBJECT)
 
 
 // Keep this in sync with enum ConnectionMethodID in gnome-cmd-con.h
@@ -85,83 +87,84 @@ static void on_open_failed (GnomeCmdCon *con)
  * Gtk class implementation
  *******************************/
 
-static void destroy (GtkObject *object)
+static void dispose (GObject *object)
 {
     GnomeCmdCon *con = GNOME_CMD_CON (object);
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
 
-    g_free (con->alias);
-    g_free (con->uri);
-    g_free (con->scheme);
+    g_clear_pointer (&priv->uuid, g_free);
+    g_clear_pointer (&con->alias, g_free);
+    g_clear_pointer (&con->uri, g_free);
+    g_clear_pointer (&con->scheme, g_free);
 
-    delete con->base_path;
-    g_string_free (con->root_path, TRUE);
-    g_free (con->open_text);
-    g_free (con->open_tooltip);
-    gnome_cmd_pixmap_free (con->open_pixmap);
-    g_free (con->close_text);
-    g_free (con->close_tooltip);
-    g_object_unref(con->base_gFileInfo);
-    g_error_free(con->open_failed_error);
-    con->open_failed_msg = nullptr;
-    gnome_cmd_pixmap_free (con->close_pixmap);
-    gnome_cmd_pixmap_free (con->go_pixmap);
+    if (con->base_path != nullptr)
+    {
+        delete con->base_path;
+        con->base_path = nullptr;
+    }
+    if (con->root_path != nullptr)
+    {
+        g_string_free (con->root_path, TRUE);
+        con->root_path = nullptr;
+    }
+    g_clear_object (&con->base_gFileInfo);
+    g_clear_error (&con->open_failed_error);
 
-    if (con->priv->default_dir)
-        gnome_cmd_dir_unref (con->priv->default_dir);
+    g_clear_pointer (&priv->default_dir, gnome_cmd_dir_unref);
 
-    delete con->priv->dir_history;
+    if (priv->dir_history != nullptr)
+    {
+        delete priv->dir_history;
+        priv->dir_history = nullptr;
+    }
 
-    g_free (con->priv);
-
-    if (GTK_OBJECT_CLASS (parent_class)->destroy)
-        (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+    G_OBJECT_CLASS (gnome_cmd_con_parent_class)->dispose (object);
 }
 
 
-static void class_init (GnomeCmdConClass *klass)
+static void gnome_cmd_con_class_init (GnomeCmdConClass *klass)
 {
-    GtkObjectClass *object_class;
-
-    object_class = GTK_OBJECT_CLASS (klass);
-    parent_class = (GtkObjectClass *) gtk_type_class (gtk_object_get_type ());
-
     signals[UPDATED] =
-        gtk_signal_new ("updated",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdConClass, updated),
-            gtk_marshal_NONE__NONE,
-            GTK_TYPE_NONE,
+        g_signal_new ("updated",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdConClass, updated),
+            nullptr, nullptr,
+            g_cclosure_marshal_VOID__VOID,
+            G_TYPE_NONE,
             0);
 
     signals[CLOSE] =
-        gtk_signal_new ("close",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdConClass, close),
-            gtk_marshal_NONE__NONE,
-            GTK_TYPE_NONE,
+        g_signal_new ("close",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdConClass, close),
+            nullptr, nullptr,
+            g_cclosure_marshal_VOID__VOID,
+            G_TYPE_NONE,
             0);
 
     signals[OPEN_DONE] =
-        gtk_signal_new ("open-done",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdConClass, open_done),
-            gtk_marshal_NONE__NONE,
-            GTK_TYPE_NONE,
+        g_signal_new ("open-done",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdConClass, open_done),
+            nullptr, nullptr,
+            g_cclosure_marshal_VOID__VOID,
+            G_TYPE_NONE,
             0);
 
     signals[OPEN_FAILED] =
-        gtk_signal_new ("open-failed",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdConClass, open_failed),
-            gtk_marshal_NONE__NONE,
-            GTK_TYPE_NONE,
+        g_signal_new ("open-failed",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdConClass, open_failed),
+            nullptr, nullptr,
+            g_cclosure_marshal_VOID__VOID,
+            G_TYPE_NONE,
             0);
 
-    object_class->destroy = destroy;
+    G_OBJECT_CLASS (klass)->dispose = dispose;
 
     klass->updated = nullptr;
     klass->open_done = on_open_done;
@@ -173,11 +176,25 @@ static void class_init (GnomeCmdConClass *klass)
     klass->open_is_needed = nullptr;
     klass->create_gfile = nullptr;
     klass->create_path = nullptr;
+
+    klass->get_go_text = nullptr;
+    klass->get_open_text = nullptr;
+    klass->get_close_text = nullptr;
+    klass->get_go_tooltip = nullptr;
+    klass->get_open_tooltip = nullptr;
+    klass->get_close_tooltip = nullptr;
+    klass->get_go_icon = nullptr;
+    klass->get_open_icon = nullptr;
+    klass->get_close_icon = nullptr;
 }
 
 
-static void init (GnomeCmdCon *con)
+static void gnome_cmd_con_init (GnomeCmdCon *con)
 {
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
+
+    priv->uuid = g_uuid_string_random ();
+
     con->alias = nullptr;
     con->uri = nullptr;
     con->scheme = nullptr;
@@ -192,59 +209,32 @@ static void init (GnomeCmdCon *con)
     con->can_show_free_space = FALSE;
     con->is_local = FALSE;
     con->is_closeable = FALSE;
-    con->go_text = nullptr;
-    con->go_tooltip = nullptr;
-    con->go_pixmap = nullptr;
-    con->open_text = nullptr;
-    con->open_tooltip = nullptr;
-    con->open_pixmap = nullptr;
-    con->close_text = nullptr;
-    con->close_tooltip = nullptr;
-    con->close_pixmap = nullptr;
 
     con->state = GnomeCmdCon::STATE_CLOSED;
     con->open_result = GnomeCmdCon::OPEN_NOT_STARTED;
     con->open_failed_msg = nullptr;
     con->open_failed_error = nullptr;
 
-    con->priv = g_new0 (GnomeCmdConPrivate, 1);
-    con->priv->default_dir = nullptr;
-    con->priv->dir_history = new History(20);
-    con->priv->bookmarks = g_new0 (GnomeCmdBookmarkGroup, 1);
-    con->priv->bookmarks->con = con;
-    // con->priv->bookmarks->bookmarks = nullptr;
-    // con->priv->bookmarks->data = nullptr;
-    con->priv->all_dirs = nullptr;
-    con->priv->all_dirs_map = nullptr;
+    priv->default_dir = nullptr;
+    priv->dir_history = new History(20);
+    priv->bookmarks = g_new0 (GnomeCmdBookmarkGroup, 1);
+    priv->bookmarks->con = con;
+    // priv->bookmarks->bookmarks = nullptr;
+    // priv->bookmarks->data = nullptr;
+    priv->all_dirs = nullptr;
+    priv->all_dirs_map = nullptr;
 }
 
 
-
 /***********************************
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_con_get_type ()
+const gchar *gnome_cmd_con_get_uuid (GnomeCmdCon *con)
 {
-    static GtkType type = 0;
-
-    if (type == 0)
-    {
-        GtkTypeInfo info =
-        {
-            (gchar*) "GnomeCmdCon",
-            sizeof (GnomeCmdCon),
-            sizeof (GnomeCmdConClass),
-            (GtkClassInitFunc) class_init,
-            (GtkObjectInitFunc) init,
-            /* reserved_1 */ nullptr,
-            /* reserved_2 */ nullptr,
-            (GtkClassInitFunc) nullptr
-        };
-
-        type = gtk_type_unique (gtk_object_get_type (), &info);
-    }
-    return type;
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
+    return priv->uuid;
 }
 
 
@@ -271,7 +261,7 @@ static gboolean check_con_open_progress (GnomeCmdCon *con)
                 gnome_cmd_con_set_default_dir (con, dir);
 
                 DEBUG ('m', "Emitting 'open-done' signal\n");
-                gtk_signal_emit (GTK_OBJECT (con), signals[OPEN_DONE]);
+                g_signal_emit (con, signals[OPEN_DONE], 0);
             }
             return FALSE;
 
@@ -279,7 +269,7 @@ static gboolean check_con_open_progress (GnomeCmdCon *con)
             {
                 DEBUG ('m', "GnomeCmdCon::OPEN_FAILED detected\n");
                 DEBUG ('m', "Emitting 'open-failed' signal\n");
-                gtk_signal_emit (GTK_OBJECT (con), signals[OPEN_FAILED]);
+                g_signal_emit (con, signals[OPEN_FAILED], 0);
             }
             return FALSE;
 
@@ -379,8 +369,8 @@ gboolean gnome_cmd_con_close (GnomeCmdCon *con)
 
     if (gnome_cmd_con_is_closeable (con) && gnome_cmd_con_is_open(con))
     {
-        gtk_signal_emit (GTK_OBJECT (con), signals[CLOSE]);
-        gtk_signal_emit (GTK_OBJECT (con), signals[UPDATED]);
+        g_signal_emit (con, signals[CLOSE], 0);
+        g_signal_emit (con, signals[UPDATED], 0);
     }
 
     return TRUE;
@@ -410,39 +400,43 @@ GnomeCmdPath *gnome_cmd_con_create_path (GnomeCmdCon *con, const gchar *path_str
 void gnome_cmd_con_set_default_dir (GnomeCmdCon *con, GnomeCmdDir *dir)
 {
     g_return_if_fail (GNOME_CMD_IS_CON (con));
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
 
-    if (dir == con->priv->default_dir)
+    if (dir == priv->default_dir)
         return;
 
     if (dir)
         gnome_cmd_dir_ref (dir);
-    if (con->priv->default_dir)
-        gnome_cmd_dir_unref (con->priv->default_dir);
-    con->priv->default_dir = dir;
+    if (priv->default_dir)
+        gnome_cmd_dir_unref (priv->default_dir);
+    priv->default_dir = dir;
 }
 
 
 GnomeCmdDir *gnome_cmd_con_get_default_dir (GnomeCmdCon *con)
 {
     g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
 
-    return con->priv->default_dir;
+    return priv->default_dir;
 }
 
 
 History *gnome_cmd_con_get_dir_history (GnomeCmdCon *con)
 {
     g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
 
-    return con->priv->dir_history;
+    return priv->dir_history;
 }
 
 
 GnomeCmdBookmarkGroup *gnome_cmd_con_get_bookmarks (GnomeCmdCon *con)
 {
     g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
 
-    return con->priv->bookmarks;
+    return priv->bookmarks;
 }
 
 
@@ -462,8 +456,9 @@ void gnome_cmd_con_erase_bookmark (GnomeCmdCon *con)
     if (!con)
         return;
     g_return_if_fail (GNOME_CMD_IS_CON (con));
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
 
-    GnomeCmdBookmarkGroup *group = con->priv->bookmarks;
+    GnomeCmdBookmarkGroup *group = priv->bookmarks;
     for(GList *l = group->bookmarks; l; l = l->next)
     {
         auto bookmark = static_cast<GnomeCmdBookmark*> (l->data);
@@ -472,8 +467,8 @@ void gnome_cmd_con_erase_bookmark (GnomeCmdCon *con)
         g_free (bookmark);
     }
     g_list_free(group->bookmarks);
-    con->priv->bookmarks = g_new0 (GnomeCmdBookmarkGroup, 1);
-    con->priv->bookmarks->con = con;
+    priv->bookmarks = g_new0 (GnomeCmdBookmarkGroup, 1);
+    priv->bookmarks->con = con;
 }
 
 
@@ -481,7 +476,7 @@ void gnome_cmd_con_updated (GnomeCmdCon *con)
 {
     g_return_if_fail (GNOME_CMD_IS_CON (con));
 
-    gtk_signal_emit (GTK_OBJECT (con), signals[UPDATED]);
+    g_signal_emit (con, signals[UPDATED], 0);
 }
 
 
@@ -543,6 +538,7 @@ void gnome_cmd_con_add_to_cache (GnomeCmdCon *con, GnomeCmdDir *dir, gchar *uri_
 {
     g_return_if_fail (GNOME_CMD_IS_CON (con));
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
 
     if (!uri_str)
     {
@@ -554,11 +550,11 @@ void gnome_cmd_con_add_to_cache (GnomeCmdCon *con, GnomeCmdDir *dir, gchar *uri_
         return;
     }
 
-    if (!con->priv->all_dirs_map)
-        con->priv->all_dirs_map = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, nullptr);
+    if (!priv->all_dirs_map)
+        priv->all_dirs_map = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, nullptr);
 
     DEBUG ('k', "ADDING %p %s to the cache\n", dir, uri_str);
-    g_hash_table_insert (con->priv->all_dirs_map, uri_str, dir);
+    g_hash_table_insert (priv->all_dirs_map, uri_str, dir);
 }
 
 
@@ -566,11 +562,12 @@ void gnome_cmd_con_remove_from_cache (GnomeCmdCon *con, GnomeCmdDir *dir)
 {
     g_return_if_fail (GNOME_CMD_IS_CON (con));
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
 
     gchar *uri_str = GNOME_CMD_FILE (dir)->get_uri_str();
 
     DEBUG ('k', "REMOVING %p %s from the cache\n", dir, uri_str);
-    g_hash_table_remove (con->priv->all_dirs_map, uri_str);
+    g_hash_table_remove (priv->all_dirs_map, uri_str);
     g_free (uri_str);
 }
 
@@ -579,9 +576,10 @@ void gnome_cmd_con_remove_from_cache (GnomeCmdCon *con, const gchar *uri_str)
 {
     g_return_if_fail (GNOME_CMD_IS_CON (con));
     g_return_if_fail (uri_str != nullptr);
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
 
     DEBUG ('k', "REMOVING %s from the cache\n", uri_str);
-    g_hash_table_remove (con->priv->all_dirs_map, uri_str);
+    g_hash_table_remove (priv->all_dirs_map, uri_str);
 }
 
 
@@ -589,12 +587,13 @@ GnomeCmdDir *gnome_cmd_con_cache_lookup (GnomeCmdCon *con, const gchar *uri_str)
 {
     g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
     g_return_val_if_fail (uri_str != nullptr, nullptr);
+    auto priv = static_cast<GnomeCmdConPrivate *> (gnome_cmd_con_get_instance_private (con));
 
     GnomeCmdDir *dir = nullptr;
 
-    if (con->priv->all_dirs_map)
+    if (priv->all_dirs_map)
     {
-        dir = static_cast<GnomeCmdDir*> (g_hash_table_lookup (con->priv->all_dirs_map, uri_str));
+        dir = static_cast<GnomeCmdDir*> (g_hash_table_lookup (priv->all_dirs_map, uri_str));
     }
 
     if (dir)
@@ -606,6 +605,99 @@ GnomeCmdDir *gnome_cmd_con_cache_lookup (GnomeCmdCon *con, const gchar *uri_str)
 }
 
 
+gchar *gnome_cmd_con_get_go_text (GnomeCmdCon *con)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    GnomeCmdConClass *klass = GNOME_CMD_CON_GET_CLASS (con);
+    if (klass->get_go_text)
+        return klass->get_go_text (con);
+
+    const gchar *alias = con->alias;
+    if (!alias)
+        alias = _("<New connection>");
+
+    return g_strdup_printf (_("Go to: %s"), alias);
+}
+
+
+gchar *gnome_cmd_con_get_go_tooltip (GnomeCmdCon *con)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    GnomeCmdConClass *klass = GNOME_CMD_CON_GET_CLASS (con);
+    return klass->get_go_tooltip ? klass->get_go_tooltip (con) : nullptr;
+}
+
+
+GIcon *gnome_cmd_con_get_go_icon (GnomeCmdCon *con)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    GnomeCmdConClass *klass = GNOME_CMD_CON_GET_CLASS (con);
+    return klass->get_go_icon ? klass->get_go_icon (con) : nullptr;
+}
+
+
+gchar *gnome_cmd_con_get_open_text (GnomeCmdCon *con)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    GnomeCmdConClass *klass = GNOME_CMD_CON_GET_CLASS (con);
+    if (klass->get_open_text)
+        return klass->get_open_text (con);
+
+    const gchar *alias = con->alias;
+    if (!alias)
+        alias = _("<New connection>");
+
+    return g_strdup_printf (_("Connect to: %s"), alias);
+}
+
+
+gchar *gnome_cmd_con_get_open_tooltip (GnomeCmdCon *con)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    GnomeCmdConClass *klass = GNOME_CMD_CON_GET_CLASS (con);
+    return klass->get_open_tooltip ? klass->get_open_tooltip (con) : nullptr;
+}
+
+
+GIcon *gnome_cmd_con_get_open_icon (GnomeCmdCon *con)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    GnomeCmdConClass *klass = GNOME_CMD_CON_GET_CLASS (con);
+    return klass->get_open_icon ? klass->get_open_icon (con) : nullptr;
+}
+
+
+gchar *gnome_cmd_con_get_close_text (GnomeCmdCon *con)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    GnomeCmdConClass *klass = GNOME_CMD_CON_GET_CLASS (con);
+    if (klass->get_close_text)
+        return klass->get_close_text (con);
+
+    const gchar *alias = con->alias;
+    if (!alias)
+        alias = _("<New connection>");
+
+    return g_strdup_printf (_("Disconnect from: %s"), alias);
+}
+
+
+gchar *gnome_cmd_con_get_close_tooltip (GnomeCmdCon *con)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    GnomeCmdConClass *klass = GNOME_CMD_CON_GET_CLASS (con);
+    return klass->get_close_tooltip ? klass->get_close_tooltip (con) : nullptr;
+}
+
+
+GIcon *gnome_cmd_con_get_close_icon (GnomeCmdCon *con)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), nullptr);
+    GnomeCmdConClass *klass = GNOME_CMD_CON_GET_CLASS (con);
+    return klass->get_close_icon ? klass->get_close_icon (con) : nullptr;
+}
+
+
 const gchar *gnome_cmd_con_get_icon_name (ConnectionMethodID method)
 {
     return icon_name[method];
@@ -696,3 +788,4 @@ void gnome_cmd_con_close_active_or_inactive_connection (GMount *gMount)
     g_free(uriString);
     g_object_unref(gFile);
 }
+
