@@ -28,8 +28,6 @@
 #define GNOME_CMD_IS_CON_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_CON))
 #define GNOME_CMD_CON_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_CON, GnomeCmdConClass))
 
-struct GnomeCmdConPrivate;
-
 #include <string>
 
 #include "gnome-cmd-path.h"
@@ -56,7 +54,7 @@ enum ConnectionMethodID        // Keep this order in sync with strings in gnome-
 
 struct GnomeCmdCon
 {
-    GtkObject parent;
+    GObject parent;
 
     enum State
     {
@@ -94,26 +92,15 @@ struct GnomeCmdCon
     State               state;
     gboolean            is_local;
     gboolean            is_closeable;
-    gchar               *go_text;
-    gchar               *go_tooltip;
-    GnomeCmdPixmap      *go_pixmap;
-    gchar               *open_text;
-    gchar               *open_tooltip;
-    GnomeCmdPixmap      *open_pixmap;
-    gchar               *close_text;
-    gchar               *close_tooltip;
-    GnomeCmdPixmap      *close_pixmap;
 
     OpenResult          open_result;
     GError              *open_failed_error;
     gchar               *open_failed_msg;
-
-    GnomeCmdConPrivate  *priv;
 };
 
 struct GnomeCmdConClass
 {
-    GtkObjectClass parent_class;
+    GObjectClass parent_class;
 
     /* signals */
     void (* updated) (GnomeCmdCon *con);
@@ -127,10 +114,22 @@ struct GnomeCmdConClass
     gboolean (* open_is_needed) (GnomeCmdCon *con);
     GFile *(* create_gfile) (GnomeCmdCon *con, GnomeCmdPath *path);
     GnomeCmdPath *(* create_path) (GnomeCmdCon *con, const gchar *path_str);
+
+    gchar *(* get_go_text) (GnomeCmdCon *con);
+    gchar *(* get_open_text) (GnomeCmdCon *con);
+    gchar *(* get_close_text) (GnomeCmdCon *con);
+    gchar *(* get_go_tooltip) (GnomeCmdCon *con);
+    gchar *(* get_open_tooltip) (GnomeCmdCon *con);
+    gchar *(* get_close_tooltip) (GnomeCmdCon *con);
+    GIcon *(* get_go_icon) (GnomeCmdCon *con);
+    GIcon *(* get_open_icon) (GnomeCmdCon *con);
+    GIcon *(* get_close_icon) (GnomeCmdCon *con);
 };
 
 
-GtkType gnome_cmd_con_get_type ();
+GType gnome_cmd_con_get_type ();
+
+const gchar *gnome_cmd_con_get_uuid (GnomeCmdCon *con);
 
 void gnome_cmd_con_set_base_path(GnomeCmdCon *con, GnomeCmdPath *path);
 void set_con_base_path_for_gmount(GnomeCmdCon *con, GMount *gMount);
@@ -216,13 +215,6 @@ inline void gnome_cmd_con_set_alias (GnomeCmdCon *con, const gchar *alias=NULL)
     g_return_if_fail (GNOME_CMD_IS_CON (con));
     g_free (con->alias);
     con->alias = g_strdup (alias);
-
-    if (!alias)
-        alias = _("<New connection>");
-
-    con->go_text = g_strdup_printf (_("Go to: %s"), alias);
-    con->open_text = g_strdup_printf (_("Connect to: %s"), alias);
-    con->close_text = g_strdup_printf (_("Disconnect from: %s"), alias);
 }
 
 inline const char *gnome_cmd_con_get_user_name (GnomeCmdCon *con)
@@ -323,60 +315,15 @@ inline gboolean gnome_cmd_con_is_closeable (GnomeCmdCon *con)
 
 History *gnome_cmd_con_get_dir_history (GnomeCmdCon *con);
 
-inline const gchar *gnome_cmd_con_get_go_text (GnomeCmdCon *con)
-{
-    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
-    return con->go_text;
-}
-
-inline const gchar *gnome_cmd_con_get_open_text (GnomeCmdCon *con)
-{
-    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
-    return con->open_text;
-}
-
-inline const gchar *gnome_cmd_con_get_close_text (GnomeCmdCon *con)
-{
-    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
-
-    return con->close_text;
-}
-
-inline const gchar *gnome_cmd_con_get_go_tooltip (GnomeCmdCon *con)
-{
-    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
-    return con->go_tooltip;
-}
-
-inline const gchar *gnome_cmd_con_get_open_tooltip (GnomeCmdCon *con)
-{
-    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
-    return con->open_tooltip;
-}
-
-inline const gchar *gnome_cmd_con_get_close_tooltip (GnomeCmdCon *con)
-{
-    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
-    return con->close_tooltip;
-}
-
-inline GnomeCmdPixmap *gnome_cmd_con_get_go_pixmap (GnomeCmdCon *con)
-{
-    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
-    return con->go_pixmap;
-}
-
-inline GnomeCmdPixmap *gnome_cmd_con_get_open_pixmap (GnomeCmdCon *con)
-{
-    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
-    return con->open_pixmap;
-}
-
-inline GnomeCmdPixmap *gnome_cmd_con_get_close_pixmap (GnomeCmdCon *con)
-{
-    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
-    return con->close_pixmap;
-}
+gchar *gnome_cmd_con_get_go_text (GnomeCmdCon *con);
+gchar *gnome_cmd_con_get_open_text (GnomeCmdCon *con);
+gchar *gnome_cmd_con_get_close_text (GnomeCmdCon *con);
+gchar *gnome_cmd_con_get_go_tooltip (GnomeCmdCon *con);
+gchar *gnome_cmd_con_get_open_tooltip (GnomeCmdCon *con);
+gchar *gnome_cmd_con_get_close_tooltip (GnomeCmdCon *con);
+GIcon *gnome_cmd_con_get_go_icon (GnomeCmdCon *con);
+GIcon *gnome_cmd_con_get_open_icon (GnomeCmdCon *con);
+GIcon *gnome_cmd_con_get_close_icon (GnomeCmdCon *con);
 
 GnomeCmdBookmarkGroup *gnome_cmd_con_get_bookmarks (GnomeCmdCon *con);
 
