@@ -2,7 +2,7 @@
  * @file gnome-cmd-convert.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2023 Uwe Scholz\n
+ * @copyright (C) 2013-2024 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -148,7 +148,7 @@ gchar *gcmd_convert_sentence_case (gchar *string)
         NULL
     };
 
-    gcmd_convert_lowercase (string);
+    string = gcmd_convert_lowercase (string);
 
     // Removes trailing whitespace
     gchar *i = string = g_strchomp (string);
