@@ -30,23 +30,20 @@
 #define GNOME_CMD_DIR_INDICATOR_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_DIR_INDICATOR, GnomeCmdDirIndicatorClass))
 
 
-struct GnomeCmdDirIndicatorPrivate;
-
-
 struct GnomeCmdDirIndicator
 {
     GtkFrame parent;
-
-    GnomeCmdDirIndicatorPrivate *priv;
 };
 
 struct GnomeCmdDirIndicatorClass
 {
     GtkFrameClass parent_class;
+
+    void (*navigate) (const gchar *path, gboolean new_tab);
 };
 
 
-GtkType gnome_cmd_dir_indicator_get_type ();
+GType gnome_cmd_dir_indicator_get_type ();
 
 GtkWidget *gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs);
 
