@@ -23,15 +23,16 @@
 #include <gtk/gtk.h>
 
 #include "gnome-cmd-hintbox.h"
+#include "libgcmd/libgcmd-utils.h"
 
 using namespace std;
 
 
-typedef GtkHBoxClass  GnomeCmdHintBoxClass;
+typedef GtkBoxClass  GnomeCmdHintBoxClass;
 
 struct GnomeCmdHintBox
 {
-  GtkHBox    parent_instance;
+  GtkBox    parent_instance;
 
   gchar     *stock_id;
   gchar     *hint;
@@ -60,7 +61,7 @@ static void     gnome_cmd_hint_box_get_property (GObject               *object,
                                                  GValue                *value,
                                                  GParamSpec            *pspec);
 
-G_DEFINE_TYPE (GnomeCmdHintBox, gnome_cmd_hint_box, GTK_TYPE_HBOX)
+G_DEFINE_TYPE (GnomeCmdHintBox, gnome_cmd_hint_box, GTK_TYPE_BOX)
 
 #define parent_class gnome_cmd_hint_box_parent_class
 
@@ -81,7 +82,7 @@ gnome_cmd_hint_box_class_init (GnomeCmdHintBoxClass *klass)
 
   g_object_class_install_property (object_class, PROP_STOCK_ID,
                                    g_param_spec_string ("stock-id", NULL, NULL,
-                                                        GTK_STOCK_DIALOG_INFO,
+                                                        "gnome-commander-info-outline",
                                                         GParamFlags (G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE)));
   g_object_class_install_property (object_class, PROP_HINT,
                                    g_param_spec_string ("hint", NULL, NULL,
@@ -109,14 +110,15 @@ gnome_cmd_hint_box_constructor (GType                  type,
 
   box = GNOME_CMD_HINT_BOX (object);
 
+  g_object_set (box, "orientation", GTK_ORIENTATION_HORIZONTAL, NULL);
   gtk_box_set_spacing (GTK_BOX (box), 12);
 
   if (box->stock_id)
     {
-      GtkWidget *image = gtk_image_new_from_stock (box->stock_id,
+      GtkWidget *image = gtk_image_new_from_gicon (g_themed_icon_new (box->stock_id),
                                                    GTK_ICON_SIZE_DIALOG);
 
-      gtk_box_pack_start (GTK_BOX (box), image, FALSE, FALSE, 0);
+      gtk_box_append (GTK_BOX (box), image);
       gtk_widget_show (image);
     }
 
@@ -131,7 +133,7 @@ gnome_cmd_hint_box_constructor (GType                  type,
   gnome_cmd_label_set_attributes (GTK_LABEL (label),
                                   PANGO_ATTR_STYLE, PANGO_STYLE_ITALIC,
                                   -1);
-  gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (box), label);
   gtk_widget_show (label);
 
   return object;
@@ -255,7 +257,11 @@ gnome_cmd_label_set_attributes (GtkLabel *label, ...)
 
   do
     {
-      PangoAttrType   attr_type = ( PangoAttrType) va_arg (args, gint);
+      gint next = va_arg (args, gint);
+      if (next == -1)
+        break;
+
+      PangoAttrType attr_type = (PangoAttrType) next;
 
 #if defined (__GNUC__)
 #pragma GCC diagnostic push
