@@ -35,12 +35,12 @@
 #define GNOME_CMD_MAIN_WIN_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_MAIN_WIN, GnomeCmdMainWinClass))
 
 
-GtkType gnome_cmd_main_win_get_type ();
+GType gnome_cmd_main_win_get_type ();
 
 
 struct GnomeCmdMainWin
 {
-    GtkWindow parent;
+    GtkApplicationWindow parent;
 
   public:       //  FIXME:  change to private
 
@@ -57,7 +57,7 @@ struct GnomeCmdMainWin
     void operator delete (void *p)      {  g_object_unref (p);  }
 
     operator GObject * () const         {  return G_OBJECT (this);         }
-    operator GtkObject * () const       {  return GTK_OBJECT (this);       }
+    operator GActionGroup * () const    {  return G_ACTION_GROUP (this);   }
     operator GtkWidget * () const       {  return GTK_WIDGET (this);       }
     operator GtkWindow * () const       {  return GTK_WINDOW (this);       }
 
@@ -68,7 +68,7 @@ struct GnomeCmdMainWin
     FileSelectorID fs(GnomeCmdFileSelector *fs) const;
     GnomeCmdFileSelector *fs(FileSelectorID id) const;
 
-    gboolean key_pressed (GdkEventKey *event);
+    gboolean key_pressed (GnomeCmdKeyPress *event);
 
     void open_tabs(FileSelectorID id);
 
@@ -77,6 +77,7 @@ struct GnomeCmdMainWin
 
     void set_fs_directory_to_opposite(FileSelectorID fsID);
 
+    void set_slide(gint percentage);
     void set_equal_panes();
     void maximize_pane();
     GnomeCmdState *get_state() const;
@@ -89,14 +90,16 @@ struct GnomeCmdMainWin
 
     void update_view();
     void update_style();
+    void update_mainmenu();
     void update_bookmarks();
     void update_show_toolbar();
+    void update_cmdline();
     void update_cmdline_visibility();
     void update_buttonbar_visibility();
     void update_horizontal_orientation();
     void update_mainmenu_visibility();
 
-    void add_plugin_menu(PluginData *data);
+    void plugins_updated();
 };
 
 extern GnomeCmdMainWin *main_win;
