@@ -25,7 +25,6 @@
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-selection-profile-component.h"
-#include "gnome-cmd-menu-button.h"
 #include "utils.h"
 
 using namespace std;
@@ -33,13 +32,13 @@ using namespace std;
 
 struct GnomeCmdSelectionProfileComponentClass
 {
-    GtkVBoxClass parent_class;
+    GtkBoxClass parent_class;
 };
 
 
 struct GnomeCmdSelectionProfileComponent::Private
 {
-    GtkWidget *table;
+    GtkWidget *grid;
     GtkWidget *filter_type_combo;
     GtkWidget *pattern_combo;
     GtkWidget *recurse_combo;
@@ -57,7 +56,7 @@ struct GnomeCmdSelectionProfileComponent::Private
 
 inline GnomeCmdSelectionProfileComponent::Private::Private()
 {
-    table = NULL;
+    grid = NULL;
     filter_type_combo = NULL;
     pattern_combo = NULL;
     recurse_combo = NULL;
@@ -103,54 +102,68 @@ void GnomeCmdSelectionProfileComponent::Private::on_find_text_toggled(GtkToggleB
 
 static void combo_box_insert_text (const gchar *text, GtkComboBox *widget)
 {
-    gtk_combo_box_append_text (widget, text);
+    if (text == nullptr || *text == '\0')
+        return;
+
+    GtkTreeModel *store = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
+
+    GtkTreeIter iter;
+    gtk_list_store_append (GTK_LIST_STORE (store), &iter);
+    gtk_list_store_set (GTK_LIST_STORE (store), &iter, 0, text, -1);
 }
 
 
-G_DEFINE_TYPE (GnomeCmdSelectionProfileComponent, gnome_cmd_selection_profile_component, GTK_TYPE_VBOX)
+G_DEFINE_TYPE (GnomeCmdSelectionProfileComponent, gnome_cmd_selection_profile_component, GTK_TYPE_BOX)
 
 
 static void gnome_cmd_selection_profile_component_init (GnomeCmdSelectionProfileComponent *component)
 {
+    g_object_set (component, "orientation", GTK_ORIENTATION_VERTICAL, NULL);
+
     component->priv = new GnomeCmdSelectionProfileComponent::Private;
 
-    component->priv->table = gtk_table_new (5, 2, FALSE);
-    gtk_table_set_row_spacings (GTK_TABLE (component->priv->table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (component->priv->table), 6);
-    gtk_box_pack_start (GTK_BOX (component), component->priv->table, FALSE, TRUE, 0);
+    component->priv->grid = gtk_grid_new ();
+    gtk_grid_set_row_spacing (GTK_GRID (component->priv->grid), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (component->priv->grid), 6);
+    gtk_box_append (GTK_BOX (component), component->priv->grid);
 
 
     // search for
-    component->priv->filter_type_combo = gtk_combo_box_new_text ();
-    gtk_combo_box_append_text (GTK_COMBO_BOX (component->priv->filter_type_combo), _("Path matches regex:"));
-    gtk_combo_box_append_text (GTK_COMBO_BOX (component->priv->filter_type_combo), _("Name contains:"));
-    component->priv->pattern_combo = gtk_combo_box_entry_new_text ();
-    table_add (component->priv->table, component->priv->filter_type_combo, 0, 0, GTK_FILL);
-    table_add (component->priv->table, component->priv->pattern_combo, 1, 0, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
+    component->priv->filter_type_combo = gtk_combo_box_text_new ();
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (component->priv->filter_type_combo), _("Path matches regex:"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (component->priv->filter_type_combo), _("Name contains:"));
+    component->priv->pattern_combo = gtk_combo_box_new_with_model_and_entry (GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING)));
+    g_object_set (component->priv->pattern_combo, "entry-text-column", 0, nullptr);
+    gtk_grid_attach (GTK_GRID (component->priv->grid), component->priv->filter_type_combo, 0, 0, 1, 1);
+    gtk_widget_set_hexpand (component->priv->pattern_combo, TRUE);
+    gtk_grid_attach (GTK_GRID (component->priv->grid), component->priv->pattern_combo, 1, 0, 1, 1);
 
 
     // recurse check
-    component->priv->recurse_combo = gtk_combo_box_new_text ();
+    component->priv->recurse_combo = gtk_combo_box_text_new ();
 
-    gtk_combo_box_append_text (GTK_COMBO_BOX (component->priv->recurse_combo), _("Unlimited depth"));
-    gtk_combo_box_append_text (GTK_COMBO_BOX (component->priv->recurse_combo), _("Current directory only"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (component->priv->recurse_combo), _("Unlimited depth"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (component->priv->recurse_combo), _("Current directory only"));
     for (int i=1; i<=40; ++i)
     {
        gchar *item = g_strdup_printf (ngettext("%i level", "%i levels", i), i);
-       gtk_combo_box_append_text (GTK_COMBO_BOX (component->priv->recurse_combo), item);
+       combo_box_insert_text (item, GTK_COMBO_BOX (component->priv->recurse_combo));
        g_free (item);
     }
 
-    table_add (component->priv->table, create_label_with_mnemonic (*component, _("Search _recursively:"), component->priv->recurse_combo), 0, 2, GTK_FILL);
-    table_add (component->priv->table, component->priv->recurse_combo, 1, 2, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
+    gtk_grid_attach (GTK_GRID (component->priv->grid), create_label_with_mnemonic (*component, _("Search _recursively:"), component->priv->recurse_combo), 0, 2, 1, 1);
+    gtk_widget_set_hexpand (component->priv->recurse_combo, TRUE);
+    gtk_grid_attach (GTK_GRID (component->priv->grid), component->priv->recurse_combo, 1, 2, 1, 1);
 
 
     // find text
     component->priv->find_text_check = create_check_with_mnemonic (*component, _("Contains _text:"), "find_text");
-    table_add (component->priv->table, component->priv->find_text_check, 0, 3, GTK_FILL);
+    gtk_grid_attach (GTK_GRID (component->priv->grid), component->priv->find_text_check, 0, 3, 1, 1);
 
-    component->priv->find_text_combo = gtk_combo_box_entry_new_text ();
-    table_add (component->priv->table, component->priv->find_text_combo, 1, 3, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
+    component->priv->find_text_combo = gtk_combo_box_new_with_model_and_entry (GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING)));
+    g_object_set (component->priv->find_text_combo, "entry-text-column", 0, nullptr);
+    gtk_widget_set_hexpand (component->priv->find_text_combo, TRUE);
+    gtk_grid_attach (GTK_GRID (component->priv->grid), component->priv->find_text_combo, 1, 3, 1, 1);
     gtk_widget_set_sensitive (component->priv->find_text_combo, FALSE);
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (component->priv->find_text_combo), 0);
@@ -158,7 +171,7 @@ static void gnome_cmd_selection_profile_component_init (GnomeCmdSelectionProfile
 
     // case check
     component->priv->case_check = create_check_with_mnemonic (*component, _("Case sensiti_ve"), "case_check");
-    gtk_table_attach (GTK_TABLE (component->priv->table), component->priv->case_check, 1, 2, 4, 5, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (component->priv->grid), component->priv->case_check, 1, 4, 1, 1);
     gtk_widget_set_sensitive (component->priv->case_check, FALSE);
 }
 
@@ -186,8 +199,9 @@ GnomeCmdSelectionProfileComponent::GnomeCmdSelectionProfileComponent(GnomeCmdDat
     if (widget)
     {
         if (label)
-            table_add (priv->table, create_label_with_mnemonic (*this, label, widget), 0, 1, GTK_FILL);
-        table_add (priv->table, widget, 1, 1, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
+            gtk_grid_attach (GTK_GRID (priv->grid), create_label_with_mnemonic (*this, label, widget), 0, 1, 1, 1);
+        gtk_widget_set_hexpand (widget, TRUE);
+        gtk_grid_attach (GTK_GRID (priv->grid), widget, 1, 1, 1, 1);
     }
 
     // if (!profile.name_patterns.empty())
@@ -203,7 +217,7 @@ GnomeCmdSelectionProfileComponent::GnomeCmdSelectionProfileComponent(GnomeCmdDat
 
     gtk_widget_grab_focus (priv->pattern_combo);
 
-    gtk_widget_show_all (priv->table);
+    gtk_widget_show_all (priv->grid);
 
     g_signal_connect (priv->filter_type_combo, "changed", G_CALLBACK (Private::on_filter_type_changed), this);
     g_signal_connect (priv->find_text_check, "toggled", G_CALLBACK (Private::on_find_text_toggled), this);
@@ -215,20 +229,22 @@ void GnomeCmdSelectionProfileComponent::update()
     set_name_patterns_history(gnome_cmd_data.search_defaults.name_patterns.ents);
     set_content_patterns_history(gnome_cmd_data.search_defaults.content_patterns.ents);
 
-    gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (priv->pattern_combo))), profile.filename_pattern.c_str());
+    gtk_editable_set_text (GTK_EDITABLE (gtk_combo_box_get_child (GTK_COMBO_BOX (priv->pattern_combo))), profile.filename_pattern.c_str());
     gtk_combo_box_set_active (GTK_COMBO_BOX (priv->filter_type_combo), (int) profile.syntax);
     gtk_combo_box_set_active (GTK_COMBO_BOX (priv->recurse_combo), profile.max_depth+1);
-    gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (priv->find_text_combo))), profile.text_pattern.c_str());
+    gtk_editable_set_text (GTK_EDITABLE (gtk_combo_box_get_child (GTK_COMBO_BOX (priv->find_text_combo))), profile.text_pattern.c_str());
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->find_text_check), profile.content_search);
 }
 
 
 void GnomeCmdSelectionProfileComponent::copy()
 {
-    stringify(profile.filename_pattern, gtk_combo_box_get_active_text (GTK_COMBO_BOX (priv->pattern_combo)));
+    const char *pattern_text = gtk_editable_get_text (GTK_EDITABLE (gtk_combo_box_get_child (GTK_COMBO_BOX (priv->pattern_combo))));
+    stringify(profile.filename_pattern, pattern_text);
     profile.syntax = (Filter::Type) gtk_combo_box_get_active (GTK_COMBO_BOX (priv->filter_type_combo));
     profile.max_depth = gtk_combo_box_get_active (GTK_COMBO_BOX (priv->recurse_combo)) - 1;
-    stringify(profile.text_pattern, gtk_combo_box_get_active_text (GTK_COMBO_BOX (priv->find_text_combo)));
+    const char *find_text = gtk_editable_get_text (GTK_EDITABLE (gtk_combo_box_get_child (GTK_COMBO_BOX (priv->find_text_combo))));
+    stringify(profile.text_pattern, find_text);
     profile.content_search = !profile.text_pattern.empty() && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->find_text_check));
     profile.match_case = profile.content_search && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->case_check));
 }
@@ -236,10 +252,12 @@ void GnomeCmdSelectionProfileComponent::copy()
 
 void GnomeCmdSelectionProfileComponent::copy(GnomeCmdData::SearchProfile &profile_in)
 {
-    stringify(profile_in.filename_pattern, gtk_combo_box_get_active_text (GTK_COMBO_BOX (priv->pattern_combo)));
+    const char *pattern_text = gtk_editable_get_text (GTK_EDITABLE (gtk_combo_box_get_child (GTK_COMBO_BOX (priv->pattern_combo))));
+    stringify(profile_in.filename_pattern, pattern_text);
     profile_in.syntax = (Filter::Type) gtk_combo_box_get_active (GTK_COMBO_BOX (priv->filter_type_combo));
     profile_in.max_depth = gtk_combo_box_get_active (GTK_COMBO_BOX (priv->recurse_combo)) - 1;
-    stringify(profile_in.text_pattern, gtk_combo_box_get_active_text (GTK_COMBO_BOX (priv->find_text_combo)));
+    const char *find_text = gtk_editable_get_text (GTK_EDITABLE (gtk_combo_box_get_child (GTK_COMBO_BOX (priv->find_text_combo))));
+    stringify(profile_in.text_pattern, find_text);
     profile_in.content_search = !profile_in.text_pattern.empty() && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->find_text_check));
     profile_in.match_case = profile_in.content_search && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->case_check));
 }
@@ -271,6 +289,6 @@ void GnomeCmdSelectionProfileComponent::set_content_patterns_history(GList *hist
 
 void GnomeCmdSelectionProfileComponent::set_default_activation(GtkWindow *w)
 {
-    g_signal_connect_swapped (gtk_bin_get_child (GTK_BIN (priv->pattern_combo)), "activate", G_CALLBACK (gtk_window_activate_default), w);
-    g_signal_connect_swapped (gtk_bin_get_child (GTK_BIN (priv->find_text_combo)), "activate", G_CALLBACK (gtk_window_activate_default), w);
+    gtk_entry_set_activates_default (GTK_ENTRY (gtk_combo_box_get_child (GTK_COMBO_BOX (priv->pattern_combo))), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (gtk_combo_box_get_child (GTK_COMBO_BOX (priv->find_text_combo))), TRUE);
 }
