@@ -29,7 +29,7 @@
 using namespace std;
 
 
-static GtkWindowClass *parent_class = nullptr;
+G_DEFINE_TYPE(GnomeCmdXferProgressWin, gnome_cmd_xfer_progress_win, GTK_TYPE_WINDOW)
 
 
 /******************************
@@ -48,32 +48,12 @@ static void on_cancel (GtkButton *btn, GnomeCmdXferProgressWin *win)
  * Gtk class implementation
  *******************************/
 
-static void destroy (GtkObject *object)
+static void gnome_cmd_xfer_progress_win_class_init (GnomeCmdXferProgressWinClass *klass)
 {
-    if (GTK_OBJECT_CLASS (parent_class)->destroy)
-        (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
 
-static void map (GtkWidget *widget)
-{
-    if (GTK_WIDGET_CLASS (parent_class)->map != nullptr)
-        GTK_WIDGET_CLASS (parent_class)->map (widget);
-}
-
-
-static void class_init (GnomeCmdXferProgressWinClass *klass)
-{
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-
-    parent_class = (GtkWindowClass *) gtk_type_class (gtk_window_get_type ());
-    object_class->destroy = destroy;
-    widget_class->map = ::map;
-}
-
-
-static void init (GnomeCmdXferProgressWin *win)
+static void gnome_cmd_xfer_progress_win_init (GnomeCmdXferProgressWin *win)
 {
     GtkWidget *vbox;
     GtkWidget *bbox;
@@ -83,35 +63,37 @@ static void init (GnomeCmdXferProgressWin *win)
     win->cancel_pressed = FALSE;
 
     gtk_window_set_title (GTK_WINDOW (win), _("Progress"));
-    gtk_window_set_policy (GTK_WINDOW (win), FALSE, FALSE, FALSE);
+    gtk_window_set_resizable (GTK_WINDOW (win), FALSE);
     gtk_window_set_position (GTK_WINDOW (win), GTK_WIN_POS_CENTER);
     gtk_widget_set_size_request (GTK_WIDGET (win), 300, -1);
 
     vbox = create_vbox (w, FALSE, 6);
+    gtk_widget_set_margin_top (GTK_WIDGET (vbox), 5);
+    gtk_widget_set_margin_bottom (GTK_WIDGET (vbox), 5);
+    gtk_widget_set_margin_start (GTK_WIDGET (vbox), 5);
+    gtk_widget_set_margin_end (GTK_WIDGET (vbox), 5);
     gtk_container_add (GTK_CONTAINER (win), vbox);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
     win->msg_label = create_label (w, "");
-    gtk_container_add (GTK_CONTAINER (vbox), win->msg_label);
+    gtk_box_append (GTK_BOX (vbox), win->msg_label);
 
     win->fileprog_label = create_label (w, "");
-    gtk_container_add (GTK_CONTAINER (vbox), win->fileprog_label);
+    gtk_box_append (GTK_BOX (vbox), win->fileprog_label);
 
     win->totalprog = create_progress_bar (w);
-    gtk_container_add (GTK_CONTAINER (vbox), win->totalprog);
+    gtk_box_append (GTK_BOX (vbox), win->totalprog);
 
     win->fileprog = create_progress_bar (w);
-    gtk_container_add (GTK_CONTAINER (vbox), win->fileprog);
+    gtk_box_append (GTK_BOX (vbox), win->fileprog);
 
     bbox = create_hbuttonbox (w);
-    gtk_container_add (GTK_CONTAINER (vbox), bbox);
+    gtk_box_append (GTK_BOX (vbox), bbox);
 
-    button = create_stock_button (w, GTK_STOCK_CANCEL, GTK_SIGNAL_FUNC (on_cancel));
+    button = create_button (w, _("_Cancel"), G_CALLBACK (on_cancel));
     gtk_widget_set_can_default (button, TRUE);
-    gtk_container_add (GTK_CONTAINER (bbox), button);
+    gtk_box_append (GTK_BOX (bbox), button);
 }
 
-
 /***********************************
  * Public functions
  ***********************************/
@@ -131,31 +113,6 @@ GtkWidget *gnome_cmd_xfer_progress_win_new (guint no_of_files)
 }
 
 
-GtkType gnome_cmd_xfer_progress_win_get_type ()
-{
-    static GtkType dlg_type = 0;
-
-    if (dlg_type == 0)
-    {
-        GtkTypeInfo dlg_info =
-        {
-            (gchar*) "GnomeCmdXferProgressWin",
-            sizeof (GnomeCmdXferProgressWin),
-            sizeof (GnomeCmdXferProgressWinClass),
-            (GtkClassInitFunc) class_init,
-            (GtkObjectInitFunc) init,
-            /* reserved_1 */ nullptr,
-            /* reserved_2 */ nullptr,
-            (GtkClassInitFunc) nullptr
-        };
-
-        dlg_type = gtk_type_unique (gtk_window_get_type (), &dlg_info);
-    }
-
-    return dlg_type;
-}
-
-
 void gnome_cmd_xfer_progress_win_set_total_progress (GnomeCmdXferProgressWin *win,
                                                      guint64 file_bytes_copied,
                                                      guint64 file_size,
