@@ -25,15 +25,12 @@
 #pragma once
 
 #include <gtk/gtk.h>
-#include <gtk/gtkadjustment.h>
-#include <gtk/gtktable.h>
 
 #include "gvtypes.h"
 #include "viewer-utils.h"
 #include "fileops.h"
 #include "inputmodes.h"
 #include "datapresentation.h"
-#include "scroll-box.h"
 #include "image-render.h"
 #include "text-render.h"
 #include "viewer-widget.h"
