@@ -37,11 +37,7 @@ GType text_render_get_type ();
 
 struct TextRender
 {
-    GtkWidget parent;
-
-    struct Private;
-
-    Private *priv;
+    GtkDrawingArea parent;
 
     struct Status
     {
@@ -65,13 +61,6 @@ inline GtkWidget *text_render_new ()
     return (GtkWidget *) g_object_new (TYPE_TEXT_RENDER, NULL);
 }
 
-GtkAdjustment *text_render_get_h_adjustment (TextRender *obj);
-void text_render_set_h_adjustment (TextRender *obj, GtkAdjustment *adjustment);
-GtkAdjustment *text_render_get_v_adjustment (TextRender *obj);
-void text_render_set_v_adjustment (TextRender *obj, GtkAdjustment *adjustment);
-
-void text_render_attach_external_v_range(TextRender *obj, GtkRange *range);
-
 void text_render_load_file(TextRender *w, const gchar *filename);
 void text_render_load_filedesc(TextRender *w, int filedesc);
 
